const mnsjayFunctions = {

	/**
	 * @param number number int
	 */
	numberToPersian: (number) => {

		const persian = {
			0: "۰", 1: "۱", 2: "۲", 3: "۳", 4: "۴",
			5: "۵", 6: "۶", 7: "۷", 8: "۸", 9: "۹"
		};

		number = number.toString().split("");
		let persianNumber = "";

		for (let i = 0; i < number.length; i++) {
			number[i] = persian[number[i]];
		}

		for (let i = 0; i < number.length; i++) {
			persianNumber += number[i];
		}

		return persianNumber;
	},

	/**
	 * @param number number int
	 */
	maybePersian: (number) => {

		return wp.i18n.isRTL ? mnsjayFunctions.numberToPersian(number) : number;
	},

	/**
	 * Move up given element
	 * @param {Object} element moveable object
	 */
	moveUp: (element) => {
		if (element.previousElementSibling)
			element.parentNode.insertBefore(element, element.previousElementSibling);
	},

	/**
	 * Move down given element
	 * @param {Object} element moveable object
	 */
	moveDown: (element) => {
		if (element.nextElementSibling)
			element.parentNode.insertBefore(element.nextElementSibling, element);
	},

	initSelect: (element, args) => {

		element.selectWoo({
			placeholder: element.attr('data-placeholder') || element.attr('placeholder') || '',
			width: '100%',
			...args
		});
	},

	setCookie: (name, value, exp = 2592000, path = '/') => {

		let date = new Date();
		date.setTime(date.getTime() + (exp * 1000));
		date = date.toUTCString();

		document.cookie = `${name}=${value}; expires=${date}; path=${path}`;
	},

	getCookie: (name) => {

		const cDecoded = decodeURIComponent(document.cookie); //to be careful
		const cArr = cDecoded.split('; ');

		let value;
		name = name + "=";

		cArr.forEach(parameter => {
			if (parameter.indexOf(name) === 0) value = parameter.substring(name.length);
		})

		return value;
	},

	/**
	 * @param distance distance in meters int
	 */
	formatDistance: (distance) => {

		let units = {
			'm': wp.i18n.__('meter', 'mnsjay-js'),
			'km': wp.i18n.__('kilometer', 'mnsjay-js')
		},
			unit = 'm',
			unitVal = 1;

		if (distance > 1000) {
			unit = 'km';
			unitVal = 1000;
		}

		let float = distance / unitVal,
			int = parseInt(float),
			decimal = float - int,
			remaining = Number(String(Math.round(decimal * unitVal)).charAt(0)),
			formatted = mnsjayFunctions.maybePersian(int) + '.' + mnsjayFunctions.maybePersian(remaining);

		return `${formatted} ${units[unit]}`;
	},

	/**
	 * @param time time in seconds int
	 */
	formatTime: (time) => {

		let units = {
			's': wp.i18n.__('second', 'mnsjay-js'),
			'm': wp.i18n.__('minute', 'mnsjay-js'),
			'h': wp.i18n.__('hour', 'mnsjay-js')
		},
			unit = 's',
			unitVal = 1,
			divVal = 1;

		if (time > 3600) {
			unit = 'h';
			unitVal = 3600;
			divVal = 60;
		} else if (time > 60) {
			unit = 'm';
			unitVal = 60;
			divVal = 60;
		}

		let float = time / unitVal,
			int = parseInt(float),
			decimal = float - int,
			remaining = Math.round(decimal * divVal),
			formatted = mnsjayFunctions.maybePersian(int) + ':' + mnsjayFunctions.maybePersian(remaining);

		return `${formatted} ${units[unit]}`;
	},

	loadCityOptions: (stateId, cityFieldId, defaultText = '', defaultValue = '') => {

		if (!mnsjayCommonVars.loadCities)
			return;

		defaultText = defaultText ? defaultText : wp.i18n.__('Choose a city', 'mnsjay-js');

		let field = jQuery(`#${cityFieldId}`),
			selected = field.data('selected') ? field.data('selected') : field.val(),
			cities = stateId in mnsjayCommonVars.states ? mnsjayCommonVars.states[stateId].cities : {};

		cities = Object.entries(cities).sort((a, b) => a[1].localeCompare(b[1]));

		field.html('');
		jQuery(`<option value="${defaultValue}">${defaultText}</option>`).appendTo(field);

		for (let city of cities) {
			jQuery(`<option value="${city[0]}">${city[1]}</option>`).appendTo(field);
			if (selected == city[0]) {
				field.val(selected);
			}
		}
	},

	/**
	 * @param element element object
	 * @param offset offset from top int
	 * @param duration duration in ms int
	 */
	scroll: (element, offset = 20, duration = 500) => {

		jQuery([document.documentElement, document.body]).animate({
			scrollTop: element.offset().top - offset
		}, duration);
	},

	/**
	 * @param map Map object
	 * @param coord LatLng object
	 * @param zoom zoom int
	 */
	flyToPoint: (map, coord, zoom) => {

		//map.panTo(new L.LatLng(coord[0], coord[1]));
		//map.setView(new L.LatLng(coord[0], coord[1]), zoom);
		map.flyTo(coord, zoom);
	},

	/**
	 * @param map Map object
	 * @param marker Marker object
	 * @param zoom zoom int
	 */
	flyToMarker: (map, marker, zoom) => {

		marker.openPopup();
		mnsjayFunctions.flyToPoint(map, marker.getLatLng(), zoom);
	},

	/**
	 * Get coordinates pattern
	 * @returns coordinates RegEx
	 */
	coordsReg: () => {
		return /^[\d.]+,[\d.]+/;
	},

	/**
	 * Validate coordinates
	 * @param {string} coords coordinates
	 * @returns {boolean} Validate result
	 */
	validateCoords: (coords) => {
		return mnsjayFunctions.coordsReg().exec(coords) !== null;
	},

	/**
	 * Converts coordinates to string
	 * @param {Object} coord coordinates: {lat: lat, lng: lng}
	 * @param {String} sep seperator
	 * @param {String} format coord type: 'latlng' | 'lonlat'
	 * @returns {String} coordinates seperated by sep in format
	 */
	coordStr: (coord, sep = ',', format = 'latlng') => {
		return format === 'latlng' ? coord.lat + sep + coord.lng : coord.lng + sep + coord.lat;
	},

	/**
	 * Converts coordinates to array
	 * @param {String} coord coordinates seperated by sep in format
	 * @param {String} sep seperator
	 * @returns {Array} coordinates
	 */
	coordsArr: (coords, sep = ',') => {

		return coords.split(sep);
	},

	/**
	 * Converts coordinates to object
	 * @param {String} coord coordinates seperated by sep in format
	 * @param {String} sep seperator
	 * @param {String} format coord type: 'latlng' | 'lonlat'
	 * @returns {Object} coordinates: {lat: lat, lng: lng}
	 */
	coordObj: (coord, sep = ',', format = 'latlng') => {

		coord = coord.split(sep);
		let obj;

		if (format === 'latlng') {
			obj = {
				lat: coord[0],
				lng: coord[1],
			}
		} else {
			obj = {
				lat: coord[1],
				lng: coord[0],
			}
		}

		return obj;
	},

	/**
	 * Converts coordinates to other type
	 * @param {*} coord coordinates in object or string
	 * @param {String} sep seperator
	 * @param {String} format coord type: 'latlng' | 'lonlat'
	 * @returns coordinates in object or string
	 */
	coordConvert: (coord, sep = ',', format = 'latlng') => {
		return typeof coord === 'string' ? mnsjayFunctions.coordObj(coord, sep, format) : mnsjayFunctions.coordStr(coord, sep, format);
	},

	/**
	 * @param coord LatLng object
	 * @param className Class name string
	 */
	createMapMarker: (coord, className = null) => {

		let divIcon = L.divIcon({
			className: "leaflet-data-marker " + className,
			html: mnsjayIcons.map_marker,
			iconAnchor: [12, 32],
			iconSize: [25, 30],
			popupAnchor: [0, -28]
		});

		coord = typeof coord === 'string' ? mnsjayFunctions.coordObj(coord) : coord;

		let marker = L.marker(coord, {
			icon: divIcon
		});

		return marker;
	},

	/**
	 * 
	 * @param {string} geometry encoded
	 * @param {number} size 
	 * @param {string} color 
	 * @param {boolean} head 
	 * @param {string|null} tooltip
	 */
	drawPath: (geometry, size, className, head = false, tooltip = null) => {

		let polyline = L.Polyline.fromEncoded(geometry, {
			color: 'currentColor',
			fill: false,
			className: className,
			weight: size
		});

		if (head) {
			polyline.arrowheads({
				fill: true,
				frequency: '200px',
				size: `${(size * 2)}px`
			});
		}

		if (tooltip) {
			polyline.bindPopup(tooltip);
		}

		return polyline;
	},

	resetPath: (path, className) => {

		path._path.classList.remove('mnsjay-general-path');
		path._path.classList.remove('mnsjay-active-path');
		path._path.classList.remove('mnsjay-deactive-path');
		path._path.classList.remove('mnsjay-hot-path');
		path._path.classList.remove('mnsjay-alternative-path');

		path._path.classList.add(className);
	},

	/**
	 * @param marker Marker object
	 * @param className Class name string
	 */
	resetMapMarker: (marker, className = null) => {

		let divIcon = L.divIcon({
			className: "leaflet-data-marker " + className,
			html: mnsjayIcons.map_marker,
			iconAnchor: [12, 32],
			iconSize: [25, 30],
			popupAnchor: [0, -28]
		});

		marker.setIcon(divIcon);

		return marker;
	},

	toggleMapLock: (map, mapPicker, options, lock) => {

		if (lock) {

			map.scrollWheelZoom.disable();
			map.dragging.disable();
			map.touchZoom.disable();
			map.doubleClickZoom.disable();
			map.boxZoom.disable();
			map.keyboard.disable();
			map.gestureHandling.disable();

			if (map.tap)
				map.tap.disable();

			mapPicker.find('.mnsjay-map-lock-overlay').fadeIn('fast');

			return;
		}

		map.scrollWheelZoom.enable();
		map.dragging.enable();
		map.touchZoom.enable();
		map.doubleClickZoom.enable();
		map.boxZoom.enable();
		map.keyboard.enable();
		options.gesture_handling ? map.gestureHandling.enable() : map.gestureHandling.disable();

		if (map.tap)
			map.tap.enable();

		mapPicker.find('.mnsjay-map-lock-overlay').fadeOut('fast');

	},

	restRequest: async (route, body = {}) => {

		return fetch(mnsjayCommonVars.restBase + route, {

			method: 'POST',
			mode: 'same-origin',
			credentials: 'same-origin',
			headers: {
				'Content-Type': 'application/json',
				'X-WP-Nonce': mnsjayCommonVars.restNonce
			},
			body: JSON.stringify(body)

		}).then(response => response.json()).then(response => {

			return new Promise((resolve, reject) => {
				('code' in response && 'message' in response) ? reject(response) : resolve(response);
			});

		})

	},

	sendRequest: async (action, body = {}) => {

		return fetch(mnsjayCommonVars.ajaxUrl, {

			method: 'POST',
			mode: 'same-origin',
			credentials: 'same-origin',
			headers: {
				'Content-Type': 'application/x-www-form-urlencoded'
			},
			body: new URLSearchParams({
				action: action,
				...body,
			})

		}).then(response => response.json()).then(response => {

			return new Promise((resolve, reject) => {
				response.success ? resolve(response.data) : reject(response.data);
			});

		})
	}
}

jQuery(document).ready(function ($) {

	const { __, _x, _n, sprintf } = wp.i18n;
	const { restRequest, toggleMapLock, flyToPoint, createMapMarker, validateCoords, coordObj, coordStr } = mnsjayFunctions;
	const { nonce, defaultLocation } = mnsjayCommonVars;

	function createMap(mapId, options) {

		let { lat, lng } = coordObj(validateCoords(options.location) ? options.location : defaultLocation);

		let parameters = {
			gestureHandling: options.gesture_handling ? true : false,
			gestureHandlingOptions: {
				text: {
					touch: __('Use two fingers to move the map', 'mnsjay-js'),
					scroll: __('Use ctrl + scroll to zoom the map', 'mnsjay-js'),
					scrollMac: __('Use \u2318 + scroll to zoom the map', 'mnsjay-js')
				},
				duration: 1000
			},
			center: [lat, lng],
			zoomControl: false,
			zoom: options.zoom,
			minZoom: options.min_zoom,
			maxZoom: options.max_zoom,
		};

		if (options.service === 'neshan') {

			let map = new L.Map(mapId, {
				key: options.api_key,
				maptype: options.template,
				poi: true,
				traffic: options.traffic ? true : false,
				...parameters
			});

			return map;
		}

		let map = new L.Map(mapId, parameters);

		if (options.service === 'openstreetmap') {

			L.tileLayer('https://{s}.tile.openstreetmap.org/{z}/{x}/{y}.png', {
				attribution: '&copy; <a href="https://www.openstreetmap.org/copyright">OpenStreetMap</a>',
				subdomains: ['a', 'b', 'c']
			}).addTo(map);

		} else if (options.service === 'mapbox') {

			L.tileLayer('https://api.mapbox.com/styles/v1/{id}/tiles/{z}/{x}/{y}?access_token={accessToken}', {
				attribution: '&copy; <a href="https://www.openstreetmap.org/copyright">OpenStreetMap</a> &copy; <a href="https://www.mapbox.com/">Mapbox</a>',
				id: options.template,
				tileSize: 512,
				zoomOffset: -1,
				accessToken: options.api_key
			}).addTo(map);

		} else if (options.service === 'mapir') {

			L.TileLayer.wmsHeader(
				'https://map.ir/shiveh',
				{
					attribution: '&copy; <a href="https://www.openstreetmap.org/copyright">OpenStreetMap</a> &copy; <a href="https://map.ir/">Map.ir</a>',
					layers: 'Shiveh:Shiveh',
					format: 'image/png',
					tileSize: 256
				},
				[
					{
						header: "x-api-key",
						value: options.api_key
					}
				]
			).addTo(map);

		}

		return map;
	}

	function initMapPicker(mapPicker) {

		if (mapPicker.hasClass('mnsjay-map-inited'))
			return;

		mapPicker.addClass('mnsjay-map-inited');

		let options = JSON.parse(mapPicker.find('.mnsjay-map-options').val());

		const mapContainer = mapPicker.find('.mnsjay-map-container');

		if (!options.central_marker) {
			mapPicker.find('.mnsjay-marker').remove();
		}

		if (!options.display_lat_lng) {
			mapPicker.find('.mnsjay-map-location').remove();
		}

		if (!options.display_lat_lng && !Object.keys(options.buttons).length) {
			mapPicker.find('.mnsjay-map-row').remove();
		}

		const zoomControl = L.control.zoom({
			position: 'bottomright',
			zoomInText: `<span class="mnsjay-control-icon">${mnsjayIcons.plus}</span>`,
			zoomInTitle: __('Zoom in', 'mnsjay-js'),
			zoomOutText: `<span class="mnsjay-control-icon">${mnsjayIcons.minus}</span>`,
			zoomOutTitle: __('Zoom out', 'mnsjay-js')
		});

		const fullscreen = L.control.fullscreen({
			position: 'bottomright',
			title: {
				'false': __('View Fullscreen', 'mnsjay-js'),
				'true': __('Exit Fullscreen', 'mnsjay-js')
			},
			text: `<span class="mnsjay-control-icon">${mnsjayIcons.fullscreen}</span>`,
		});

		const locate = L.control.locate({
			position: 'bottomright',
			setView: 'once',
			flyTo: true,
			clickBehavior: {
				inView: 'stop',
				outOfView: 'setView',
				inViewNotFollowing: 'inView'
			},
			onLocationError: function (t, i) {
				alert(__('Your device\'s location could not be found.', 'mnsjay-js'));
			},
			strings: {
				title: __('My location', 'mnsjay-js'),
				text: mnsjayIcons.locate,
				metersUnit: __('meters', 'mnsjay-js'),
				feetUnit: __('feet', 'mnsjay-js'),
				popup: __('You are within {distance} {unit} from this point', 'mnsjay-js'),
				outsideMapBoundsMsg: __('You seem located outside the boundaries of the map', 'mnsjay-js')
			},
			createButtonCallback: function (buttonEl, options) {

				const s = L.DomUtil.create('a', 'leaflet-bar-part leaflet-bar-part-single', buttonEl);
				s.title = options.strings.title, s.role = 'button', s.href = '#';

				const o = L.DomUtil.create(options.iconElementTag, options.icon + ' mnsjay-control-icon', s);
				o.innerHTML = options.strings.text;

				return {
					link: s,
					icon: o
				}
			},
			locateOptions: {
				maxZoom: options.max_zoom,
				watch: !0,
				setView: !1
			}
		});

		let map = createMap(mapContainer.attr('id'), options);

		map.invalidateSize();

		let { lat, lng } = map.getCenter();

		map.attributionControl.setPrefix(false);
		map.attributionControl.setPosition('bottomleft');

		if (options.service === 'neshan') {
			let neshan = mapContainer.find('a[href="https://maps.neshan.org"]').parent();
			neshan.children('a').find('img').css({ 'vertical-align': 'middle' });
			neshan.children('span').css({ 'margin': '0', 'top': '0' });
			mapContainer.find('.leaflet-control-attribution').html(neshan.html()).css({ 'display': 'flex', 'justify-content': 'start', 'align-items': 'center', 'gap': '5px' });
			neshan.remove();
		}

		zoomControl.addTo(map);

		if (options.fullscreen) {
			fullscreen.addTo(map);
		}

		if (options.device_location) {
			locate.addTo(map);
		}

		map.on('fullscreenchange', function () {
			if (map.isFullscreen()) {
				map.gestureHandling.disable();
			} else {
				options.gesture_handling ? map.gestureHandling.enable() : map.gestureHandling.disable();
			}
		});

		const lockOverlay = mapPicker.find('.mnsjay-map-lock-overlay');

		L.DomEvent.disableScrollPropagation(lockOverlay[0]);
		L.DomEvent.disableClickPropagation(lockOverlay[0]);

		toggleMapLock(map, mapPicker, options, options.lock);

		mapPicker.find('.mnsjay-map-overlay').fadeOut('fast', function () {

			mapPicker.find('.mnsjay-map-row').fadeIn('fast');
			mapPicker.find('.mnsjay-latitude').find('span').text(lat.toFixed(5));
			mapPicker.find('.mnsjay-longitude').find('span').text(lng.toFixed(5));

			$(this).remove();
		});

		map.on('move', function () {

			({ lat, lng } = map.getCenter());

			mapPicker.find('.mnsjay-latitude').find('span').text(lat.toFixed(5));
			mapPicker.find('.mnsjay-longitude').find('span').text(lng.toFixed(5));
			mapPicker.find('.mnsjay-location').val(coordStr({ lat: lat, lng: lng }));
		});


		mapPicker.on('click', '.mnsjay-return', function (e) {

			e.preventDefault();

			({ lat, lng } = coordObj((options.location == '' ? defaultLocation : options.location)));

			flyToPoint(map, new L.LatLng(lat, lng), options.max_zoom);
		});

		let features = new L.FeatureGroup();

		let layers = {
			markers: {},
			areas: {},
			paths: {}
		};

		features.addTo(map);

		if (Object.keys(options.markers).length) {
			for (let _key in options.markers) {

				let _marker = createMapMarker(options.markers[_key].coord, options.markers[_key].class);
				layers.markers[_key] = _marker;

				features.addLayer(_marker);
				options.markers[_key].text && _marker.bindPopup(options.markers[_key].text);
			}
		}

		if (Object.keys(options.areas).length) {
			for (let _key in options.areas) {

				let _area = L.polygon(JSON.parse(options.areas[_key].layers));
				layers.areas[_key] = _area;

				features.addLayer(_area);
				options.areas[_key].text && _area.bindPopup(options.areas[_key].text);
			}
		}

		if (features.getLayers().length) {
			map.fitBounds(features.getBounds());
		}

		wp.hooks.doAction('mnsjayMapInit', map, mapPicker, options, layers);
	}

	wp.hooks.addAction('mnsjayMapInit', 'mns/mnsjay/search', (map, mapPicker, options, layers) => {

		let container = mapPicker.find('.mnsjay-search'),
			input = container.find('.mnsjay-search-input'),
			button = container.find('.mnsjay-search-button'),
			results = container.find('.mnsjay-search-results');

		if (!options.display_search) {
			container.remove();
			return;
		}

		let { lat, lng } = map.getCenter();

		map.on('move', () => ({ lat, lng } = map.getCenter()));

		L.DomEvent.disableScrollPropagation(container[0]);
		L.DomEvent.disableClickPropagation(container[0]);

		input.keypress(function (e) {

			// 13 key code means Enter
			if (e.keyCode != 13)
				return;

			e.preventDefault();

			button.click();
		});

		button.on('click', function (e) {

			e.preventDefault();

			if (input.val().length < 3)
				return;

			if (button.hasClass('mnsjay-loading'))
				return;

			button.addClass('mnsjay-loading').html(mnsjayIcons.spinner);
			container.removeClass('mnsjay-opened');
			results.slideUp('fast', function () {
				$(this).html('');
			});

			restRequest('mnsjay/location/v1/search', {

				coords: `${lat},${lng}`,
				query: input.val()

			}).then(response => {

				$(`<div class="mnsjay-search-close">${mnsjayIcons.arrow_up}</div>`).appendTo(results);

				for (let loc of response.locations) {
					$(`<div class="mnsjay-location-item" data-lat="${loc.latitude}" data-lng="${loc.longitude}"><div>${loc.title}<span>${loc.address}</span></div><div>${loc.region}<span>${loc.neighbourhood}</span></div></div>`).appendTo(results);
				};

				container.addClass('mnsjay-opened');
				results.slideDown('fast');

			}).catch(response => {

				console.error(response);

				container.removeClass('mnsjay-opened');
				results.slideUp('fast');

			}).finally(() => {

				button.removeClass('mnsjay-loading').html(mnsjayIcons.magnifying_glass);
			});
		});

		results.on('click', '.mnsjay-search-close', function () {

			container.removeClass('mnsjay-opened');
			results.slideUp('fast');
		});

		results.on('click', '.mnsjay-location-item', function () {

			flyToPoint(map, new L.LatLng($(this).data('lat'), $(this).data('lng')), options.max_zoom);
			container.removeClass('mnsjay-opened');
			results.slideUp('fast');
		});
	});

	$(document).find('.mnsjay-enhanced-select').each(function () {
		mnsjayFunctions.initSelect($(this));
	});

	$('#billing_city, #shipping_city, #_billing_city, #_shipping_city').each(function () {
		if (mnsjayCommonVars.loadCities) {
			$(this).selectWoo();
		}
	});

	$('#billing_state, #shipping_state, #_billing_state, #_shipping_state').each(function () {
		mnsjayFunctions.loadCityOptions($(this).val(), $(this).attr('id').replace('state', 'city'));
	});

	$('#billing_state, #shipping_state, #_billing_state, #_shipping_state').on('change', function () {
		mnsjayFunctions.loadCityOptions($(this).val(), $(this).attr('id').replace('state', 'city'));
	});

	$(document).find('.mnsjay-map-picker.mnsjay-autoload').each(function () {
		initMapPicker($(this));
	});

	$('.mnsjay-map-picker').on('click', '.mnsjay-map-overlay', function (e) {

		e.preventDefault();
		initMapPicker($(this).parents('.mnsjay-map-picker'));
	});

});