(function ($) {

	const { __, _x, _n, sprintf } = wp.i18n;
	const { restRequest, coordsArr, setCookie } = mnsjayFunctions;

	wp.hooks.addAction('mnsjayMapInit', 'mns/mnsjay/ordersHeatmap', (map, mapPicker, options, layers) => {

		let rangeInput = mapPicker.siblings('.mnsjay-orders-range').find('.mnsjay-orders-range-input'),
			ordersCounter = mapPicker.siblings('.mnsjay-orders-range').find('.mnsjay-counter');

		let points = [];

		function refresh() {

			if (isNaN(rangeInput.val()))
				return;

			points = [];

			ordersCounter.slideUp('fast');

			setCookie('mnsjayHeatmapInterval', rangeInput.val());

			restRequest('mnsjay/heatmap/v1/orders', {

				interval: parseInt(rangeInput.val())

			}).then(response => {

				for (const orderId in response) {
					points.push(coordsArr(response[orderId]));
				}

				heat.setLatLngs(points);
				map.fitBounds(L.latLngBounds(points));

				ordersCounter.text(sprintf(__('Heatmap of %s orders', 'mnsjay-js'), points.length));
				ordersCounter.slideDown('fast');

			}).catch(response => {

				console.error(response);

				heat.setLatLngs(points);

				ordersCounter.text(response.message);
				ordersCounter.slideDown('fast');

			});
		}

		let group = new L.FeatureGroup();
		group.addTo(map);

		let heatOptions = {
			minOpacity: 0.50,
			radius: 25,
			blur: 15
		};

		let heat = L.heatLayer(points, heatOptions);
		group.addLayer(heat);

		$('.mnsjay-heatmap-opacity-range').on('input', function () {
			heatOptions.minOpacity = parseFloat($(this).val());
			heat.setOptions(heatOptions);
		});

		$('.mnsjay-heatmap-radius-range').on('input', function () {
			heatOptions.radius = parseFloat($(this).val());
			heat.setOptions(heatOptions);
		});

		$('.mnsjay-heatmap-blur-range').on('input', function () {
			heatOptions.blur = parseFloat($(this).val());
			heat.setOptions(heatOptions);
		});

		$('.mnsjay-orders-range-input').on('change', function () {
			refresh();
		});

		refresh();

	});

})(jQuery);