(function ($) {

	const { __, _x, _n, sprintf } = wp.i18n;
	const { restRequest, maybePersian, flyToMarker, drawPath, resetPath, loadCityOptions, resetMapMarker, formatDistance, formatTime, coordStr } = mnsjayFunctions;

	function doDelivery(orderId) {

		let orderEl = $(document).find('#mnsjay-order-item-' + orderId);

		if (orderEl.hasClass('mnsjay-order-delivered'))
			return;

		let orderButton = orderEl.find('.mnsjay-delivered');

		if (orderButton.hasClass('mnsjay-loading') || orderButton.hasClass('mnsjay-disable'))
			return;

		orderButton.addClass('mnsjay-loading mnsjay-flash');

		let confirmContainer = $(document).find('.mnsjay-delivery-container'),
			codeInput = confirmContainer.find('.mnsjay-delivery-code-input'),
			details = confirmContainer.find('.mnsjay-popup-details');

		details.html(orderEl.find('.mnsjay-order-details').html());
		codeInput.val('');
		confirmContainer.fadeIn('fast');

		confirmPopup(confirmContainer, codeInput).then(deliveryCode => {

			orderButton.find('span').text(__('Please wait...', 'mnsjay-js'));
			confirmContainer.find('.mnsjay-confirm').addClass('mnsjay-loading mnsjay-flash');

			restRequest('mnsjay/postman/v1/delivery', {

				delivery_code: deliveryCode,
				order_id: orderId,

			}).then(response => {

				orderEl.addClass('mnsjay-order-delivered');

				orderButton.find('span').text(__('Delivered', 'mnsjay-js'));
				orderButton.addClass('mnsjay-disable').removeClass('mnsjay-loading mnsjay-flash');

				confirmContainer.fadeOut('fast');

				wp.hooks.doAction('mnsjayDelivered', response);

			}).catch(response => {

				console.error(response);
				alert(response.message);

				orderButton.find('span').text(__('Deliver', 'mnsjay-js'));
				orderButton.removeClass('mnsjay-loading mnsjay-flash');

				confirmContainer.fadeOut('fast');

			}).finally(() => {

				confirmContainer.find('.mnsjay-confirm').removeClass('mnsjay-loading mnsjay-flash');

			});

		}).catch(() => {

			orderButton.removeClass('mnsjay-loading mnsjay-flash');
			confirmContainer.fadeOut('fast');

		});
	}

	function doReturn(orderId) {

		let orderEl = $(document).find('#mnsjay-order-item-' + orderId);

		if (orderEl.hasClass('mnsjay-order-returned'))
			return;

		let orderButton = orderEl.find('.mnsjay-returned');

		if (orderButton.hasClass('mnsjay-loading') || orderButton.hasClass('mnsjay-disable'))
			return;

		orderButton.addClass('mnsjay-loading mnsjay-flash');

		let confirmContainer = $(document).find('.mnsjay-return-container'),
			note = confirmContainer.find('.mnsjay-return-note'),
			details = confirmContainer.find('.mnsjay-popup-details');

		details.html(orderEl.find('.mnsjay-order-details').html());
		note.val('');
		confirmContainer.fadeIn('fast');

		confirmPopup(confirmContainer, note).then(note => {

			orderButton.find('span').text(__('Please wait...', 'mnsjay-js'));
			confirmContainer.find('.mnsjay-confirm').addClass('mnsjay-loading mnsjay-flash');

			restRequest('mnsjay/postman/v1/return', {

				note: note,
				order_id: orderId,

			}).then(response => {

				orderEl.addClass('mnsjay-order-returned');

				orderButton.find('span').text(__('Returned', 'mnsjay-js'));
				orderButton.addClass('mnsjay-disable').removeClass('mnsjay-loading mnsjay-flash');

				confirmContainer.fadeOut('fast');

				wp.hooks.doAction('mnsjayReturned', response);

			}).catch(response => {

				console.error(response);
				alert(response.message);

				orderButton.find('span').text(__('Return', 'mnsjay-js'));
				orderButton.removeClass('mnsjay-loading mnsjay-flash');

				confirmContainer.fadeOut('fast');

			}).finally(() => {

				confirmContainer.find('.mnsjay-confirm').removeClass('mnsjay-loading mnsjay-flash');

			});

		}).catch(() => {

			orderButton.removeClass('mnsjay-loading mnsjay-flash');
			confirmContainer.fadeOut('fast');

		});
	}

	function doNavigation(orderId, button) {

		if (button.hasClass('mnsjay-loading'))
			return;

		let type;

		if (button.hasClass('mnsjay-here-origin')) {
			type = 'live-to-origin';
		} else if (button.hasClass('mnsjay-here-destination')) {
			type = 'live-to-destination';
		} else if (button.hasClass('mnsjay-origin-destination')) {
			type = 'origin-to-destination';
		} else {
			return;
		}

		button.addClass('mnsjay-loading mnsjay-flash');

		restRequest('mnsjay/postman/v1/navigation', {

			order_id: orderId,
			type: type

		}).then(response => {

			let polylines = [],
				primary = true;

			for (_route of response.routes) {

				let _distance = sprintf(__('Distance: %s', 'mnsjay-js'), formatDistance(_route.distance)),
					_duration = sprintf(__('Duration: %s', 'mnsjay-js'), formatTime(_route.duration));

				if (primary) {
					polylines.push(drawPath(_route.geometry, 5, 'mnsjay-general-path', true, `${_distance}<br>${_duration}`));
					primary = false;
				} else {
					polylines.push(drawPath(_route.geometry, 5, 'mnsjay-alternative-path', true, `${_distance}<br>${_duration}`));
				}
			}

			button.removeClass('mnsjay-loading mnsjay-flash');

			wp.hooks.doAction('mnsjayNavigated', response, polylines);

		}).catch(response => {

			console.error(response);
			button.removeClass('mnsjay-loading mnsjay-flash');

		});

	}

	function confirmPopup(confirmContainer, input) {

		return new Promise((resolve, reject) => {

			confirmContainer.on('click', '.mnsjay-confirm', function (e) {
				e.preventDefault();
				resolve(input.val());
			});

			confirmContainer.on('click', '.mnsjay-cancel', function (e) {
				e.preventDefault();
				reject(false);
			});

		});
	}

	function initTspProfileInput(input) {

		if (input.is(':checked')) {
			input.parents('.mnsjay-tsp-profile').addClass('mnsjay-active').siblings('.mnsjay-tsp-profile').removeClass('mnsjay-active');
		} else {
			input.parents('.mnsjay-tsp-profile').removeClass('mnsjay-active');
		}
	}

	function tspInitShippingInputs(container, activeShippings) {

		let starts = container.find('.mnsjay-tsp-start-list'),
			orders = container.find('.mnsjay-tsp-order-list'),
			ends = container.find('.mnsjay-tsp-end-list');

		let counter = 0;

		starts.find('li').each(function () {

			if ($(this).data('start') === 'live') {
				$(this).show().find('input').prop('checked', true).prop('disabled', false);
				return;
			}

			if (!activeShippings.includes($(this).data('start'))) {
				$(this).hide().find('input').prop('checked', false).prop('disabled', true);
			} else {
				$(this).show().find('input').prop('checked', false).prop('disabled', false);
			}

		});

		orders.find('li').each(function () {

			$(this).find('input').prop('checked', false);

			if (!activeShippings.includes($(this).data('shipping'))) {
				$(this).hide().find('input').prop('disabled', true);
				return;
			}

			$(this).show().find('input').prop('disabled', false);

			if (counter < parseInt(orders.data('max'))) {
				$(this).find('input').prop('checked', true);
				counter++;
			}
		});

		ends.find('li').each(function () {

			if ($(this).data('end') === 'live') {
				$(this).show().find('input').prop('checked', false).prop('disabled', false);
				return;
			}

			if ($(this).data('end') === 'last') {
				$(this).show().find('input').prop('checked', true).prop('disabled', false);
				return;
			}

			if (!activeShippings.includes($(this).data('end'))) {
				$(this).hide().find('input').prop('checked', false).prop('disabled', true);
			} else {
				$(this).show().find('input').prop('checked', false).prop('disabled', false);
			}

		});
	}

	function tspToggleOrderInput(input, ordersList) {

		if (!input.is(':checked')) {
			return;
		}

		let max = parseInt(ordersList.data('max')),
			counter = 0;

		ordersList.find('li').each(function () {

			if (!$(this).find('input').is(':checked'))
				return;

			counter++;
		});

		if (counter <= max)
			return;

		input.prop('checked', false);
	}

	function insertTspItem(resultContainer, response, stepId) {

		let tspItem = resultContainer.find('.mnsjay-tsp-step-placeholder').clone(),
			tspSteps = resultContainer.find('.mnsjay-tsp-steps');

		tspSteps.html('');

		if (stepId === null) {

			tspItem.addClass('mnsjay-start mnsjay-has-icon').removeClass('mnsjay-tsp-step-placeholder');
			tspItem.html(mnsjayIcons.start + ' ' + __('Start your trip!', 'mnsjay-js'));
			tspItem.appendTo(tspSteps);
			tspItem.fadeIn('fast');

			return;
		}

		if (typeof response.steps[stepId] === 'undefined') {

			tspItem.addClass('mnsjay-done mnsjay-has-icon').removeClass('mnsjay-tsp-step-placeholder');
			tspItem.html(mnsjayIcons.location_smile + ' ' + __('It\'s over!', 'mnsjay-js'));
			tspItem.appendTo(tspSteps);
			tspItem.fadeIn('fast');

			return;
		}

		let step = response.steps[stepId];

		tspItem.data('id', step.details.id);
		tspItem.data('type', step.details.type);
		tspItem.data('step', step.step);
		tspItem.data('next', step.step + 1);

		if (step.details.type === 'pick_up' || step.details.type === 'live') {

			tspItem.addClass('mnsjay-next mnsjay-has-icon').removeClass('mnsjay-tsp-step-placeholder');
			tspItem.html(mnsjayIcons.location_check + ' ' + __('Go next!', 'mnsjay-js'));
			tspItem.appendTo(tspSteps);
			tspItem.fadeIn('fast');

			return;
		}

		tspItem.attr('id', 'mnsjay-order-item-' + step.details.id);

		tspItem.addClass(`mnsjay-${step.details.type}`).removeClass('mnsjay-tsp-step-placeholder');
		tspItem.addClass('mnsjay-order-item');

		tspItem.find('.mnsjay-step-turn').text(`${maybePersian((step.step + 1))} / ${maybePersian(response.steps.length)}`);
		tspItem.find('.mnsjay-customer').text(step.details.title);
		tspItem.find('.mnsjay-description').addClass('mnsjay-order-details').html(step.details.description);
		tspItem.find('.mnsjay-distance span').text(formatDistance(step.distance));
		tspItem.find('.mnsjay-duration span').text(formatTime(step.duration));

		tspItem.appendTo(tspSteps);
		tspItem.fadeIn('fast');
	}

	function tspRequest() {

		let container = $(document).find('.mnsjay-tsp-container'),
			form = container.find('form'),
			resultContainer = container.find('.mnsjay-tsp-result'),
			submitButton = container.find('.mnsjay-tsp-calculate');

		if (submitButton.hasClass('mnsjay-loading'))
			return;

		submitButton.addClass('mnsjay-loading');
		submitButton.addClass('mnsjay-flash');
		submitButton.find('span').text(__('Calculating', 'mnsjay-js'));

		resultContainer.slideUp('fast');

		let origin, destination, pickUps = [], dropOffs = [];

		for (let _input of form.serializeArray()) {

			switch (_input.name) {
				case 'mnsjay_tsp_start':
					origin = _input.value;
					break;
				case 'mnsjay_tsp_end':
					destination = _input.value;
					break;
				case 'mnsjay_tsp_item[]':
					dropOffs.push(_input.value);
					break;
				case 'mnsjay_tsp_method[]':
					pickUps.push(_input.value);
					break;
				default:
					break;
			}
		}

		restRequest('mnsjay/postman/v1/tsp', {

			origin: origin,
			destination: destination,
			pick_ups: pickUps,
			drop_offs: dropOffs,
			postman_id: mnsjayCommonVars.currentUserID

		}).then(response => {

			wp.hooks.doAction('mnsjayTsp', response, resultContainer);

		}).catch(response => {

			console.error(response);
			alert(response.message);

		}).finally(() => {

			submitButton.removeClass('mnsjay-loading');
			submitButton.removeClass('mnsjay-flash');
			submitButton.find('span').text(__('Suggest a route', 'mnsjay-js'));

		});
	};

	function saveSettings(form) {

		let button = form.find('.mnsjay-save'),
			inputs = {};

		for (let input of form.serializeArray()) {
			inputs[input.name] = input.value;
		}

		button.addClass('mnsjay-loading');
		button.find('span').text(__('Please wait...', 'mnsjay-js'));

		restRequest('mnsjay/postman/v1/settings', {

			inputs: inputs,
			postman_id: mnsjayCommonVars.currentUserID

		}).then(response => {

			button.find('span').text(__('Changes saved!', 'mnsjay-js'));
			button.removeClass('mnsjay-loading');

		}).catch(response => {

			console.error(response);

			button.find('span').text(__('Try Again!', 'mnsjay-js'));
			button.removeClass('mnsjay-loading');

		});
	}

	wp.hooks.addAction('mnsjayMapInit', 'mns/mnsjay/postmanPanel', function (map, mapPicker, options, layers) {

		let { lat, lng } = map.getCenter();

		map.on('move', () => ({ lat, lng } = map.getCenter()));

		let postmanLayers = new L.FeatureGroup();
		postmanLayers.addTo(map);

		let live;

		if (options.watch === 'yes') {

			new Promise((resolve, reject) => {

				map.locate({
					watch: true,
					enableHighAccuracy: true
				});

				map.on('locationfound', function (e) {

					live = e.latlng;

					restRequest('mnsjay/postman/v1/live', {

						coords: coordStr(e.latlng),
						postman_id: mnsjayPostmanGlobal.postmanId,

					})

					resolve(e);
				});

				map.on('locationerror', function (e) {
					reject(e);
				});

			}).catch(response => {

				console.error(response);
				alert(__('This page needs your location to work better. If you have disabled your device locator, turn it on, and if permission denied, please allow it.', 'mnsjay-js'));

			});
		}

		wp.hooks.addAction('mnsjayNavigated', 'mns/mnsjay/navigation', (response, polylines) => {

			postmanLayers.clearLayers();

			for (let polyline of polylines.reverse()) {
				polyline.addTo(postmanLayers);
				polyline.openPopup();
			}

			map.fitBounds(postmanLayers.getBounds());

		});

		$('.mnsjay-order-header').on('click', function () {

			let orderEl = $(this).parents('.mnsjay-order-item'),
				orderId = orderEl.data('id');

			orderEl.siblings('.mnsjay-order-item').each(function () {
				$(this).removeClass('mnsjay-opened');
				$(this).find('.mnsjay-order-body').slideUp('fast');
			});

			if (orderEl.hasClass('mnsjay-opened')) {
				orderEl.removeClass('mnsjay-opened');
				orderEl.find('.mnsjay-order-body').slideUp('fast');
			} else {
				flyToMarker(map, layers.markers[orderId], options.max_zoom);
				orderEl.addClass('mnsjay-opened');
				orderEl.find('.mnsjay-order-body').slideDown('fast');
			}
		});

		wp.hooks.addAction('mnsjayTsp', 'mns/mnsjay/tsp', function (response, resultContainer) {

			console.log(response);

			postmanLayers.clearLayers();
			let stepsPolyline = {};

			for (let step of response.steps) {

				if (!step.geometries.length)
					continue;

				let _geometry = step.geometries[0];

				let _distance = sprintf(__('Distance: %s', 'mnsjay-js'), formatDistance(_geometry.distance)),
					_duration = sprintf(__('Duration: %s', 'mnsjay-js'), formatTime(_geometry.duration));

				let _polyline = drawPath(_geometry.geometry, 5, 'mnsjay-general-path', false, `${_distance}<br>${_duration}`);

				stepsPolyline[step.step] = _polyline;
				_polyline.addTo(postmanLayers);
			}

			map.fitBounds(postmanLayers.getBounds());

			let resultCount = resultContainer.find('.mnsjay-tsp-count'),
				resultDistance = resultContainer.find('.mnsjay-tsp-distance'),
				resultDuration = resultContainer.find('.mnsjay-tsp-duration');

			let origins = maybePersian(1),
				coordinates = maybePersian(Object.keys(response.coords).length - 1),
				distance = formatDistance(response.distance),
				duration = formatTime(response.duration);

			resultCount.html(sprintf(__('The trip includes <span>%s</span> origin and <span>%s</span> destinations', 'mnsjay-js'), origins, coordinates));
			resultDistance.html(sprintf(__('Total distance <span>%s</span>', 'mnsjay-js'), distance));
			resultDuration.html(sprintf(__('Probable time <span>%s</span>', 'mnsjay-js'), duration));

			resultContainer.on('click', '.mnsjay-open-location-url', function (e) {
				e.preventDefault();
				let orderId = parseInt($(this).parents('.mnsjay-order-item').data('id'));
				Object.assign(document.createElement('a'), {
					target: '_blank',
					rel: 'noopener noreferrer',
					href: options.urls[orderId],
				}).click();
			});

			insertTspItem(resultContainer, response, null);

			resultContainer.siblings('.mnsjay-tsp-form').slideUp('fast', function () {
				resultContainer.slideDown('fast');
			});

			// first remove old event to prevent run duplicate events
			resultContainer.off('click', '.mnsjay-call');
			resultContainer.on('click', '.mnsjay-call', function () {
				let orderId = parseInt($(this).parents('.mnsjay-order-item').data('id'));
				window.open(`tel:${options.phones[orderId]}`, '_self');
			});

			// first remove old event to prevent run duplicate events
			resultContainer.off('click', '.mnsjay-start');
			resultContainer.on('click', '.mnsjay-start', function () {

				resetPath(stepsPolyline[0], 'mnsjay-hot-path');
				stepsPolyline[0].openPopup();
				stepsPolyline[0].bringToFront();
				map.fitBounds(stepsPolyline[0].getBounds());

				insertTspItem(resultContainer, response, 0);
			});

			// first remove old event to prevent run duplicate events
			resultContainer.off('click', '.mnsjay-next');
			resultContainer.on('click', '.mnsjay-next', function () {

				let stepId = parseInt($(this).data('step')),
					nextId = parseInt($(this).data('next'));

				if (typeof response.steps[nextId] !== 'undefined') {
					resetPath(stepsPolyline[nextId], 'mnsjay-hot-path');
					stepsPolyline[nextId].openPopup();
					stepsPolyline[nextId].bringToFront();
					map.fitBounds(stepsPolyline[nextId].getBounds());
				}

				resetPath(stepsPolyline[stepId], 'mnsjay-deactive-path');
				insertTspItem(resultContainer, response, nextId);
			});

			function nextStep(r) {

				let stepId = parseInt(resultContainer.find('#mnsjay-order-item-' + r.order_id).data('step')),
					nextId = parseInt(resultContainer.find('#mnsjay-order-item-' + r.order_id).data('next'));

				if (typeof response.steps[nextId] !== 'undefined') {
					resetPath(stepsPolyline[nextId], 'mnsjay-hot-path');
					stepsPolyline[nextId].openPopup();
					stepsPolyline[nextId].bringToFront();
					map.fitBounds(stepsPolyline[nextId].getBounds());
				}

				resetPath(stepsPolyline[stepId], 'mnsjay-deactive-path');
				insertTspItem(resultContainer, response, nextId);
			}

			wp.hooks.removeAction('mnsjayDelivered', 'mns/mnsjay/stepDelivered');
			wp.hooks.removeAction('mnsjayReturned', 'mns/mnsjay/stepReturned');
			wp.hooks.addAction('mnsjayDelivered', 'mns/mnsjay/stepDelivered', nextStep);
			wp.hooks.addAction('mnsjayReturned', 'mns/mnsjay/stepReturned', nextStep);

		}, 10);

		wp.hooks.addAction('mnsjayDelivered', 'mns/mnsjay/delivered', function (response) {
			resetMapMarker(layers.markers[response.order_id]);
		});

		wp.hooks.addAction('mnsjayReturned', 'mns/mnsjay/returned', function (response) {
			resetMapMarker(layers.markers[response.order_id]);
		});

		mapPicker.find('#mnsjay_submit_location').on('click', function (e) {

			e.preventDefault();

			let button = $(this);

			if (button.hasClass('mnsjay-loading'))
				return;

			button.addClass('mnsjay-loading');
			button.find('.mnsjay-has-icon').html(mnsjayIcons.location_dash);
			button.find('.mnsjay-button-title').text(__('Please wait...', 'mnsjay-js'));

			restRequest(`mnsjay/location/v1/submit/coords/${lat},${lng}`).then(response => {

				$(document).find('#_mnsjay_postman_address').val(response.formatted_address);
				$(document).find('#_mnsjay_postman_coords').val(`${lat},${lng}`);

				button.find('.mnsjay-has-icon').html(mnsjayIcons.location_edit);
				button.find('.mnsjay-button-title').text(__('Submit Location', 'mnsjay-js'));
				button.removeClass('mnsjay-loading');

			}).catch(response => {

				console.error(response);

				button.find('.mnsjay-has-icon').html(mnsjayIcons.location_error);
				button.find('.mnsjay-button-title').text(__('Try Again!', 'mnsjay-js'));
				button.removeClass('mnsjay-loading');

			});

		});

	});

	$('form.mnsjay-tsp-form').on('submit', function (e) {

		e.preventDefault();
		tspRequest();
	});

	$(document).on('click', '.mnsjay-delivered', function () {

		let orderId = $(this).parents('.mnsjay-order-item').data('id');

		doDelivery(orderId);
	});

	$(document).on('click', '.mnsjay-returned', function () {

		let orderId = $(this).parents('.mnsjay-order-item').data('id');

		doReturn(orderId);
	});

	$(document).on('click', '.mnsjay-navigations > *', function () {

		let orderId = $(this).parents('.mnsjay-order-item').data('id');

		doNavigation(orderId, $(this));

	});

	$(document).on('click', '.mnsjay-tsp-calculate', function () {
		tspRequest();
	});

	$(document).on('click', '.mnsjay-tsp-reset', function () {
		$(this).parents('.mnsjay-tsp-result').slideUp('fast', function () {
			$(this).siblings('.mnsjay-tsp-form').slideDown('fast');
		});
	});

	$(document).on('change', '.mnsjay-tsp-order-input', function () {
		tspToggleOrderInput($(this), $(this).parents('.mnsjay-tsp-order-list'));
	});

	$(document).on('change', '.mnsjay-tsp-shipping-input', function () {

		let activeShippings = [];

		$(this).parents('.mnsjay-tsp-shipping-list').find('input').each(function () {
			$(this).is(':checked') && activeShippings.push($(this).val());
		});

		tspInitShippingInputs($(this).parents('.mnsjay-tsp-container'), activeShippings);
	});

	$(document).ready(function () {

		$(document).on('submit', '.mnsjay-settings-form', function (e) {
			e.preventDefault();
			$(this).find('.mnsjay-save').click();
		});

		$(document).find('.mnsjay-settings-form').on('click', '.mnsjay-save', function () {
			saveSettings($(this).parents('.mnsjay-settings-form'));
		});

		$(document).find('.mnsjay-state-select').each(function () {
			loadCityOptions($(this).val(), $(this).attr('id').replace('state', 'city'));
		});

		$(document).on('change', '.mnsjay-state-select', function () {
			loadCityOptions($(this).val(), $(this).attr('id').replace('state', 'city'));
		});

		$(document).find('.mnsjay-tsp-shipping-list').each(function () {

			let activeShippings = [],
				_first = true;

			$(this).find('input').each(function () {
				if (_first) {
					$(this).prop('checked', true);
					_first = false;
				}
				$(this).is(':checked') && activeShippings.push($(this).val());
			});

			tspInitShippingInputs($(this).parents('.mnsjay-tsp-container'), activeShippings);

		});
	});

})(jQuery);