(function ($) {

	const { __, _x, _n, sprintf } = wp.i18n;
	const { restRequest, coordStr, coordObj, flyToPoint, toggleMapLock } = mnsjayFunctions;
	const { locationFieldKey, onlyInRegions } = mnsjayCheckoutGlobal;
	const { updateMapOnCheckoutFieldsChange } = mnsjayCommonVars;

	function isInRegions(state, city) {

		if (!onlyInRegions.length)
			return true;

		for (let region of onlyInRegions) {
			region = region.split(':');
			if (region.includes('city')) {
				if (region[2] === state && region[3] === city) {
					return true;
				}
			} else if (region.includes('state')) {
				if (region[2] === state) {
					return true;
				}
			}
		}

		return false;
	}

	function toggleLocationField(field) {

		let type = field.attr('id').indexOf('billing') === -1 ? 'shipping' : 'billing';

		let city = $(`#${type}_city`).val(),
			state = $(`#${type}_state`).val();

		if (isInRegions(state, city)) {
			$(`#${type}_${locationFieldKey}_field`).show();
			wp.hooks.doAction('mnsjayMapDisplayed', type);
		} else {
			$(`#${type}_${locationFieldKey}_field`).hide();
			wp.hooks.doAction('mnsjayMapHided', type);
		}
	}

	wp.hooks.addAction('mnsjayMapInit', 'mns/mnsjay/checkout', (map, mapPicker, options) => {

		let { lat, lng } = map.getCenter();

		map.on('move', () => ({ lat, lng } = map.getCenter()));

		wp.hooks.addAction('mnsjayMapOpenPopUp', 'mns/mnsjay/checkout', () => map.invalidateSize());
		wp.hooks.addAction('mnsjayMapDisplayed', 'mns/mnsjay/checkout', () => map.invalidateSize());

		let instantSubmit = options.submit_type === 'move';

		let lock = options.lock;

		toggleMapLock(map, mapPicker, options, lock);

		let submitButton = mapPicker.find('#mnsjay_submit_location');
		let coordsInput = mapPicker.find('#' + options.checkout + '_' + locationFieldKey);

		$('#' + options.checkout + '_state, #' + options.checkout + '_city').on('change', function () {

			if (lock || updateMapOnCheckoutFieldsChange !== 'yes')
				return;

			let stateInput = $('#' + options.checkout + '_state'),
				cityInput = $('#' + options.checkout + '_city');

			let state = stateInput[0].tagName.toLowerCase() === 'input' ? stateInput.val() : stateInput.find(':selected').text(),
				city = cityInput[0].tagName.toLowerCase() === 'input' ? cityInput.val() : cityInput.find(':selected').text();

			if (!state || !city)
				return;

			restRequest('mnsjay/checkout/v1/geocode', {

				province: state,
				city: city

			}).then(response => {

				flyToPoint(map, coordObj(response.coords), options.zoom);

			}).catch(response => {

				console.error(response);

			});

		});

		if (lock) {

			coordsInput.val(coordStr({ lat: lat, lng: lng }));

			submitButton.find('.mnsjay-has-icon').html(mnsjayIcons.location_edit);
			submitButton.find('.mnsjay-button-title').text(__('Change Location', 'mnsjay-js'));

			if (options.holder_type === 'popup-small' || options.holder_type === 'popup-full') {
				mapPicker.find('.mnsjay-open-map-holder').addClass('mnsjay-location-submitted').find('.mnsjay-title').text(__('Location Submitted', 'mnsjay-js'));
			}

		} else {

			coordsInput.val('');

			submitButton.find('.mnsjay-has-icon').html(mnsjayIcons.location_check);
			submitButton.find('.mnsjay-button-title').text(__('Submit Location', 'mnsjay-js'));

			if (options.holder_type === 'popup-small' || options.holder_type === 'popup-full') {
				mapPicker.find('.mnsjay-open-map-holder').removeClass('mnsjay-location-submitted').find('.mnsjay-title').text(__('Submit Location', 'mnsjay-js'));
			}

		}

		if (instantSubmit) {

			toggleMapLock(map, mapPicker, options, false);

			submitButton.find('.mnsjay-has-icon').html(mnsjayIcons.location_check);
			submitButton.find('.mnsjay-button-title').text(__('Submit Location', 'mnsjay-js'));

			if (options.holder_type === 'popup-small' || options.holder_type === 'popup-full') {
				mapPicker.find('.mnsjay-open-map-holder').removeClass('mnsjay-location-submitted').find('.mnsjay-title').text(__('Submit Location', 'mnsjay-js'));
			}

			map.on('movestart', () => {
				submitButton.find('.mnsjay-has-icon').html(mnsjayIcons.location_edit);
				submitButton.find('.mnsjay-button-title').text(__('Moving...', 'mnsjay-js'));
			});

			map.on('move', () => {
				submitButton.find('.mnsjay-has-icon').html(mnsjayIcons.location_edit);
				submitButton.find('.mnsjay-button-title').text(__('Moving...', 'mnsjay-js'));
			});

			map.on('moveend', () => submitButton.click());
		}

		submitButton.on('click', function (e) {

			e.preventDefault();

			if (submitButton.hasClass('mnsjay-loading'))
				return;

			submitButton.addClass('mnsjay-loading');
			submitButton.find('.mnsjay-has-icon').html(mnsjayIcons.location_dash);
			submitButton.find('.mnsjay-button-title').text(__('Please wait...', 'mnsjay-js'));

			restRequest('mnsjay/checkout/v1/set-coords', {

				coords: `${lat},${lng}`,
				checkout: options.checkout,
				set: instantSubmit ? true : !lock

			}).then(response => {

				if (instantSubmit) {

					coordsInput.val(coordStr({ lat: lat, lng: lng }));

					if (options.fill_address) {
						$('#' + options.checkout + '_address_1').val(response.formatted_address);
					}

					submitButton.find('.mnsjay-has-icon').html(mnsjayIcons.location_check);
					submitButton.find('.mnsjay-button-title').text(__('Submit Location', 'mnsjay-js'));

					$(document.body).trigger("update_checkout");

					return;
				}

				toggleMapLock(map, mapPicker, options, !lock);

				if (lock) {

					coordsInput.val('');

					submitButton.find('.mnsjay-has-icon').html(mnsjayIcons.location_check);
					submitButton.find('.mnsjay-button-title').text(__('Submit Location', 'mnsjay-js'));

					if (options.holder_type === 'popup-small' || options.holder_type === 'popup-full') {
						mapPicker.find('.mnsjay-open-map-holder').removeClass('mnsjay-location-submitted').find('.mnsjay-title').text(__('Submit Location', 'mnsjay-js'));
					}

				} else {

					coordsInput.val(coordStr({ lat: lat, lng: lng }));

					if (options.fill_address) {
						$('#' + options.checkout + '_address_1').val(response.formatted_address);
					}

					submitButton.find('.mnsjay-has-icon').html(mnsjayIcons.location_edit);
					submitButton.find('.mnsjay-button-title').text(__('Change Location', 'mnsjay-js'));

					if (options.holder_type === 'popup-small' || options.holder_type === 'popup-full') {
						mapPicker.find('.mnsjay-open-map-holder').addClass('mnsjay-location-submitted').find('.mnsjay-title').text(__('Location Submitted', 'mnsjay-js'));
						mapPicker.find('.mnsjay-close-map-holder').click();
					}

				}

				$(document.body).trigger("update_checkout");

				lock = !lock;

			}).catch(response => {

				console.error(response);

				submitButton.find('.mnsjay-has-icon').html(mnsjayIcons.location_error);
				submitButton.find('.mnsjay-button-title').text(__('Try Again!', 'mnsjay-js'));

			}).finally(() => {

				submitButton.removeClass('mnsjay-loading');

			});

		});

	}, 10);

	$(document).ready(function () {

		$(document).find('.mnsjay-checkout-map').each(function () {
			let checkout = $(this).hasClass('mnsjay-billing-map') ? 'billing' : 'shipping';
			$(document).find(`#${checkout}_${locationFieldKey}_field`).find('.woocommerce-input-wrapper').html($(this));
		});

		$('#billing_city, #shipping_city').each(function () {
			toggleLocationField($(this));
		});

		$('#billing_city, #shipping_city').on('change', function () {
			toggleLocationField($(this));
		});

		$('#billing_state, #shipping_state').each(function () {
			toggleLocationField($(this));
		});

		$('#billing_state, #shipping_state').on('change', function () {
			toggleLocationField($(this));
		});

		$('.mnsjay-checkout-map').find('.mnsjay-open-map-holder').each(function () {

			$(this).parents('.mnsjay-map-picker').find('.mnsjay-map-overlay').click();
		});

		$('.mnsjay-checkout-map').on('click', '.mnsjay-open-map-holder', function (e) {

			e.preventDefault();

			$(this).parents('.mnsjay-map-picker').find('.mnsjay-map-holder').fadeIn('fast');

			wp.hooks.doAction('mnsjayMapOpenPopUp');
		});

		$('.mnsjay-checkout-map').on('click', '.mnsjay-close-map-holder', function (e) {

			e.preventDefault();

			$(this).parents('.mnsjay-map-holder').fadeOut('fast');
		});
	});

})(jQuery);