<?php

// Converter functions to version 4.x.x (till 1402)

function mnsjay_converter_display_distance($data) {

	$display = get_option('mnsjay_display_distance');

	if ($display !== 'yes')
		return $data;

	foreach ($data as $key => $value) {
		if ($value !== 'yes') {
			$data[$key] = $display;
		}
	}

	update_option('mnsjay_shipping_display_distance', $data);
	delete_option('mnsjay_display_distance');

	return $data;
}

function mnsjay_converter_shipping_base_costs($data) {

	if (count($data))
		return $data;

	$data = [];

	foreach (mnsjay_get_option_shipping_methods() as $_method_key => $_method_values) {
		$data[$_method_key] = isset($_method_values['base_cost']) ? $_method_values['base_cost'] : '0';
	}

	return $data;
}

function mnsjay_converter_shipping_distances($data) {

	if (count($data))
		return $data;

	$data = [];

	$ranges = mnsjay_get_option_shipping_distance_ranges();
	$classes = mnsjay_get_option_shipping_distance_classes();

	foreach (mnsjay_get_option_shipping_distance_bases() as $_method_key => $_each_km_cost) {

		$data[$_method_key] = [];
		$_data = [];
		$classes[$_method_key] = (isset($classes[$_method_key]) and is_array($classes[$_method_key])) ? $classes[$_method_key] : [];

		$_each_km_cost = is_numeric($_each_km_cost) ? intval($_each_km_cost) : 0;

		$general_from = is_numeric($ranges[$_method_key]['from']) ? intval($ranges[$_method_key]['from']) : 0;
		$general_to = is_numeric($ranges[$_method_key]['to']) ? intval($ranges[$_method_key]['to']) : 0;

		$class_lower_from = null;
		$class_higher_to = null;

		////////////////

		if ($general_from > 0) {
			$data[$_method_key]['1000'] = [
				'from' => 0,
				'to' => $general_from - 1,
				'cost' => 0,
				'cost_type' => 'fixed',
				'inactive' => 'yes',
			];
		}

		foreach ($classes[$_method_key] as $_class_key => $_class_values) {

			$_from = is_numeric($_class_values['distance_from']) ? intval($_class_values['distance_from']) : 0;
			$_to = is_numeric($_class_values['distance_to']) ? intval($_class_values['distance_to']) : 0;

			$_from = ($_from <= $general_from) ? $general_from : $_from;
			$_to = ($general_to > 0 and $_to >= $general_to) ? $general_to : $_to;
			$_to = ($general_to > 0 and $_to < 1) ? $general_to : $_to;

			if ($_from > $_to and $_to > 0) {
				continue;
			}

			$class_lower_from = $class_lower_from === null ? $_from : $class_lower_from;
			$class_higher_to = $class_higher_to === null ? $_to : $class_higher_to;

			$class_lower_from = $class_lower_from > $_from ? $_from : $class_lower_from;
			$class_higher_to = $class_higher_to < $_to ? $_to : $class_higher_to;

			$_data[$_class_key] = [
				'from' => $_from,
				'to' => $_to,
				'cost' => is_numeric($_class_values['cost']) ? $_class_values['cost'] : 0,
				'cost_type' => 'fixed',
				'inactive' => '',
			];
		}

		if (count($_data)) {

			if ($class_lower_from > $general_from) {
				$data[$_method_key]['1001'] = [
					'from' => $general_from,
					'to' => $class_lower_from - 1,
					'cost' => $_each_km_cost,
					'cost_type' => 'stepwise',
					'inactive' => '',
				];
			}

			foreach ($_data as $_k => $_v) {
				$data[$_method_key][$_k] = $_v;
			}

			if ($class_higher_to < $general_to or ($class_higher_to > $general_to and $general_to == 0)) {
				$data[$_method_key]['1002'] = [
					'from' => $class_higher_to + 1,
					'to' => $general_to,
					'cost' => $_each_km_cost,
					'cost_type' => 'stepwise',
					'inactive' => '',
				];
			}
		} else {
			if ($_each_km_cost > 0) {
				$data[$_method_key]['1005'] = [
					'from' => $general_from,
					'to' => $general_to,
					'cost' => $_each_km_cost,
					'cost_type' => 'stepwise',
					'inactive' => '',
				];
			}
		}

		if ($general_to > 0) {
			$data[$_method_key]['1003'] = [
				'from' => $general_to + 1,
				'to' => 0,
				'cost' => 0,
				'cost_type' => 'fixed',
				'inactive' => 'yes',
			];
		}
	}

	return $data;
}

function mnsjay_converter_shipping_weights($data) {

	if (count($data))
		return $data;

	$data = [];

	$ranges = mnsjay_get_option_shipping_weight_ranges();
	$classes = mnsjay_get_option_shipping_weight_classes();

	foreach (mnsjay_get_option_shipping_weight_bases() as $_method_key => $_each_km_cost) {

		$data[$_method_key] = [];
		$_data = [];
		$classes[$_method_key] = (isset($classes[$_method_key]) and is_array($classes[$_method_key])) ? $classes[$_method_key] : [];

		$_each_km_cost = is_numeric($_each_km_cost) ? intval($_each_km_cost) : 0;

		$general_from = is_numeric($ranges[$_method_key]['from']) ? intval($ranges[$_method_key]['from']) : 0;
		$general_to = is_numeric($ranges[$_method_key]['to']) ? intval($ranges[$_method_key]['to']) : 0;

		$class_lower_from = null;
		$class_higher_to = null;

		////////////////

		if ($general_from > 0) {
			$data[$_method_key]['1000'] = [
				'from' => 0,
				'to' => $general_from - 1,
				'cost' => 0,
				'cost_type' => 'fixed',
				'inactive' => 'yes',
			];
		}

		foreach ($classes[$_method_key] as $_class_key => $_class_values) {

			$_from = is_numeric($_class_values['weight_from']) ? intval($_class_values['weight_from']) : 0;
			$_to = is_numeric($_class_values['weight_to']) ? intval($_class_values['weight_to']) : 0;

			$_from = ($_from <= $general_from) ? $general_from : $_from;
			$_to = ($general_to > 0 and $_to >= $general_to) ? $general_to : $_to;
			$_to = ($general_to > 0 and $_to < 1) ? $general_to : $_to;

			if ($_from > $_to and $_to > 0) {
				continue;
			}

			$class_lower_from = $class_lower_from === null ? $_from : $class_lower_from;
			$class_higher_to = $class_higher_to === null ? $_to : $class_higher_to;

			$class_lower_from = $class_lower_from > $_from ? $_from : $class_lower_from;
			$class_higher_to = $class_higher_to < $_to ? $_to : $class_higher_to;

			$_data[$_class_key] = [
				'from' => $_from,
				'to' => $_to,
				'cost' => is_numeric($_class_values['cost']) ? $_class_values['cost'] : 0,
				'cost_type' => 'fixed',
				'inactive' => '',
			];
		}

		if (count($_data)) {

			if ($class_lower_from > $general_from) {
				$data[$_method_key]['1001'] = [
					'from' => $general_from,
					'to' => $class_lower_from - 1,
					'cost' => $_each_km_cost,
					'cost_type' => 'stepwise',
					'inactive' => '',
				];
			}

			foreach ($_data as $_k => $_v) {
				$data[$_method_key][$_k] = $_v;
			}

			if ($class_higher_to < $general_to or ($class_higher_to > $general_to and $general_to == 0)) {
				$data[$_method_key]['1002'] = [
					'from' => $class_higher_to + 1,
					'to' => $general_to,
					'cost' => $_each_km_cost,
					'cost_type' => 'stepwise',
					'inactive' => '',
				];
			}
		} else {
			if ($_each_km_cost > 0) {
				$data[$_method_key]['1005'] = [
					'from' => $general_from,
					'to' => $general_to,
					'cost' => $_each_km_cost,
					'cost_type' => 'stepwise',
					'inactive' => '',
				];
			}
		}

		if ($general_to > 0) {
			$data[$_method_key]['1003'] = [
				'from' => $general_to + 1,
				'to' => 0,
				'cost' => 0,
				'cost_type' => 'fixed',
				'inactive' => 'yes',
			];
		}
	}

	return $data;
}

add_action('wp_ajax_mnsjay_converter_old_data', function () {

	if (!wp_doing_ajax())
		wp_send_json_error(['message' => 'Request is not an AJAX']);

	if (!isset($_POST['methodKey']) or !isset($_POST['buttonAction']))
		wp_send_json_error(['message' => 'Request is not correct']);

	$method_key = sanitize_text_field($_POST['methodKey']);
	$action = sanitize_text_field($_POST['buttonAction']);

	$methods = mnsjay_get_option_shipping_methods();

	if ($action === 'origin-delete') {

		$data = mnsjay_get_option_origin_locations();

		if (isset($data[$method_key])) {
			unset($data[$method_key]);
			update_option('mnsjay_origin_locations', $data);
		}

		wp_send_json_success(['message' => 'تنظیمات مبدا قدیمی این روش حمل و نقل با موفقیت حذف شد.']);
	}

	if ($action === 'origin-trans') {

		$data = mnsjay_get_option_origin_locations();

		if (isset($data[$method_key])) {

			$location_id = wp_insert_post(array(
				'comment_status' => 'close',
				'ping_status'    => 'close',
				'post_author'    => get_current_user_id(),
				'post_title'     => sprintf(__('%s origin', 'mnsjay'), $methods[$method_key]['title']),
				'post_status'    => 'publish',
				'post_type'      => 'mnsjay-location',
			));

			mnsjay_update_location_coords($location_id, $data[$method_key]);

			$coords = mnsjay_coords_parse($data[$method_key]);
			$place = mnsjay_get_place($coords['lat'], $coords['lng']);

			if ($place['status']) {
				mnsjay_update_location_country($location_id, $place['country']);
				mnsjay_update_location_province($location_id, $place['state']);
				mnsjay_update_location_city($location_id, $place['city']);
				mnsjay_update_location_address($location_id, $place['formatted_address']);
			}

			unset($data[$method_key]);
			update_option('mnsjay_origin_locations', $data);

			$origins = mnsjay_get_option_shipping_origins();
			$origins[$method_key] = $location_id;
			update_option('mnsjay_shipping_origins', $origins);
		}

		wp_send_json_success(['message' => 'تنظیمات مبدا قدیمی این روش حمل و نقل با موفقیت به نسخه جدید تبدیل شد. این صفحه را مجددا بارگذاری کنید.']);
	}

	if ($action === 'layer-delete') {

		$data = mnsjay_get_option_zone_layers();

		if (isset($data[$method_key])) {
			unset($data[$method_key]);
			update_option('mnsjay_zone_layers', $data);
		}

		wp_send_json_success(['message' => 'تنظیمات منطقه‌های قدیمی این روش حمل و نقل با موفقیت حذف شد.']);
	}

	if ($action === 'layer-trans') {

		$data = mnsjay_get_option_zone_layers();

		if (isset($data[$method_key])) {

			$area_id = wp_insert_post(array(
				'comment_status' => 'close',
				'ping_status'    => 'close',
				'post_author'    => get_current_user_id(),
				'post_title'     => sprintf(__('%s area', 'mnsjay'), $methods[$method_key]['title']),
				'post_status'    => 'publish',
				'post_type'      => 'mnsjay-area',
			));

			mnsjay_update_area_layers($area_id, $data[$method_key]);

			unset($data[$method_key]);
			update_option('mnsjay_zone_layers', $data);

			$areas = mnsjay_get_option_shipping_areas();
			$areas[$method_key] = [$area_id];
			update_option('mnsjay_shipping_areas', $areas);
		}

		wp_send_json_success(['message' => 'تنظیمات منطقه‌های قدیمی این روش حمل و نقل با موفقیت به نسخه جدید تبدیل شد. این صفحه را مجددا بارگذاری کنید.']);
	}
});
