<?php

function mnsjay_get_cart_sellers() {

	$items = WC()->cart->get_cart();
	$sellers = array();

	foreach ($items as $item => $values) {

		$_product = wc_get_product($values['data']->get_id());

		if (!$_product)
			continue;

		$seller_id = get_post_field('post_author', $_product->get_id());

		$sellers[$seller_id][] = $_product->get_id();
	}

	return $sellers;
}

function mnsjay_is_cart_single_seller() {

	$sellers = mnsjay_get_cart_sellers();

	return count($sellers) == 1;
}

function mnsjay_is_cart_shipping_by_seller() {

	if (!mnsjay_is_cart_single_seller())
		return false;

	$sellers = mnsjay_get_cart_sellers();

	foreach ($sellers as $seller_id => $items) {

		return dokan_is_user_seller($seller_id);
	}
}

function mnsjay_seller_shipping_method() {

	class MNSJAY_Variable_Seller_Shipping_Method extends WC_Shipping_Method {
		/**
		 * Constructor for your shipping class
		 *
		 * @access public
		 * @return void
		 */
		public function __construct($instance_id = 0) {

			$this->supports = [
				'shipping-zones',
				'instance-settings',
				'instance-settings-modal',
			];

			$this->id                 = 'mnsjay_shipping_seller';
			$this->instance_id        = absint($instance_id);
			$this->method_title       = __('Seller Shipping', 'mnsjay');
			$this->method_description = __('Delivery seller shipping method (Jaayegah)', 'mnsjay');

			$this->init();
		}

		/**
		 * Init your settings
		 *
		 * @access public
		 * @return void
		 */
		function init() {

			// Load the settings API
			$this->init_form_fields();

			$this->init_settings();

			$this->title = $this->get_option('title', $this->method_title);
			$this->cart_total  = isset(WC()->cart) ? WC()->cart->get_cart_contents_total() : 0;
			$this->cart_weight = isset(WC()->cart) ? wc_get_weight(WC()->cart->get_cart_contents_weight(), 'g') : 0;

			// Save settings in admin if you have any defined
			add_action('woocommerce_update_options_shipping_' . $this->id, array($this, 'process_admin_options'));
		}

		public function init_form_fields() {

			$this->instance_form_fields = [
				'title' => array(
					'title' => __('Title', 'mnsjay'),
					'type' => 'text',
					'description' => __('Title to be display on site', 'mnsjay'),
					'default' => $this->title,
					'desc_tip'    => true,
				),
			];
		}

		public function is_available($package): bool {

			if (mnsjay_get_option_dokan_seller_shipping() != 'yes')
				return false;

			if (!mnsjay_is_cart_shipping_by_seller())
				return false;

			$sellers = mnsjay_get_cart_sellers();

			foreach ($sellers as $seller_id => $items) {
				$seller_id = $seller_id;
			}

			if (get_user_meta($seller_id, 'dokan_enable_selling', true) != 'yes')
				return false;

			$dokan_settings = dokan_get_store_info($seller_id);

			if (!isset($dokan_settings['mnsjay_shipping_active']) or $dokan_settings['mnsjay_shipping_active'] != 'yes')
				return false;

			$available = $this->is_enabled();

			if (empty($package)) {
				$available = false;
			}

			if ($package['destination']['country'] != 'IR') {
				$available = false;
			}

			$ship_to = mnsjay_get_ship_to_address_type();
			$location = mnsjay_get_current_location($ship_to);
			$city = mnsjay_get_current_city($ship_to);
			$state = mnsjay_get_current_state($ship_to);

			$shipping_active = isset($dokan_settings['mnsjay_shipping_active']) ? $dokan_settings['mnsjay_shipping_active'] : false;
			$shipping_title = isset($dokan_settings['mnsjay_shipping_title']) ? $dokan_settings['mnsjay_shipping_title'] : '';
			$shipping_base_cost = isset($dokan_settings['mnsjay_shipping_base_cost']) ? $dokan_settings['mnsjay_shipping_base_cost'] : '0';
			$shipping_distance_range = isset($dokan_settings['mnsjay_shipping_distance_range']) ? $dokan_settings['mnsjay_shipping_distance_range'] : array('from' => '0', 'to' => '0');
			$shipping_weight_range = isset($dokan_settings['mnsjay_shipping_weight_range']) ? $dokan_settings['mnsjay_shipping_weight_range'] : array('from' => '0', 'to' => '0');
			$shipping_distance_bases = isset($dokan_settings['mnsjay_shipping_distance_bases']) ? $dokan_settings['mnsjay_shipping_distance_bases'] : '0';
			$shipping_weight_bases = isset($dokan_settings['mnsjay_shipping_weight_bases']) ? $dokan_settings['mnsjay_shipping_weight_bases'] : '0';

			$origin_location = isset($dokan_settings['mnsjay_location']) ? $dokan_settings['mnsjay_location'] : mnsjay_get_default_location();
			$distance = mnsjay_do_get_distance_haversine($origin_location, $location);
			$cart_weight = $this->cart_weight;

			if ($shipping_distance_range['from'] != 0 and $distance < $shipping_distance_range['from'])
				return false;

			if ($shipping_distance_range['to'] != 0 and $distance > $shipping_distance_range['to'])
				return false;

			if ($shipping_weight_range['from'] != 0 and $cart_weight < $shipping_weight_range['from'])
				return false;

			if ($shipping_weight_range['to'] != 0 and $cart_weight > $shipping_weight_range['to'])
				return false;

			/*if ( !mnsjay_shipping_is_in_zone($this->id, $state, $city) ) {
				$available = false;
			}*/

			return apply_filters('woocommerce_shipping_' . $this->id . '_is_available', $available, $package, $this);
		}

		/**
		 * This function is used to calculate the shipping cost. Within this function we can check for weights, dimensions and other parameters.
		 *
		 * @access public
		 * @param mixed $package
		 * @return void
		 */
		public function calculate_shipping($package = array()) {

			$ship_to = mnsjay_get_ship_to_address_type();
			$location = mnsjay_get_current_location($ship_to);
			$sellers = mnsjay_get_cart_sellers();

			foreach ($sellers as $seller_id => $items) {
				$seller_id = $seller_id;
			}

			$dokan_settings = dokan_get_store_info($seller_id);
			$shipping_title = isset($dokan_settings['mnsjay_shipping_title']) ? $dokan_settings['mnsjay_shipping_title'] : $this->title;
			$shipping_base_cost = isset($dokan_settings['mnsjay_shipping_base_cost']) ? $dokan_settings['mnsjay_shipping_base_cost'] : '0';
			$shipping_distance_bases = isset($dokan_settings['mnsjay_shipping_distance_bases']) ? $dokan_settings['mnsjay_shipping_distance_bases'] : '0';
			$shipping_weight_bases = isset($dokan_settings['mnsjay_shipping_weight_bases']) ? $dokan_settings['mnsjay_shipping_weight_bases'] : '0';
			$origin_location = isset($dokan_settings['mnsjay_location']) ? $dokan_settings['mnsjay_location'] : mnsjay_get_default_location();

			$distance = mnsjay_do_get_distance_haversine($origin_location, $location);
			$cart_weight = $this->cart_weight;

			$cost = $shipping_base_cost + ($shipping_distance_bases * $distance);
			$cost = $cost + ($shipping_weight_bases * $cart_weight);

			$rate = array(
				'id' => $this->id,
				'label' => $shipping_title . ' ' . sprintf(__('(%s Kilometers)', 'mnsjay'), $distance),
				'cost' => $cost
			);

			$this->add_rate($rate);
		}
	}
}
add_action('woocommerce_shipping_init', 'mnsjay_seller_shipping_method');

function mnsjay_add_seller_shipping_methods($methods) {

	$methods['mnsjay_shipping_seller'] = 'MNSJAY_Variable_Seller_Shipping_Method';
	return $methods;
}
add_filter('woocommerce_shipping_methods', 'mnsjay_add_seller_shipping_methods', 10);

add_action('dokan_order_detail_after_order_items', function ($order) {

	$checkout = 'shipping';
	$location = mnsjay_get_order_location($order->get_id(), $checkout);

	if (!$location) {
		$checkout = 'billing';
		$location = mnsjay_get_order_location($order->get_id(), $checkout);
	}

	if ($location) {
		echo '<a class="mnsjay-routing-button" href="' . mnsjay_create_order_location_url($post->ID, $checkout) . '" target="_blank">' . __('View and share location', 'mnsjay') . '</a>';
	}
});

// Add extra field in seller settings
add_filter('dokan_settings_form_bottom', 'mnsjay_dokan_store_loaction_field', 10, 2);

function mnsjay_dokan_store_loaction_field($current_user, $profile_info) {

	if (mnsjay_get_option_dokan_seller_shipping() != 'yes')
		return;

	mnsjay_enqueue_map_assets();

	wp_enqueue_style('mnsjay-common', mnsjay_asset_url('common.css'), array(), mnsjay_asset_version('common.css'));
	wp_enqueue_script('mnsjay-common', mnsjay_asset_url('common.js'), array('jquery', 'wp-hooks', 'wp-i18n'), mnsjay_asset_version('common.js'), false);

	$location = isset($profile_info['mnsjay_location']) ? $profile_info['mnsjay_location'] : mnsjay_get_default_location();
	$shipping_active = isset($profile_info['mnsjay_shipping_active']) ? $profile_info['mnsjay_shipping_active'] : false;
	$shipping_title = isset($profile_info['mnsjay_shipping_title']) ? $profile_info['mnsjay_shipping_title'] : '';
	$shipping_base_cost = isset($profile_info['mnsjay_shipping_base_cost']) ? $profile_info['mnsjay_shipping_base_cost'] : '0';
	$shipping_distance_range = isset($profile_info['mnsjay_shipping_distance_range']) ? $profile_info['mnsjay_shipping_distance_range'] : array('from' => '0', 'to' => '0');
	$shipping_weight_range = isset($profile_info['mnsjay_shipping_weight_range']) ? $profile_info['mnsjay_shipping_weight_range'] : array('from' => '0', 'to' => '0');
	$shipping_distance_bases = isset($profile_info['mnsjay_shipping_distance_bases']) ? $profile_info['mnsjay_shipping_distance_bases'] : '0';
	$shipping_weight_bases = isset($profile_info['mnsjay_shipping_weight_bases']) ? $profile_info['mnsjay_shipping_weight_bases'] : '0';

?>

	<div class="dokan-form-group">

		<label class="dokan-w3 dokan-control-label">
			<?php _e('Shipping Options', 'mnsjay'); ?>
		</label>

		<div class="mnsjay-dokan-panel-fields dokan-w9 dokan-text-left">

			<div class="dokan-form-group">
				<div class="checkbox">
					<label for="mnsjay_shipping_active" class="control-label">
						<input type="checkbox" name="mnsjay_shipping_active" id="mnsjay_shipping_active" value="yes" <?php checked('yes', $shipping_active); ?>>
						<?php _e('Active your own shipping method', 'mnsjay'); ?>
					</label>
				</div>
			</div>

			<div class="dokan-form-group">
				<label class="dokan-w12 control-label">
					<?php _e('Your Store Location', 'mnsjay'); ?>
				</label>
				<div class="dokan-w12">
					<?php mnsjay_template_admin_map('mnsjay_order_location_vendor', 'mnsjay_location', array(
						'central_marker' => true,
						'display_lat_lng' => true,
						'display_search' => mnsjay_get_option_map_display_search(),
						'gesture_handling' => true,
						'device_location' => true,
						'fullscreen' => true,
						'traffic' => mnsjay_get_option_map_display_traffic(),
						'location' => $location,
						'overlay_text' => __('Click to edit', 'mnsjay')
					)); ?>
				</div>
			</div>

			<div class="dokan-form-group">
				<label class="dokan-w12 control-label" for="mnsjay_shipping_title">
					<?php _e('Shipping Title', 'mnsjay'); ?>:
				</label>
				<input name="mnsjay_shipping_title" id="mnsjay_shipping_title" class="dokan-form-control input-md" value="<?php echo $shipping_title; ?>">
			</div>

			<div class="dokan-form-group">
				<label class="dokan-w12 control-label" for="mnsjay_shipping_base_cost">
					<?php _e('Base Cost', 'mnsjay'); ?> (<?php echo get_woocommerce_currency_symbol(); ?>):
				</label>
				<input name="mnsjay_shipping_base_cost" type="number" id="mnsjay_shipping_base_cost" class="dokan-form-control input-md" value="<?php echo $shipping_base_cost; ?>">
			</div>

			<div class="dokan-form-group">
				<label class="dokan-w12 control-label">
					<?php _e('Allowable distance range:', 'mnsjay'); ?>
				</label>
				<input name="mnsjay_shipping_distance_range[from]" type="number" class="dokan-form-control input-md" value="<?php echo $shipping_distance_range['from']; ?>" style="width: 80px; display: inline-block;">
				<?php _e('to', 'mnsjay'); ?>
				<input name="mnsjay_shipping_distance_range[to]" type="number" class="dokan-form-control input-md" value="<?php echo $shipping_distance_range['to']; ?>" style="width: 80px; display: inline-block;">
				<?php _e('Kilometers', 'mnsjay'); ?>
			</div>

			<div class="dokan-form-group">
				<label class="dokan-w12 control-label">
					<?php _e('Allowable weight range:', 'mnsjay'); ?>
				</label>
				<input name="mnsjay_shipping_weight_range[from]" type="number" class="dokan-form-control input-md" value="<?php echo $shipping_weight_range['from']; ?>" style="width: 80px; display: inline-block;">
				<?php _e('to', 'mnsjay'); ?>
				<input name="mnsjay_shipping_weight_range[to]" type="number" class="dokan-form-control input-md" value="<?php echo $shipping_weight_range['to']; ?>" style="width: 80px; display: inline-block;">
				<?php _e('Grams', 'mnsjay'); ?>
			</div>

			<div class="dokan-form-group">
				<label class="dokan-w12 control-label" for="mnsjay_shipping_distance_bases">
					<?php _e('Extra cost per kilometer', 'mnsjay'); ?> (<?php echo get_woocommerce_currency_symbol(); ?>):
				</label>
				<input name="mnsjay_shipping_distance_bases" type="number" id="mnsjay_shipping_distance_bases" class="dokan-form-control input-md" value="<?php echo $shipping_distance_bases; ?>">
			</div>

			<div class="dokan-form-group">
				<label class="dokan-w12 control-label" for="mnsjay_shipping_weight_bases">
					<?php _e('Extra cost per gram', 'mnsjay'); ?> (<?php echo get_woocommerce_currency_symbol(); ?>):
				</label>
				<input name="mnsjay_shipping_weight_bases" type="number" id="mnsjay_shipping_weight_bases" class="dokan-form-control input-md" value="<?php echo $shipping_weight_bases; ?>">
			</div>

		</div>
	</div>
<?php
}

//save the field value
add_action('dokan_store_profile_saved', 'mnsjay_dokan_store_loaction_save', 15);

function mnsjay_dokan_store_loaction_save($store_id) {

	$dokan_settings = dokan_get_store_info($store_id);

	if (isset($_POST['mnsjay_shipping_active'])) {
		$dokan_settings['mnsjay_shipping_active'] = 'yes';
	} else {
		$dokan_settings['mnsjay_shipping_active'] = false;
	}

	if (isset($_POST['mnsjay_location'])) {
		$dokan_settings['mnsjay_location'] = sanitize_text_field($_POST['mnsjay_location']);
	}

	if (isset($_POST['mnsjay_shipping_title'])) {
		$dokan_settings['mnsjay_shipping_title'] = sanitize_text_field($_POST['mnsjay_shipping_title']);
	}

	if (isset($_POST['mnsjay_shipping_base_cost'])) {
		$dokan_settings['mnsjay_shipping_base_cost'] = sanitize_text_field($_POST['mnsjay_shipping_base_cost']);
	}

	if (isset($_POST['mnsjay_shipping_distance_range'])) {
		$dokan_settings['mnsjay_shipping_distance_range'] = $_POST['mnsjay_shipping_distance_range'];
	}

	if (isset($_POST['mnsjay_shipping_weight_range'])) {
		$dokan_settings['mnsjay_shipping_weight_range'] = $_POST['mnsjay_shipping_weight_range'];
	}

	if (isset($_POST['mnsjay_shipping_distance_bases'])) {
		$dokan_settings['mnsjay_shipping_distance_bases'] = sanitize_text_field($_POST['mnsjay_shipping_distance_bases']);
	}

	if (isset($_POST['mnsjay_shipping_weight_bases'])) {
		$dokan_settings['mnsjay_shipping_weight_bases'] = sanitize_text_field($_POST['mnsjay_shipping_weight_bases']);
	}

	update_user_meta($store_id, 'dokan_profile_settings', $dokan_settings);
}
