<?php

if (!defined('ABSPATH')) {
	exit;
}

function mnsjay_area_map_meta_box() {

	add_meta_box(
		'mnsjay_area_map',
		__('Area Map', 'mnsjay'),
		'mnsjay_area_map_meta_box_output',
		'mnsjay-area',
		'normal',
		'default'
	);
}
add_action('add_meta_boxes', 'mnsjay_area_map_meta_box');

function mnsjay_get_area_layers($area_id) {

	$layers = get_post_meta($area_id, '_mnsjay_area_layers', true);
	$layers = $layers ? $layers : '[]';

	return $layers;
}

function mnsjay_update_area_layers($area_id, $layers) {

	update_post_meta($area_id, '_mnsjay_area_layers', $layers);
}

function mnsjay_area_map_meta_box_output($area) {

	$layers = mnsjay_get_area_layers($area->ID);

?>

	<div class="mnsjay mnsjay-area-meta-box">

		<div class="mnsjay-search-area" style="display: none;">
			<div class="mnsjay-column">
				<label for="mnsjay_search_area_country"><?php _e('Country', 'mnsjay'); ?>:</label>
				<div>
					<input type="text" class="mnsjay-input" id="mnsjay_search_area_country" value="">
				</div>
			</div>
			<div class="mnsjay-column">
				<label for="mnsjay_search_area_province"><?php _e('Province', 'mnsjay'); ?>:</label>
				<div>
					<input type="text" class="mnsjay-input" id="mnsjay_search_area_province" value="">
				</div>
			</div>
			<div class="mnsjay-column">
				<label for="mnsjay_search_area_county"><?php _e('County', 'mnsjay'); ?>:</label>
				<div>
					<input type="text" class="mnsjay-input" id="mnsjay_search_area_county" value="">
				</div>
			</div>
			<div class="mnsjay-column">
				<label for="mnsjay_search_area_city"><?php _e('City / District', 'mnsjay'); ?>:</label>
				<div>
					<input type="text" class="mnsjay-input" id="mnsjay_search_area_city" value="">
				</div>
			</div>
			<div class="mnsjay-column">
				<div class="mnsjay-buttons">
					<span class="spinner"></span>
					<a href="#search" class="button"><?php _e('Search for areas', 'mnsjay'); ?></a>
				</div>
				<div class="mnsjay-item" style="display: none;">
					<div class="mnsjay-title"></div>
					<div class="mnsjay-action"><?php echo mnsjay_icon('check', 'mnsjay-apply'); ?></div>
				</div>
				<div class="mnsjay-results" style="display: none;"></div>
			</div>
		</div>

		<?php mnsjay_template_map([
			'id' => 'mnsjay-area-map',
			'holder_type' => 'simple-clickable',
			'central_marker' => false,
			'display_lat_lng' => false,
			'display_search' => true,
			'gesture_handling' => false,
			'device_location' => true,
			'fullscreen' => true,
			'overlay_text' => __('Click to draw area', 'mnsjay'),
			'location' => mnsjay_get_default_location(),
			'layers' => $layers,
			'inputs' => [
				'_mnsjay_area_layers' => [
					'class' => 'mnsjay-layers',
					'name' => '_mnsjay_area_layers',
					'value' => $layers
				]
			]
		]); ?>

	</div>

<?php
}

function mnsjay_area_map_meta_box_save($area_id) {

	if (defined('DOING_AUTOSAVE') and DOING_AUTOSAVE)
		return;

	if (!current_user_can('edit_post', $area_id))
		return;

	if (get_post_type($area_id) !== 'mnsjay-area')
		return;

	if (!empty($_POST['_mnsjay_area_layers'])) {
		mnsjay_update_area_layers($area_id, sanitize_text_field($_POST['_mnsjay_area_layers']));
	}
}
add_action('save_post', 'mnsjay_area_map_meta_box_save');
