<?php

if (!defined('ABSPATH')) {
	exit;
}

function mnsjay_locations_map_meta_box() {

	add_meta_box(
		'mnsjay_locations_map',
		__('Location Map', 'mnsjay'),
		'mnsjay_locations_map_meta_box_output',
		array('mnsjay-location'),
		'normal',
		'default'
	);
}
add_action('add_meta_boxes', 'mnsjay_locations_map_meta_box');

function mnsjay_get_location_coords($location_id) {

	$coords = get_post_meta($location_id, '_mnsjay_location_coords', true);
	$coords = $coords ? $coords : mnsjay_get_default_location();

	return $coords;
}

function mnsjay_get_location_country($location_id) {

	$country = get_post_meta($location_id, '_mnsjay_location_country', true);

	return $country;
}

function mnsjay_get_location_province($location_id) {

	$province = get_post_meta($location_id, '_mnsjay_location_province', true);

	return $province;
}

function mnsjay_get_location_city($location_id) {

	$city = get_post_meta($location_id, '_mnsjay_location_city', true);

	return $city;
}

function mnsjay_get_location_address($location_id) {

	$address = get_post_meta($location_id, '_mnsjay_location_address', true);

	return $address;
}

function mnsjay_get_location_region($location_id) {

	$region = get_post_meta($location_id, '_mnsjay_location_region', true);

	return $region;
}

function mnsjay_update_location_coords($location_id, $coords) {

	update_post_meta($location_id, '_mnsjay_location_coords', trim($coords));
}

function mnsjay_update_location_country($location_id, $country) {

	update_post_meta($location_id, '_mnsjay_location_country', trim($country));
}

function mnsjay_update_location_province($location_id, $province) {

	update_post_meta($location_id, '_mnsjay_location_province', trim($province));
}

function mnsjay_update_location_city($location_id, $city) {

	update_post_meta($location_id, '_mnsjay_location_city', trim($city));
}

function mnsjay_update_location_address($location_id, $address) {

	update_post_meta($location_id, '_mnsjay_location_address', trim($address));
}

function mnsjay_update_location_region($location_id, $region) {

	update_post_meta($location_id, '_mnsjay_location_region', trim($region));
}

function mnsjay_locations_map_meta_box_output($location) {

	$coords = mnsjay_get_location_coords($location->ID);
	$country = mnsjay_get_location_country($location->ID);
	$province = mnsjay_get_location_province($location->ID);
	$city = mnsjay_get_location_city($location->ID);
	$address = mnsjay_get_location_address($location->ID);
	$region = mnsjay_get_location_region($location->ID);

?>

	<div class="mnsjay mnsjay-locations-meta-box">

		<div class="mnsjay-location-address mnsjay-location-inputs">
			<div>
				<label class="mnsjay-label" for="_mnsjay_location_country"><?php _e('Location Country:', 'mnsjay'); ?></label><br>
				<input type="text" id="_mnsjay_location_country" name="_mnsjay_location_country" value="<?php echo $country; ?>">
			</div>
			<div>
				<label class="mnsjay-label" for="_mnsjay_location_province"><?php _e('Location Province:', 'mnsjay'); ?></label><br>
				<input type="text" id="_mnsjay_location_province" name="_mnsjay_location_province" value="<?php echo $province; ?>">
			</div>
			<div>
				<label class="mnsjay-label" for="_mnsjay_location_city"><?php _e('Location City:', 'mnsjay'); ?></label><br>
				<input type="text" id="_mnsjay_location_city" name="_mnsjay_location_city" value="<?php echo $city; ?>">
			</div>
			<div>
				<label class="mnsjay-label" for="_mnsjay_location_region"><?php _e('Region related to this location:', 'mnsjay'); ?></label><br>
				<?php mnsjay_regions_dropdown('_mnsjay_location_region', '_mnsjay_location_region', $region, false); ?>
			</div>
			<div>
				<label class="mnsjay-label" for="_mnsjay_location_address"><?php _e('Location Address:', 'mnsjay'); ?></label><br>
				<input type="text" id="_mnsjay_location_address" name="_mnsjay_location_address" value="<?php echo $address; ?>">
			</div>
		</div>

		<div class="mnsjay-location-address mnsjay-location-results" style="display: none;">
			<div class="mnsjay-import"><?php echo mnsjay_icon('check'); ?></div>
			<div>
				<span class="mnsjay-label"><?php _e('Location Country:', 'mnsjay'); ?></span>
				<span class="mnsjay-value" id="mnsjay_location_country_result"></span>
			</div>
			<div>
				<span class="mnsjay-label"><?php _e('Location Province:', 'mnsjay'); ?></span>
				<span class="mnsjay-value" id="mnsjay_location_province_result"></span>
			</div>
			<div>
				<span class="mnsjay-label"><?php _e('Location City:', 'mnsjay'); ?></span>
				<span class="mnsjay-value" id="mnsjay_location_city_result"></span>
			</div>
			<div>
				<span class="mnsjay-label"><?php _e('Location Address:', 'mnsjay'); ?></span>
				<span class="mnsjay-value" id="mnsjay_location_address_result"></span>
			</div>
		</div>

		<?php mnsjay_template_map([
			'id' => 'mnsjay-location-map',
			'holder_type' => 'simple-clickable',
			'central_marker' => true,
			'display_lat_lng' => true,
			'display_search' => true,
			'gesture_handling' => true,
			'device_location' => true,
			'fullscreen' => true,
			'overlay_text' => __('Change Location', 'mnsjay'),
			'location' => $coords,
			'buttons' => [
				'mnsjay_return' => [
					'class' => ['button', 'mnsjay-return'],
					'href' => '#return',
					'title' => __('Return', 'mnsjay'),
				],
				'mnsjay_location_submit' => [
					'class' => ['button', 'mnsjay-submit', 'mnsjay-location-submit'],
					'href' => '#submit',
					'title' => __('Submit', 'mnsjay'),
				]
			],
			'inputs' => [
				'_mnsjay_location_coords' => [
					'class' => 'mnsjay-location',
					'name' => '_mnsjay_location_coords',
					'value' => $coords
				]
			]
		]); ?>

	</div>

<?php
}

function mnsjay_locations_map_meta_box_save($location_id) {

	if (defined('DOING_AUTOSAVE') and DOING_AUTOSAVE)
		return;

	if (!current_user_can('edit_post', $location_id))
		return;

	if (get_post_type($location_id) !== 'mnsjay-location')
		return;

	if (!empty($_POST['_mnsjay_location_coords'])) {
		mnsjay_update_location_coords($location_id, sanitize_text_field($_POST['_mnsjay_location_coords']));
	}

	if (!empty($_POST['_mnsjay_location_country'])) {
		mnsjay_update_location_country($location_id, sanitize_text_field($_POST['_mnsjay_location_country']));
	}

	if (!empty($_POST['_mnsjay_location_province'])) {
		mnsjay_update_location_province($location_id, sanitize_text_field($_POST['_mnsjay_location_province']));
	}

	if (!empty($_POST['_mnsjay_location_city'])) {
		mnsjay_update_location_city($location_id, sanitize_text_field($_POST['_mnsjay_location_city']));
	}

	if (!empty($_POST['_mnsjay_location_address'])) {
		mnsjay_update_location_address($location_id, sanitize_text_field($_POST['_mnsjay_location_address']));
	}

	if (!empty($_POST['_mnsjay_location_region'])) {
		mnsjay_update_location_region($location_id, sanitize_text_field($_POST['_mnsjay_location_region']));
	}
}
add_action('save_post', 'mnsjay_locations_map_meta_box_save');
