<?php

if (!defined('ABSPATH')) {
	exit;
}

function mnsjay_map_items_meta_box() {

	add_meta_box(
		'mnsjay_map_items',
		__('Map Items', 'mnsjay'),
		'mnsjay_map_items_meta_box_output',
		['mnsjay-map'],
		'normal',
		'default'
	);
}
add_action('add_meta_boxes', 'mnsjay_map_items_meta_box');

function mnsjay_get_map_locations($map_id) {

	$locations = get_post_meta($map_id, '_mnsjay_map_locations', true);
	$locations = is_array($locations) ? $locations : [];

	return $locations;
}

function mnsjay_get_map_areas($map_id) {

	$areas = get_post_meta($map_id, '_mnsjay_map_areas', true);
	$areas = is_array($areas) ? $areas : [];

	return $areas;
}

function mnsjay_get_map_items_counter($map_id) {

	$counter = get_post_meta($map_id, 'mnsjay_map_items_counter', true);
	$counter = is_numeric($counter) ? $counter : '1';

	return $counter;
}

function mnsjay_update_map_locations($map_id, $locations) {

	update_post_meta($map_id, '_mnsjay_map_locations', $locations);
}

function mnsjay_update_map_areas($map_id, $areas) {

	update_post_meta($map_id, '_mnsjay_map_areas', $areas);
}

function mnsjay_update_map_items_counter($map_id, $count) {

	update_post_meta($map_id, 'mnsjay_map_items_counter', $count);
}

function mnsjay_map_items_meta_box_output($map) {

	$locations = mnsjay_get_locations();
	$areas = mnsjay_get_areas();

	$map_locations = mnsjay_get_map_locations($map->ID);
	$map_areas = mnsjay_get_map_areas($map->ID);

	$locations_data = [];
	$areas_data = [];

	foreach ($locations as $location) {
		$locations_data[$location->ID] = mnsjay_get_location_coords($location->ID);
	}

	foreach ($areas as $area) {
		$areas_data[$area->ID] = mnsjay_get_area_layers($area->ID);
	}

	$locations_field_name = '_mnsjay_map_locations{PLACEHOLDER}[{KEY}][%s]';
	$locations_field_id = 'mnsjay_map_locations_{KEY}_%s';

	$areas_field_name = '_mnsjay_map_areas{PLACEHOLDER}[{KEY}][%s]';
	$areas_field_id = 'mnsjay_map_areas_{KEY}_%s';

?>

	<div class="mnsjay mnsjay-maps-meta-box mnsjay-addable-area">

		<input type="hidden" class="mnsjay-counter" name="mnsjay_map_items_counter" value="<?php echo mnsjay_get_map_items_counter($map->ID); ?>">

		<div class="mnsjay-addable-container mnsjay-moveable-container mnsjay-map-locations-container" data-path="">
			<div class="mnsjay-header">
				<div style="font-weight: 700;"><?php _e('Locations', 'mnsjay'); ?></div>
			</div>
			<div class="mnsjay-buttons">
				<select class="mnsjay-add-select" data-path="">
					<option value="0"><?php _e('+ Add new location', 'mnsjay'); ?></option>
					<?php foreach ($locations as $location) {
						echo '<option value="' . $location->ID . '">' . get_the_title($location) . '</option>';
					} ?>
				</select>
			</div>
			<div class="mnsjay-addables mnsjay-moveables mnsjay-weight-addables" data-path=""></div>
			<div class="mnsjay-new" style="display: none;">
				<div class="mnsjay-addable mnsjay-moveable" style="display: none;">
					<div class="mnsjay-column mnsjay-center-y">
						<div>
							{LOCATION_NAME}
						</div>
						<input type="hidden" id="<?php echo sprintf($locations_field_id, 'id'); ?>" name="<?php echo sprintf($locations_field_name, 'id'); ?>" value="">
					</div>
					<div class="mnsjay-column">
						<div>
							<label for="<?php echo sprintf($locations_field_id, 'description'); ?>"><?php _e('Description', 'mnsjay'); ?>:</label>
							<textarea class="large-text" name="<?php echo sprintf($locations_field_name, 'description'); ?>" id="<?php echo sprintf($locations_field_id, 'description'); ?>"></textarea>
						</div>
					</div>
					<div class="mnsjay-column mnsjay-actions">
						<?php
						echo mnsjay_icon('xmark', 'mnsjay-remove');
						echo mnsjay_icon('arrow_up', 'mnsjay-move-up');
						echo mnsjay_icon('arrow_down', 'mnsjay-move-down');
						?>
					</div>
				</div>
			</div>
			<input type="hidden" class="mnsjay-data" value='<?php echo wp_json_encode($map_locations); ?>'>
		</div>

		<div class="mnsjay-addable-container mnsjay-moveable-container mnsjay-map-areas-container" data-path="">
			<div class="mnsjay-header">
				<div style="font-weight: 700;"><?php _e('Areas', 'mnsjay'); ?></div>
			</div>
			<div class="mnsjay-buttons">
				<select class="mnsjay-add-select" data-path="">
					<option value="0"><?php _e('+ Add new area', 'mnsjay'); ?></option>
					<?php foreach ($areas as $area) {
						echo '<option value="' . $area->ID . '">' . get_the_title($area) . '</option>';
					} ?>
				</select>
			</div>
			<div class="mnsjay-addables mnsjay-moveables mnsjay-weight-addables" data-path=""></div>
			<div class="mnsjay-new" style="display: none;">
				<div class="mnsjay-addable mnsjay-moveable" style="display: none;">
					<div class="mnsjay-column mnsjay-center-y">
						<div>
							{AREA_NAME}
						</div>
						<input type="hidden" id="<?php echo sprintf($areas_field_id, 'id'); ?>" name="<?php echo sprintf($areas_field_name, 'id'); ?>" value="">
					</div>
					<div class="mnsjay-column">
						<div>
							<label for="<?php echo sprintf($areas_field_id, 'description'); ?>"><?php _e('Description', 'mnsjay'); ?>:</label>
							<textarea class="large-text" name="<?php echo sprintf($areas_field_name, 'description'); ?>" id="<?php echo sprintf($areas_field_id, 'description'); ?>"></textarea>
						</div>
					</div>
					<div class="mnsjay-column mnsjay-actions">
						<?php
						echo mnsjay_icon('xmark', 'mnsjay-remove');
						echo mnsjay_icon('arrow_up', 'mnsjay-move-up');
						echo mnsjay_icon('arrow_down', 'mnsjay-move-down');
						?>
					</div>
				</div>
			</div>
			<input type="hidden" class="mnsjay-data" value='<?php echo wp_json_encode($map_areas); ?>'>
		</div>

	</div>

	<?php /*mnsjay_template_map([
		'id' => 'mnsjay-map-metabox',
		'classes' => ['mnsjay-map-metabox'],
		'holder_type' => 'simple-clickable',
		'display_lat_lng' => false,
		'display_search' => false,
		'gesture_handling' => false,
		'device_location' => false,
		'fullscreen' => true,
		'overlay_text' => __('Customize', 'mnsjay'),
		'locations_data' => $locations_data,
		'areas_data' => $areas_data,
		'map_locations' => $map_locations,
		'map_areas' => $map_areas
	]);*/ ?>

<?php
}

function mnsjay_map_items_meta_box_save($map_id) {

	if (defined('DOING_AUTOSAVE') and DOING_AUTOSAVE)
		return;

	if (!current_user_can('edit_post', $map_id))
		return;

	if (get_post_type($map_id) !== 'mnsjay-map')
		return;

	if (!empty($_POST['_mnsjay_map_locations'])) {
		mnsjay_update_map_locations($map_id, $_POST['_mnsjay_map_locations']);
	} else {
		mnsjay_update_map_locations($map_id, []);
	}

	if (!empty($_POST['_mnsjay_map_areas'])) {
		mnsjay_update_map_areas($map_id, $_POST['_mnsjay_map_areas']);
	} else {
		mnsjay_update_map_areas($map_id, []);
	}

	if (!empty($_POST['mnsjay_map_items_counter'])) {
		mnsjay_update_map_items_counter($map_id, $_POST['mnsjay_map_items_counter']);
	}
}
add_action('save_post', 'mnsjay_map_items_meta_box_save');
