<?php

if (!defined('ABSPATH')) {
	exit;
}

function mnsjay_settings_license_output() {

	if (mnsjay_check_activation() and !mnsjay_is_conditional_activation_activated()) {
		$license_token = mnsjay_get_license_key(true);
		$license_token_attr = ' disabled="disabled"';
		$submit_class = 'uninstall';
		$submit_value = __('Uninstall license', 'mnsjay');
		$notice_class = 'notice-success';
		$notice_value = __('License key registered!', 'mnsjay');
	} else {
		$license_token = '';
		$license_token_attr = '';
		$submit_class = 'install';
		$submit_value = __('Install license', 'mnsjay');
		$notice_class = 'notice-warning';
		$notice_value = __('Enter your license key', 'mnsjay');
	}
?>

	<div class="mnsjay-license-container" data-nonce="<?php echo wp_create_nonce('mnsjay_license_nonce'); ?>">
		<div class="mnsjay-license-form">
			<input type="text" id="mnsjay_license_token" class="regular-text code" value="<?php echo $license_token; ?>" placeholder="xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxxxxxx" <?php echo $license_token_attr; ?>>
			<a href="#submit-license" id="mnsjay_license_submit" class="button <?php echo $submit_class; ?>"><?php echo $submit_value; ?></a>
		</div>
		<p class="notice notice-alt <?php echo $notice_class; ?> message"><?php echo $notice_value; ?></p>
		<p class="description"><?php _e('Enter your license key to enable the plugin fully. You can get the license key from your Panel on Zhaket.', 'mnsjay'); ?></p>
	</div>

<?php }

function mnsjay_settings_access_keys_output() {

	$providers = mnsjay_map_providers();

	echo '<div class="mnsjay-tabs-container mnsjay-services-tabs">';
	echo '<div class="mnsjay-tab-items">';
	foreach ($providers as $provider_key => $provider_values) {
		if (!count($provider_values['settings_fields']))
			continue;
		$active_tab = isset($active_tab) ? $active_tab : $provider_key;
		echo '<div class="mnsjay-tab-item mnsjay-' . $provider_key . ($active_tab == $provider_key ? ' current' : '') . '">' . $provider_values['title_en'] . '</div>';
	}
	echo '</div>';
	foreach ($providers as $provider_key => $provider_values) {
		if (!count($provider_values['settings_fields']))
			continue;
		echo '<div class="mnsjay-tab-box" style="display: ' . ($active_tab == $provider_key ? 'block' : 'none') . ';">';
		foreach ($provider_values['settings_fields'] as $setting_key => $setting_values) {
			echo '<p>';
			echo '<label for="' . $setting_values['key'] . '">' . $setting_values['title'] . ':</label><br>';
			echo '<input type="text" class="regular-text code" name="' . $setting_values['key'] . '" id="' . $setting_values['key'] . '" value="' . $setting_values['callback']() . '">';
			echo '</p>';
			echo '<br>';
		}
		echo '<p class="description">' . sprintf($provider_values['settings_description'], esc_url($provider_values['url']), $provider_values['title']) . '</p>';
		echo '</div>';
	}
	echo '</div>';
}

function mnsjay_settings_debug_mode_output() {

	$debug_mode = mnsjay_get_option_debug_mode();
?>

	<label><input type="checkbox" name="mnsjay_debug_mode" id="mnsjay_debug_mode" value="yes" <?php checked($debug_mode, 'yes'); ?>> <?php _e('Active', 'mnsjay'); ?></label>
	<p class="description"><?php _e('Do not enable this option unless a debugging mode is required.', 'mnsjay'); ?></p>

<?php
}

function mnsjay_settings_dequeue_scripts_output() {

	$dequeue_scripts = mnsjay_get_option_dequeue_scripts();
?>

	<textarea name="mnsjay_dequeue_scripts" id="mnsjay_dequeue_scripts" class="regular-text code" placeholder="script-handle"><?php echo $dequeue_scripts; ?></textarea>
	<p class="description"><?php _e('If there is a conflict, enter the handle names of the scripts that caused the conflict. One handle on each line. Do not fill this field until needed.', 'mnsjay'); ?></p>

<?php
}

function mnsjay_settings_services_provider_output() {

	$providers = mnsjay_get_option_map_providers();

?>

	<div class="mnsjay-provider-fields-container">
		<div>
			<label for="mnsjay_map_providers_display"><?php _e('Map Display Provider', 'mnsjay'); ?>:</label><br>
			<select id="mnsjay_map_providers_display" name="mnsjay_map_providers[display]">
				<?php foreach (mnsjay_map_type_providers('display') as $provider_key => $provider_values) {
					echo '<option value="' . $provider_key . '" ' . selected($provider_key, $providers['display'], false) . '>' . $provider_values['title_en'] . '</option>';
				} ?>
			</select>
		</div>
		<div>
			<label for="mnsjay_map_providers_search"><?php _e('Map Search Provider', 'mnsjay'); ?>:</label><br>
			<select id="mnsjay_map_providers_search" name="mnsjay_map_providers[search]">
				<?php foreach (mnsjay_map_type_providers('search') as $provider_key => $provider_values) {
					echo '<option value="' . $provider_key . '" ' . selected($provider_key, $providers['search'], false) . '>' . $provider_values['title_en'] . '</option>';
				} ?>
			</select>
		</div>
		<div>
			<label for="mnsjay_map_providers_navigation"><?php _e('Map Navigation Provider', 'mnsjay'); ?>:</label><br>
			<select id="mnsjay_map_providers_navigation" name="mnsjay_map_providers[navigation]">
				<?php foreach (mnsjay_map_type_providers('navigation') as $provider_key => $provider_values) {
					echo '<option value="' . $provider_key . '" ' . selected($provider_key, $providers['navigation'], false) . '>' . $provider_values['title_en'] . '</option>';
				} ?>
			</select>
		</div>
		<div>
			<label for="mnsjay_map_providers_location"><?php _e('Map Location Provider', 'mnsjay'); ?>:</label><br>
			<select id="mnsjay_map_providers_location" name="mnsjay_map_providers[location]">
				<?php foreach (mnsjay_map_type_providers('location') as $provider_key => $provider_values) {
					echo '<option value="' . $provider_key . '" ' . selected($provider_key, $providers['location'], false) . '>' . $provider_values['title_en'] . '</option>';
				} ?>
			</select>
		</div>
	</div>
	<br>
	<p class="description"><?php _e('Define provider of each map services.', 'mnsjay'); ?></p>

<?php
}

function mnsjay_settings_default_location_output() {

	echo '<p class="description">' . __('Specify map default location that will be loaded on the customer\'s first visit.', 'mnsjay') . '</p>';

	echo '<br>';

	mnsjay_template_map([
		'id' => 'mnsjay-default-location-map',
		'holder_type' => 'simple-clickable',
		'central_marker' => true,
		'display_lat_lng' => true,
		'display_search' => true,
		'gesture_handling' => true,
		'device_location' => true,
		'fullscreen' => true,
		'overlay_text' => __('Click to change default location', 'mnsjay'),
		'location' => mnsjay_get_option_default_location(),
		'buttons' => [
			'mnsjay_return' => [
				'class' => ['button', 'mnsjay-return'],
				'href' => '#return',
				'title' => __('Return', 'mnsjay'),
			]
		],
		'inputs' => [
			'mnsjay_default_location' => [
				'class' => 'mnsjay-location',
				'name' => 'mnsjay_default_location',
				'value' => mnsjay_get_option_default_location()
			]
		]
	]);
}

function mnsjay_settings_map_template_output() {

	$template = mnsjay_get_option_map_template();

	echo '<div class="mnsjay-map-templates-container">';
	foreach (mnsjay_map_type_providers('display') as $provider_key => $provider_values) {
		echo '<div class="mnsjay-map-templates mnsjay-map-templates-' . $provider_key . '">';
		foreach ($provider_values['templates'] as $template_key => $template_name) {
			echo '<label class="map-template">';
			echo '<img src="https://storage.hoomanmns.com/mns-jaayegah/' . $provider_key . '-' . str_replace($provider_key . '/', '', $template_key) . '.png' . '">';
			echo '<input type="radio" name="mnsjay_map_template" value="' . $template_key . '" ' . checked($template, $template_key, false) . '>';
			echo '<span>' . $template_name . '</span>';
			echo '</label>';
		}
		echo '</div>';
	}
	echo '</div>';
}

function mnsjay_settings_customize_map_output() {

	$lat_lng = mnsjay_get_option_map_display_lat_lng();
	$search = mnsjay_get_option_map_display_search();
	$cover_text = mnsjay_get_option_map_cover_text();
	$search_text = mnsjay_get_option_map_search_text();
	$gesture_handling = mnsjay_get_option_map_gesture_handling();
	$traffic = mnsjay_get_option_map_display_traffic();
	$device_location = mnsjay_get_option_map_device_location();
	$holder_type = mnsjay_get_option_map_holder_type();
	$submit_type = mnsjay_get_option_map_submit_type();

	$holder_types = array(
		'simple-autoload' => __('Simple (Auto load)', 'mnsjay'),
		'simple-clickable' => __('Simple (Loads with click)', 'mnsjay'),
		'popup-small' => __('Pop-Up (Small)', 'mnsjay'),
		'popup-full' => __('Pop-Up (Full)', 'mnsjay'),
	);

?>

	<p>
		<label><input type="checkbox" name="mnsjay_map_display_lat_lng" value="yes" <?php checked($lat_lng, 'yes'); ?>> <?php _e('Display latitude and longitude', 'mnsjay'); ?></label>
	</p>
	<p>
		<label><input type="checkbox" name="mnsjay_map_display_search" value="yes" <?php checked($search, 'yes'); ?>> <?php _e('Display location serach', 'mnsjay'); ?></label>
	</p>
	<p>
		<label><input type="checkbox" name="mnsjay_map_gesture_handling" value="1" <?php checked($gesture_handling, 'yes'); ?>> <?php _e('Lock zoom with single scroll and move with single finger', 'mnsjay'); ?></label>
	</p>
	<p>
		<label><input type="checkbox" name="mnsjay_map_display_traffic" value="yes" <?php checked($traffic, 'yes'); ?>> <?php _e('Display traffic (Only on Neshan template)', 'mnsjay'); ?></label>
	</p>
	<p>
		<label><input type="checkbox" name="mnsjay_map_device_location" value="yes" <?php checked($device_location, 'yes'); ?>> <?php _e('Display get device location button', 'mnsjay'); ?></label>
	</p>
	<br>
	<p>
		<label for="mnsjay_map_search_text"><?php _e('Map Search Text', 'mnsjay'); ?>:</label><br>
		<input type="text" class="regular-text" name="mnsjay_map_search_text" id="mnsjay_map_search_text" value="<?php echo $search_text; ?>">
	</p>
	<br>
	<p>
		<label for="mnsjay_map_cover_text"><?php _e('Map Cover Text', 'mnsjay'); ?>:</label><br>
		<input type="text" class="regular-text" name="mnsjay_map_cover_text" id="mnsjay_map_cover_text" value="<?php echo $cover_text; ?>">
	</p>
	<br>
	<p>
		<label for="mnsjay_map_holder_type"><?php _e('Map Display Type', 'mnsjay'); ?>:</label><br>
		<select id="mnsjay_map_holder_type" name="mnsjay_map_holder_type">
			<?php foreach ($holder_types as $holder_type_key => $holder_type_name) {
				echo '<option value="' . $holder_type_key . '" ' . selected($holder_type_key, $holder_type, false) . '>' . $holder_type_name . '</option>';
			} ?>
		</select>
	</p>
	<br>
	<p>
		<label for="mnsjay_map_submit_type"><?php _e('Location Submit Type', 'mnsjay'); ?>:</label><br>
		<select id="mnsjay_map_submit_type" name="mnsjay_map_submit_type">
			<option value="click" <?php selected('click', $submit_type); ?>><?php _e('Submit by click on button', 'mnsjay'); ?></option>
			<option value="move" <?php selected('move', $submit_type); ?>><?php _e('Submit by draging on map', 'mnsjay'); ?></option>
		</select>
	</p>

<?php
}

function mnsjay_settings_logistic_provider_output() {

	$providers_settings = mnsjay_get_option_logistic_providers();
	$providers = array_filter(mnsjay_logistic_providers(), function ($provider) {
		return !empty($provider['settings']);
	});

	$active_tab = array_key_first($providers);

	echo '<div class="mnsjay-tabs-container mnsjay-services-tabs">';
	echo '<div class="mnsjay-tab-items">';
	foreach ($providers as $provider_key => $provider) {
		echo '<div class="mnsjay-tab-item mnsjay-' . $provider_key . ($active_tab === $provider_key ? ' current' : '') . '">' . $provider['title_en'] . '</div>';
	}
	echo '</div>';
	foreach ($providers as $provider_key => $provider) {
		echo '<div class="mnsjay-tab-box" style="display: ' . ($active_tab === $provider_key ? 'block' : 'none') . ';">';
		foreach ($provider['settings'] as $setting_key => $setting_values) {
			echo '<p>';
			if ($setting_values['type'] === 'text') {
				echo '<label for="mnsjay_logistic_providers_' . $provider_key . '_' . $setting_key . '">' . $setting_values['title'] . ':</label><br>';
				echo '<input type="text" class="regular-text code" name="mnsjay_logistic_providers[' . $provider_key . '][' . $setting_key . ']" id="mnsjay_logistic_providers_' . $provider_key . '_' . $setting_key . '" value="' . $providers_settings[$provider_key][$setting_key] . '">';
			} elseif ($setting_values['type'] === 'select') {
				echo '<label for="mnsjay_logistic_providers_' . $provider_key . '_' . $setting_key . '">' . $setting_values['title'] . ':</label><br>';
				echo '<select name="mnsjay_logistic_providers[' . $provider_key . '][' . $setting_key . ']" id="mnsjay_logistic_providers_' . $provider_key . '_' . $setting_key . '">';
				foreach ($setting_values['options'] as $option_key => $option_name) {
					echo '<option value="' . $option_key . '" ' . selected($option_key, $providers_settings[$provider_key][$setting_key], false) . '>' . $option_name . '</option>';
				}
				echo '</select>';
			} elseif ($setting_values['type'] === 'checkbox') {
				echo '<label><input type="checkbox" name="mnsjay_logistic_providers[' . $provider_key . '][' . $setting_key . ']" value="yes" ' . checked($providers_settings[$provider_key][$setting_key], 'yes', false) . '>' . $setting_values['title'] . '</label>';
			}
			echo '<p class="description">' . $setting_values['description'] . '</p>';
			echo '</p>';
			echo '<br>';
		}
		echo '</div>';
	}
	echo '</div>';
}

function mnsjay_settings_order_location_page_id_output() {

	$page_id = intval(mnsjay_get_option_order_location_page_id());

?>

	<select name="mnsjay_order_location_page_id" id="mnsjay_order_location_page_id" class="wc-page-search regular-text" data-placeholder="<?php _e('Search a page...', 'mnsjay'); ?>">
		<?php if (get_post_type($page_id) == 'page') {
			echo '<option value="' . $page_id . '" selected="selected">' . get_the_title($page_id) . '</option>';
		} ?>
	</select>
	<p class="description"><?php _e('Select a page for order location. This page used to display customer location on map and share it to postman or others.', 'mnsjay'); ?></p>

<?php
}

function mnsjay_settings_display_distance_output() {

	$display_distance = mnsjay_get_option_display_distance();

?>

	<label><input type="checkbox" name="mnsjay_display_distance" value="yes" <?php checked($display_distance, 'yes'); ?>> <?php _e('Yes', 'mnsjay'); ?></label>
	<p class="description"><?php _e('Display distance from origin to customer destination next to name of shipping methods.', 'mnsjay'); ?></p>

<?php
}

function mnsjay_settings_distance_calculation_type_output() {

	$calculation = mnsjay_get_option_distance_calculation_type();

?>

	<select name="mnsjay_distance_calculation_type" id="mnsjay_distance_calculation_type">
		<option value="vincenty" <?php selected($calculation, 'vincenty'); ?>><?php _e('Distance radius (Vincenty\'s Formula)', 'mnsjay'); ?></option>
		<option value="haversine" <?php selected($calculation, 'haversine'); ?>><?php _e('Distance radius (Haversine Formula)', 'mnsjay'); ?></option>
		<option value="navigation" <?php selected($calculation, 'navigation'); ?>><?php _e('Ground distance (Navigation)', 'mnsjay'); ?></option>
	</select>
	<p class="description"><?php _e('Determine how to calculate the distance from origin to destination.', 'mnsjay'); ?></p>
	<p>
		<a href="https://en.wikipedia.org/wiki/Vincenty%27s_formulae" target="_blank"><span class="dashicons dashicons-external"></span><?php _e('Vincenty\'s Formula', 'mnsjay'); ?></a>&nbsp;&nbsp;&nbsp;
		<a href="https://en.wikipedia.org/wiki/Haversine_formula" target="_blank"><span class="dashicons dashicons-external"></span><?php _e('Haversine Formula', 'mnsjay'); ?></a>&nbsp;&nbsp;&nbsp;
		<a href="https://en.wikipedia.org/wiki/Navigation" target="_blank"><span class="dashicons dashicons-external"></span><?php _e('Navigation', 'mnsjay'); ?></a>
	</p>

<?php
}

function mnsjay_settings_display_map_output() {

	$billing = mnsjay_get_option_map_on_billing();
	$shipping = mnsjay_get_option_map_on_shipping();

?>

	<p><label><input type="checkbox" name="mnsjay_map_on_billing" value="yes" <?php checked($billing, 'yes'); ?>> <?php _e('Display map in billing form', 'mnsjay'); ?></label></p>
	<p><label><input type="checkbox" name="mnsjay_map_on_shipping" value="yes" <?php checked($shipping, 'yes'); ?>> <?php _e('Display map in shipping form', 'mnsjay'); ?></label></p>
	<br>
	<p class="description"><?php _e('If you use plugins to edit checkout fields, this may override the settings. In this case, define the following fields in the settings of this plugin so that the map is displayed correctly:', 'mnsjay'); ?></p>
	<p class="description"><?php _e('Billing form field key', 'mnsjay'); ?>: <code><?php echo mnsjay_location_field_key('billing'); ?></code></p>
	<p class="description"><?php _e('Shipping form field key', 'mnsjay'); ?>: <code><?php echo mnsjay_location_field_key('shipping'); ?></code></p>
<?php
}

function mnsjay_settings_map_priority_output() {

	$priority = mnsjay_get_option_map_priority();

?>

	<input type="number" min="1" max="<?php echo mnsjay_max_map_priority(); ?>" step="1" name="mnsjay_map_priority" id="mnsjay_map_priority" value="<?php echo $priority; ?>">
	<p class="description"><?php echo sprintf(__('Set map field priority in checkout form. Enter a number between 1 to %s. Lower priority means higher position.', 'mnsjay'), mnsjay_max_map_priority()); ?></p>

<?php
}

function mnsjay_settings_map_only_on_physical_products_output() {

	$physical = mnsjay_get_option_map_only_on_physical_products();

?>

	<label><input type="checkbox" name="mnsjay_map_only_on_physical_products" value="yes" <?php checked($physical, 'yes'); ?>> <?php _e('Yes', 'mnsjay'); ?></label>
	<p class="description"><?php _e('Display map only when physical products are in the cart.', 'mnsjay'); ?></p>

<?php
}

function mnsjay_settings_map_only_in_regions_output() {

	mnsjay_regions_dropdown('mnsjay_map_only_in_regions', 'mnsjay_map_only_in_regions', mnsjay_get_option_map_only_in_regions());
	echo '<p class="description">' . __('Display map only in these regions. If you want it to be displayed in all regions, leave it blank.<br>For options related to cities to work correctly, the Cities field needs to be active.', 'mnsjay') . '</p>';
}

function mnsjay_settings_cities_field_output() {

	$field = mnsjay_get_option_cities_field();

?>

	<label><input type="checkbox" name="mnsjay_cities_field" value="yes" <?php checked($field, 'yes'); ?>> <?php _e('Yes', 'mnsjay'); ?></label>
	<p class="description"><?php _e('By activating this option, the complete list of cities and villages will replace the WooCommerce city field.', 'mnsjay'); ?></p>

<?php
}

function mnsjay_settings_forced_map_output() {

	$forced = mnsjay_get_option_forced_map();

?>

	<label><input type="checkbox" name="mnsjay_forced_map" value="yes" <?php checked($forced, 'yes'); ?>> <?php _e('Yes', 'mnsjay'); ?></label>
	<p class="description"><?php _e('Mandatory positioning through the map for the customer.', 'mnsjay'); ?></p>

<?php
}

function mnsjay_settings_fill_address_output() {

	$fill = mnsjay_get_option_fill_address();

?>

	<label><input type="checkbox" name="mnsjay_fill_address" value="yes" <?php checked($fill, 'yes'); ?>> <?php _e('Yes', 'mnsjay'); ?></label>
	<p class="description"><?php _e('Fill address field, after set location.', 'mnsjay'); ?></p>

<?php
}

function mnsjay_settings_update_map_on_fields_change_output() {

	$change = mnsjay_get_option_update_map_on_fields_change();

?>

	<label><input type="checkbox" name="mnsjay_update_map_on_fields_change" value="yes" <?php checked($change, 'yes'); ?>> <?php _e('Yes', 'mnsjay'); ?></label>
	<p class="description"><?php _e('When state or city fields changed by customer, map location will be update.', 'mnsjay'); ?></p>

<?php
}

function mnsjay_settings_no_shipping_text_output() {

	$text = mnsjay_get_option_no_shipping_text();

?>

	<textarea class="regular-text" name="mnsjay_no_shipping_text" id="mnsjay_no_shipping_text"><?php echo $text; ?></textarea>
	<p class="description"><?php _e('Text that will be shown to customer when no shipping methods available due to address or location.', 'mnsjay'); ?></p>

<?php
}

function mnsjay_settings_dokan_seller_shipping_output() {

	$shipping = mnsjay_get_option_dokan_seller_shipping();

?>

	<label><input type="checkbox" name="mnsjay_dokan_seller_shipping" value="yes" <?php checked($shipping, 'yes'); ?>> <?php _e('Yes', 'mnsjay'); ?></label>
	<p class="description"><?php _e('Each Dokan seller can define own shipping method.', 'mnsjay'); ?></p>

<?php
}

function mnsjay_settings_heatmap_active_output() {

	$active = mnsjay_get_option_heatmap_active();

?>

	<label><input type="checkbox" name="mnsjay_heatmap_active" value="yes" <?php checked($active, 'yes'); ?>> <?php _e('Yes', 'mnsjay'); ?></label>
	<p class="description"><?php _e('Active orders heatmap feature.', 'mnsjay'); ?></p>

<?php
}

function mnsjay_settings_heatmap_roles_output() {

	$roles = mnsjay_get_option_heatmap_roles();

?>

	<select class="wc-enhanced-select regular-text" name="mnsjay_heatmap_roles[]" id="mnsjay_heatmap_roles" multiple>
		<?php mnsjay_dropdown_roles($roles); ?>
	</select>
	<p class="description"><?php _e('Specify user roles that have access to the heatmap page.', 'mnsjay'); ?></p>

<?php
}

function mnsjay_settings_heatmap_page_id_output() {

	$page_id = intval(mnsjay_get_option_heatmap_page_id());

?>

	<select name="mnsjay_heatmap_page_id" id="mnsjay_heatmap_page_id" class="wc-page-search regular-text" data-placeholder="<?php _e('Search a page...', 'mnsjay'); ?>">
		<?php if (get_post_type($page_id) == 'page') {
			echo '<option value="' . $page_id . '" selected="selected">' . get_the_title($page_id) . '</option>';
		} ?>
	</select>
	<p class="description"><?php _e('Select a page for heatmap.', 'mnsjay'); ?></p>

<?php
}
