<?php

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

function mnsjay_settings_sms_webservice_output() {

	$webservice = mnsjay_get_option_sms_webservice();
	$username = mnsjay_get_option_sms_username();
	$password = mnsjay_get_option_sms_password();
	$apikey = mnsjay_get_option_sms_apikey();
	$secretkey = mnsjay_get_option_sms_secretkey();
	$from = mnsjay_get_option_sms_from();
	$patterns = mnsjay_get_option_sms_patterns();

	if(mnsjay_get_option_debug_mode() == 'yes') {
		echo '<pre class="mnsjay-sms-debug-log">';
		print_r(get_option('mnsjay_sms_response', array()));
		echo '</pre>';
	}

	?>

<div class="mnsjay-sms-settings-container">
	<div class="mnsjay-sms-settings-row">
		<label for="mnsjay_sms_webservice"><?php _e('Choose Webservice:', 'mnsjay'); ?></label>
		<select class="wc-enhanced-select" name="mnsjay_sms_webservice" id="mnsjay_sms_webservice">
			<option value="none" data-support="none" <?php selected($webservice, 'none'); ?>><?php _e('Do not send SMS', 'mnsjay'); ?></option>
			<?php foreach (mnsjay_get_sms_webservices() as $webservice_key => $webservice_values) {
				echo '<option value="' . $webservice_key . '" ' . selected($webservice, $webservice_key, false) . ' data-support="' . implode(',', $webservice_values['support']) . '" data-url="' . $webservice_values['url'] . '">' . $webservice_values['name'] . ' (' . ucfirst($webservice_values['type']) . ')</option>';
			} ?>
		</select>
		<p class="description"><?php _e('Choose a webservice to send SMS.', 'mnsjay'); ?></p>
	</div>
	<div class="mnsjay-sms-settings-row mnsjay-show-if-plugin">
		<p class="description"></p>
	</div>
	<div class="mnsjay-sms-settings-row mnsjay-show-if-userpass">
		<label><?php _e('Username and Password:', 'mnsjay'); ?></label>
		<input class="ltr" type="text" name="mnsjay_sms_username" id="mnsjay_sms_username" value="<?php echo $username; ?>" placeholder="<?php _e('Username', 'mnsjay'); ?>">
		<input class="ltr" type="text" name="mnsjay_sms_password" id="mnsjay_sms_password" value="<?php echo $password; ?>" placeholder="<?php _e('Password', 'mnsjay'); ?>">
		<p class="description"><?php _e('Enter your SMS panel username and password.', 'mnsjay'); ?></p>
	</div>
	<div class="mnsjay-sms-settings-row mnsjay-show-if-apikey">
		<label for="mnsjay_sms_apikey"><?php _e('API Key:', 'mnsjay'); ?></label>
		<input class="ltr regular-text" type="text" name="mnsjay_sms_apikey" id="mnsjay_sms_apikey" value="<?php echo $apikey; ?>">
		<p class="description"><?php _e('Enter your SMS panel API key.', 'mnsjay'); ?></p>
	</div>
	<div class="mnsjay-sms-settings-row mnsjay-show-if-secretkey">
		<label for="mnsjay_sms_secretkey"><?php _e('Secret Key:', 'mnsjay'); ?></label>
		<input class="ltr regular-text" type="text" name="mnsjay_sms_secretkey" id="mnsjay_sms_secretkey" value="<?php echo $secretkey; ?>">
		<p class="description"><?php _e('Enter your SMS panel Secret key.', 'mnsjay'); ?></p>
	</div>
	<div class="mnsjay-sms-settings-row mnsjay-show-if-from">
		<label for="mnsjay_sms_from"><?php _e('From Number:', 'mnsjay'); ?></label>
		<input class="ltr" type="text" name="mnsjay_sms_from" id="mnsjay_sms_from" value="<?php echo $from; ?>">
		<p class="description"><?php _e('Enter your SMS panel sender number.', 'mnsjay'); ?></p>
	</div>
	
	<?php foreach (mnsjay_get_sms_patterns() as $pattern_key => $pattern_values) {

		echo '<div class="mnsjay-sms-settings-row mnsjay-show-if-patterns">';
		echo '<label class="mnsjay-sms-pattern-title"><strong>' . $pattern_values['title'] . '</strong></label>';
		echo '<div class="mnsjay-sms-pattern-fields">';
		echo '<div class="mnsjay-show-if-text"><textarea class="regular-text" name="mnsjay_sms_patterns[' . $pattern_key . '][text]" placeholder="' . __('Pattern Text', 'mnsjay') . '">' . $patterns[$pattern_key]['text'] . '</textarea>
			<p class="description">';
			foreach ($pattern_values['vars'] as $var_key => $var_name) {
				echo $var_name . ': <code>%' . $var_key . '%</code><br>';
			}
			echo '</p>
		</div>';
		echo '<div class="mnsjay-show-if-id"><input class="ltr" type="text" name="mnsjay_sms_patterns[' . $pattern_key . '][id]" placeholder="' . __('Pattern ID', 'mnsjay') . '" value="' . $patterns[$pattern_key]['id'] . '"></div>';
		echo '<div class="mnsjay-show-if-vars">';
		foreach ($pattern_values['vars'] as $var_key => $var_name) {
			echo '<input class="ltr" type="text" name="mnsjay_sms_patterns[' . $pattern_key . '][vars][' . $var_key . ']" placeholder="' . $var_name . '" value="' . $patterns[$pattern_key]['vars'][$var_key] . '">';
		}
		echo '</div>';
		echo '</div>';
		echo '<p class="description">' . sprintf(__('Enter pattern details for this type of message. This pattern needs %s variables.', 'mnsjay'), count($pattern_values['vars'])) . ' <a href="#" class="mnsjay-sms-pattern-example-toggle">(' . __('Example', 'mnsjay') . ')</a></p>';
		echo '<textarea class="mnsjay-sms-pattern-example regular-text" readonly="readonly" style="display: none;">' . $pattern_values['text'] . '</textarea>';
		echo '</div>';

	} ?>
	
</div>

	<?php
}