<?php

if(!defined('ABSPATH'))
	exit;


function mnsjay_settings_conditions_output() {

	$methods = mnsjay_get_option_shipping_methods();
	$categories = get_terms('product_cat', 'orderby=name&hide_empty=0');

	$cart_classes = mnsjay_get_option_shipping_cart_classes();
	$disable_shippings = mnsjay_get_option_shipping_disable_shippings();
	$conditions_counter = mnsjay_get_option_shipping_conditions_classes_counter();
	$product_ids = mnsjay_get_option_shipping_product_ids();
	$exclude_product_ids = mnsjay_get_option_shipping_exclude_product_ids();
	$product_categories = mnsjay_get_option_shipping_product_categories();
	$exclude_product_categories = mnsjay_get_option_shipping_exclude_product_categories();

	if(!mnsjay_is_available_method()) {
		echo '<p class="description">' . __('There is no active method! Please active at least one of them and then return back.', 'mnsjay') . '</p>';
		return;
	}

	$active_method = isset($_GET['method_key']) ? sanitize_text_field($_GET['method_key']) : false;

	if($active_method and !mnsjay_shipping_is_available($active_method)) {
		echo '<p class="description">' . __('This shipping method is not active! Please active it and then return back.', 'mnsjay') . '</p>';
		return;
	}

	?>

	<div class="mnsjay-shipping-conditions-container mnsjay-tabs-container">
		
		<div class="mnsjay-tab-items">
			<?php foreach ($methods as $method_key => $method_values) {

				if(!mnsjay_shipping_is_active($method_values))
					continue;

				$active_method = $active_method ? $active_method : $method_key;

				echo '<div class="mnsjay-tab-item' . ($active_method == $method_key ? ' current' : '') . '"><span>' . $method_values['title'] . '</span></div>';
			} ?>
		</div>

		<div class="mnsjay-shipping-conditions-new" style="display: none;">
			<input type="hidden" id="mnsjay_shipping_conditions_classes_counter" class="mnsjay-shipping-conditions-classes-counter" name="mnsjay_shipping_conditions_classes_counter" value="<?php echo $conditions_counter; ?>">
			<?php mnsjay_template_cart_class_item(); ?>
		</div>

		<?php foreach ($methods as $method_key => $method_values) {
			
			if(!mnsjay_shipping_is_active($method_values))
				continue;

			$cart_classes[$method_key] = isset($cart_classes[$method_key]) ? $cart_classes[$method_key] : array();
		?>

		<div class="mnsjay-tab-box mnsjay-shipping-cart-classes mnsjay-addable-container" style="display: <?php echo $active_method == $method_key ? 'block' : 'none'; ?>;" data-method_key="<?php echo $method_key; ?>">

			<strong><?php _e('Disable Shippings', 'mnsjay'); ?>:</strong>
			<p><select class="wc-enhanced-select regular-text" name="mnsjay_shipping_disable_shippings[<?php echo $method_key; ?>][]" multiple>
				<?php foreach ($methods as $disable_key => $disable_values) {

					if($disable_key == $method_key)
						continue;
					
					echo '<option value="' . $disable_key . '" ' . selected(in_array($disable_key, $disable_shippings[$method_key]), true, false) . '>' . $disable_values['title'] . '</option>';
				} ?>
			</select></p>
			<p class="description"><?php _e('If this shipping method is enabled, other selected methods will be disabled.', 'mnsjay'); ?></p>
			<br><br>

			<label for="mnsjay_shipping_product_ids_<?php echo $method_key; ?>"><strong><?php _e('Only in these products', 'mnsjay'); ?>:</strong></label>
			<p><select class="wc-product-search regular-text" id="mnsjay_shipping_product_ids_<?php echo $method_key; ?>" name="mnsjay_shipping_product_ids[<?php echo $method_key; ?>][]" data-action="woocommerce_json_search_products_and_variations" multiple="multiple">
				<?php foreach ( $product_ids[$method_key] as $product_id ) {
					$product = wc_get_product( $product_id );
					if ( is_object( $product ) ) {
						echo '<option value="' . esc_attr( $product_id ) . '"' . selected( true, true, false ) . '>' . esc_html( wp_strip_all_tags( $product->get_formatted_name() ) ) . '</option>';
					}
				} ?>
			</select></p>
			<p class="description"><?php _e('This shipping method is only available when the shopping cart contains these products.', 'mnsjay'); ?></p>
			<br><br>

			<label for="mnsjay_shipping_exclude_product_ids_<?php echo $method_key; ?>"><strong><?php _e('All except these products', 'mnsjay'); ?>:</strong></label>
			<p><select class="wc-product-search regular-text" id="mnsjay_shipping_exclude_product_ids_<?php echo $method_key; ?>" name="mnsjay_shipping_exclude_product_ids[<?php echo $method_key; ?>][]" data-action="woocommerce_json_search_products_and_variations" multiple="multiple">
				<?php foreach ( $exclude_product_ids[$method_key] as $product_id ) {
					$product = wc_get_product( $product_id );
					if ( is_object( $product ) ) {
						echo '<option value="' . esc_attr( $product_id ) . '"' . selected( true, true, false ) . '>' . esc_html( wp_strip_all_tags( $product->get_formatted_name() ) ) . '</option>';
					}
				} ?>
			</select></p>
			<p class="description"><?php _e('This shipping method is only available when the shopping cart does not include these products.', 'mnsjay'); ?></p>
			<br><br>

			<label for="mnsjay_shipping_product_categories_<?php echo $method_key; ?>"><strong><?php _e('Only in these categories', 'mnsjay'); ?>:</strong></label>
			<p><select class="wc-enhanced-select regular-text" id="mnsjay_shipping_product_categories_<?php echo $method_key; ?>" name="mnsjay_shipping_product_categories[<?php echo $method_key; ?>][]" data-action="woocommerce_json_search_products_and_variations" multiple="multiple">
				<?php if ( $categories ) {
					foreach ( $categories as $cat ) {
						echo '<option value="' . esc_attr( $cat->term_id ) . '"' . wc_selected( $cat->term_id, $product_categories[$method_key] ) . '>' . esc_html( $cat->name ) . '</option>';
					}
				} ?>
			</select></p>
			<p class="description"><?php _e('This shipping method is only available when the shopping cart contains products from these categories.', 'mnsjay'); ?></p>
			<br><br>

			<label for="mnsjay_shipping_exclude_product_categories_<?php echo $method_key; ?>"><strong><?php _e('All except these categories', 'mnsjay'); ?>:</strong></label>
			<p><select class="wc-enhanced-select regular-text" id="mnsjay_shipping_exclude_product_categories_<?php echo $method_key; ?>" name="mnsjay_shipping_exclude_product_categories[<?php echo $method_key; ?>][]" data-action="woocommerce_json_search_products_and_variations" multiple="multiple">
				<?php if ( $categories ) {
					foreach ( $categories as $cat ) {
						echo '<option value="' . esc_attr( $cat->term_id ) . '"' . wc_selected( $cat->term_id, $exclude_product_categories[$method_key] ) . '>' . esc_html( $cat->name ) . '</option>';
					}
				} ?>
			</select></p>
			<p class="description"><?php _e('This shipping method is only available when the shopping cart does not include products in these categories.', 'mnsjay'); ?></p>
			<br><br>

			<strong><?php _e('Cart Total Conditions', 'mnsjay'); ?>:</strong>
			<p class="description"><?php _e('In this section you can define classes for cart total ranges and in each class determine whether this shipping method is active or not.<br>And also set a ratio for it. The ratio will be applied to the final amount of the shipping cost.<br>For unlimited range you can use 0.', 'mnsjay'); ?></p>
			<br>

			<div class="mnsjay-shipping-cart-classes-add mnsjay-addable-add-row">
				<a href="#add" class="button mnsjay-shipping-cart-classes-add-button"><?php _e('+ Add new class', 'mnsjay'); ?></a>
			</div>

			<div class="mnsjay-shipping-cart-classes-area mnsjay-addable-items">
				<?php foreach ($cart_classes[$method_key] as $class_key => $class_values) {	
					mnsjay_template_cart_class_item($method_key, $class_key, $class_values);
				} ?>
			</div>

		</div>

		<?php } ?>
	</div>

	<?php
}