<?php

if(!defined('ABSPATH'))
	exit;


function mnsjay_settings_shipping_distance_classes_output() {

	$methods = mnsjay_get_option_shipping_methods();
	$classes = mnsjay_get_option_shipping_distance_classes();
	$counter = mnsjay_get_option_shipping_distance_classes_counter();

	$distance_bases = mnsjay_get_option_shipping_distance_bases();
	$distance_ranges = mnsjay_get_option_shipping_distance_ranges();

	
	if(!mnsjay_is_available_method()) {
		echo '<p class="description">' . __('There is no active method! Please active at least one of them and then return back.', 'mnsjay') . '</p>';
		return;
	}

	$active_method = isset($_GET['method_key']) ? sanitize_text_field($_GET['method_key']) : false;

	if($active_method and !mnsjay_shipping_is_available($active_method)) {
		echo '<p class="description">' . __('This shipping method is not active! Please active it and then return back.', 'mnsjay') . '</p>';
		return;
	}

	?>

	<div class="mnsjay-tabs-container">

		<div class="mnsjay-tab-items">
			<?php foreach ($methods as $method_key => $method_values) {

				if(!mnsjay_shipping_is_active($method_values))
					continue;

				$active_method = $active_method ? $active_method : $method_key;

				echo '<div class="mnsjay-tab-item' . ($active_method == $method_key ? ' current' : '') . '"><span>' . $method_values['title'] . '</span></div>';
			} ?>
		</div>

		<div class="mnsjay-shipping-distance-classes-new-section" style="display: none;">
			<input type="hidden" id="mnsjay_shipping_distance_classes_counter" class="mnsjay-shipping-distance-classes-counter" name="mnsjay_shipping_distance_classes_counter" value="<?php echo $counter; ?>">
			<?php mnsjay_template_distance_class_raw(); ?>
		</div>

		<?php foreach ($methods as $method_key => $method_values) {

			if(!mnsjay_shipping_is_active($method_values))
				continue;
			
			$distance_bases[$method_key] = isset($distance_bases[$method_key]) ? $distance_bases[$method_key] : 0;
			$distance_ranges[$method_key] = isset($distance_ranges[$method_key]) ? $distance_ranges[$method_key] : array('from' => '0', 'to' => '0');

			?>

		<div class="mnsjay-tab-box mnsjay-shipping-distance-classes mnsjay-addable-container mnsjay-final-cost-container" style="display: <?php echo $active_method == $method_key ? 'block' : 'none'; ?>;" data-method_key="<?php echo $method_key; ?>">

			<p class="mnsjay-final-cost-base" data-base="<?php echo floatval($method_values['base_cost']); ?>">
				<?php echo __('Base Cost:', 'mnsjay') . ' ' . wc_price($method_values['base_cost']); ?>
			</p>
			<br>
			<p>
				<label><?php _e('Allowable distance range', 'mnsjay'); ?>:</label><br>
				<input type="number" class="small-text" name="mnsjay_shipping_distance_ranges[<?php echo $method_key; ?>][from]" min="0" value="<?php echo $distance_ranges[$method_key]['from']; ?>">
				<?php _e('to', 'mnsjay'); ?>
				<input type="number" class="small-text" name="mnsjay_shipping_distance_ranges[<?php echo $method_key; ?>][to]" min="0" value="<?php echo $distance_ranges[$method_key]['to']; ?>">
				<?php _e('Kilometers', 'mnsjay'); ?>
			</p>
			<p class="description"><?php _e('Determine the minimum and maximum range of distance that this shipping method can cover. Enter 0 to 0 for unlimited range.', 'mnsjay'); ?></p>
			<br>
			<p>
				<label for="mnsjay_shipping_distance_bases_<?php echo $method_key; ?>"><?php _e('Extra cost per kilometer', 'mnsjay'); ?>:</label><br>
				<input type="number" min="0" id="mnsjay_shipping_distance_bases_<?php echo $method_key; ?>" name="mnsjay_shipping_distance_bases[<?php echo $method_key; ?>]" value="<?php echo $distance_bases[$method_key]; ?>"> <?php echo get_woocommerce_currency_symbol(); ?>
			</p>
			<p class="description"><?php _e('Determine how much is added to the base cost of shipping per kilometer, or from below, specify the extra cost of shipping for each distance class separately.', 'mnsjay'); ?></p><br>

			<div class="mnsjay-shipping-distance-classes-add mnsjay-addable-add-row">
				<a href="#add" class="button mnsjay-shipping-distance-classe-add-button"><?php _e('+ Add new class', 'mnsjay'); ?></a>
			</div>

			<div class="mnsjay-shipping-distance-classes-area mnsjay-addable-items">
				<?php if(isset($classes[$method_key]) and is_array($classes[$method_key])) {
					foreach ($classes[$method_key] as $class_key => $class_values) {	
						mnsjay_template_distance_class_raw($method_key, $class_key, $class_values);
					}
				} ?>
			</div>

		</div>

		<?php } ?>
	</div>

	<?php
}