<?php

if(!defined('ABSPATH'))
	exit;


function mnsjay_settings_shipping_distance_weight_classes_output() {

	$methods = mnsjay_get_option_shipping_methods();
	$distance_classes = mnsjay_get_option_shipping_distance_classes();
	$weight_classes = mnsjay_get_option_shipping_weight_classes();
	$distance_weight_classes = mnsjay_get_option_shipping_distance_weight_classes();

	if(!mnsjay_is_available_method()) {
		echo '<p class="description">' . __('There is no active method! Please active at least one of them and then return back.', 'mnsjay') . '</p>';
		return;
	}

	$active_method = isset($_GET['method_key']) ? sanitize_text_field($_GET['method_key']) : false;

	if($active_method and !mnsjay_shipping_is_available($active_method)) {
		echo '<p class="description">' . __('This shipping method is not active! Please active it and then return back.', 'mnsjay') . '</p>';
		return;
	}

	?>

	<div class="mnsjay-tabs-container">
		
		<div class="mnsjay-tab-items">
			<?php foreach ($methods as $method_key => $method_values) {

				if(!mnsjay_shipping_is_active($method_values))
					continue;

				$active_method = $active_method ? $active_method : $method_key;

				echo '<div class="mnsjay-tab-item' . ($active_method == $method_key ? ' current' : '') . '"><span>' . $method_values['title'] . '</span></div>';
			} ?>
		</div>

		<?php foreach ($methods as $method_key => $method_values) {
			
			if(!mnsjay_shipping_is_active($method_values))
				continue;
		?>

		<div class="mnsjay-tab-box mnsjay-addable-container mnsjay-final-cost-container" style="display: <?php echo $active_method == $method_key ? 'block' : 'none'; ?>;">
			<p class="mnsjay-final-cost-base" data-base="<?php echo floatval($method_values['base_cost']); ?>">
				<?php echo __('Base Cost:', 'mnsjay') . ' ' . wc_price($method_values['base_cost']); ?>
			</p>
			<p class="description"><?php _e('This section has a higher priority and you can set extra cost for each distance and weight specified.', 'mnsjay'); ?></p><br>
			<div class="mnsjay-shipping-distance_weight-classes-area mnsjay-addable-items">
				<?php if(isset($distance_classes[$method_key]) and is_array($distance_classes[$method_key]) and count($distance_classes[$method_key]) and isset($weight_classes[$method_key]) and is_array($weight_classes[$method_key]) and count($weight_classes[$method_key])) {
					foreach ($distance_classes[$method_key] as $distance_class_key => $distance_class_values) {	
						foreach ($weight_classes[$method_key] as $weight_classe_key => $weight_classe_values) {
							mnsjay_template_distance_weight_class_raw($method_key, $distance_class_key, $weight_classe_key, $distance_class_values, $weight_classe_values, $distance_weight_classes);
						}
					}
				} else {
					echo '<p class="description">' . __('No classes are set for distance and weight.', 'mnsjay') . '</p>';
				} ?>
			</div>
		</div>

		<?php } ?>
	</div>

	<?php
}