<?php

if(!defined('ABSPATH'))
	exit;


function mnsjay_settings_zone_layers_output() {

	$methods = mnsjay_get_option_shipping_methods();
	$origins = mnsjay_get_option_origin_locations();

	$check_type = mnsjay_get_option_shipping_zone_check_type();
	$zones = mnsjay_get_option_shipping_zones();
	$count = mnsjay_get_option_shipping_zones_count();
	$layers = mnsjay_get_option_zone_layers();

	if(!mnsjay_is_available_method()) {
		echo '<p class="description">' . __('There is no active method! Please active at least one of them and then return back.', 'mnsjay') . '</p>';
		return;
	}

	$active_method = isset($_GET['method_key']) ? sanitize_text_field($_GET['method_key']) : false;

	if($active_method and !mnsjay_shipping_is_available($active_method)) {
		echo '<p class="description">' . __('This shipping method is not active! Please active it and then return back.', 'mnsjay') . '</p>';
		return;
	}

	?>

	<script>
		var mnsjayCities = <?php echo json_encode(mnsjay_get_cites()); ?>;
	</script>

	<div class="mnsjay-shipping-zones mnsjay-tabs-container">
		
		<div class="mnsjay-tab-items">
			<?php foreach ($methods as $method_key => $method_values) {

				if(!mnsjay_shipping_is_active($method_values))
					continue;

				$active_method = $active_method ? $active_method : $method_key;

				echo '<div class="mnsjay-tab-item' . ($active_method == $method_key ? ' current' : '') . '"><span>' . $method_values['title'] . '</span></div>';
			} ?>
		</div>

		<div class="mnsjay-zone-placeholder-row">
			<input type="hidden" name="mnsjay_shipping_zones_count" id="mnsjay_shipping_zones_count" value="<?php echo $count; ?>">
			<?php mnsjay_template_shipping_zone_item(); ?>
		</div>

		<?php foreach ($methods as $method_key => $method_values) {
			
			if(!mnsjay_shipping_is_active($method_values))
				continue;

			$zones[$method_key] = isset($zones[$method_key]) ? $zones[$method_key] : array();
			$origins[$method_key] = isset($origins[$method_key]) ? $origins[$method_key] : mnsjay_get_default_location();
			$layers[$method_key] = isset($layers[$method_key]) ? $layers[$method_key] : '[]';
			$check_type[$method_key] = isset($check_type[$method_key]) ? $check_type[$method_key] : 'zone-and-polygon';
		?>

		<div class="mnsjay-tab-box" style="display: <?php echo $active_method == $method_key ? 'block' : 'none'; ?>;">

			<div>
				<label for="mnsjay_shipping_zone_check_type_<?php echo $method_key; ?>" style="margin-bottom: 3px; display: inline-block;"><?php _e('How check customer\'s place?', 'mnsjay'); ?></label><br>
				<select id="mnsjay_shipping_zone_check_type_<?php echo $method_key; ?>" name="mnsjay_shipping_zone_check_type[<?php echo $method_key; ?>]">
					<option value="none" <?php selected($check_type[$method_key], 'none'); ?>><?php _e('None', 'mnsjay'); ?></option>
					<option value="zone" <?php selected($check_type[$method_key], 'zone'); ?>><?php _e('Only zone', 'mnsjay'); ?></option>
					<option value="polygon" <?php selected($check_type[$method_key], 'polygon'); ?>><?php _e('Only area', 'mnsjay'); ?></option>
					<option value="zone-or-polygon" <?php selected($check_type[$method_key], 'zone-or-polygon'); ?>><?php _e('Zone or area', 'mnsjay'); ?></option>
					<option value="zone-and-polygon" <?php selected($check_type[$method_key], 'zone-and-polygon'); ?>><?php _e('Zone and area', 'mnsjay'); ?></option>
				</select>
				<p class="description">
					<?php _e('Zone: States and cities you have chosen.', 'mnsjay'); ?><br>
					<?php _e('Area: Areas you have drawn on map.', 'mnsjay'); ?>
				</p>
			</div><br>

			<div class="mnsjay-shipping-zones-container mnsjay-addable-container" data-method="<?php echo $method_key; ?>">
				<p class="description"><?php _e('Identify states and cities where this shipping method can be used. If left empty, all states and cities will be covered.', 'mnsjay'); ?></p><br>
				<div class="mnsjay-add-zone-row mnsjay-addable-add-row">
					<a class="button mnsjay-add-zone-button" href="#add"><?php _e('+ Add Zone', 'mnsjay'); ?></a>
				</div>
				<div class="mnsjay-zone-items mnsjay-addable-items">
					<?php foreach ($zones[$method_key] as $zone_key => $zone_values) {
						mnsjay_template_shipping_zone_item($method_key, $zone_key, $zone_values);
					} ?>
				</div>
			</div>
			
			<br><p class="description"><?php _e('Specify the covered zones of this shipping method. If you want the whole area to be covered, left it blank.', 'mnsjay'); ?></p><br>
			
			<?php mnsjay_template_admin_map('mnsjay_zone_layers_' . $method_key, 'mnsjay_zone_layers[' . $method_key . ']', array(
				'central_marker' => false,
				'display_lat_lng' => false,
				'display_search' => true,
				'gesture_handling' => false,
				'device_location' => true,
				'fullscreen' => true,
				'overlay_text' => __('Click to draw area', 'mnsjay'),
				'location' => $origins[$method_key],
				'layers' => $layers[$method_key],
				'markers' => array(
					array(
						'coord' => $origins[$method_key],
						'class' => 'mnsjay-origin-marker',
						'text' => __('Origin', 'mnsjay')
					)
				)
			)); ?>
			
		</div>

		<?php } ?>
	</div>

	<?php
}