<?php

if (!defined('ABSPATH')) {
	exit;
}


function mnsjay_settings_slug() {

	return 'mns-jaayegah';
}

function mnsjay_postmans_slug() {

	return 'mnsjay-postmans';
}

function mnsjay_settings_url() {

	return esc_url(admin_url('admin.php?page=' . mnsjay_settings_slug()));
}

function mnsjay_set_wc_screen_ids($screen) {

	return array_merge($screen, mnsjay_screen_ids());
}
add_filter('woocommerce_screen_ids', 'mnsjay_set_wc_screen_ids');

function mnsjay_settings_menu_item() {

	add_menu_page(
		__('MNS Jaayegah Settings', 'mnsjay'),
		__('Jaayegah', 'mnsjay'),
		'manage_options',
		mnsjay_settings_slug(),
		'mnsjay_settings_page',
		mnsjay_svg_base64_encode(mnsjay_svg_logo()),
		56
	);

	add_submenu_page(
		mnsjay_settings_slug(),
		__('MNS Jaayegah Settings', 'mnsjay'),
		__('Settings', 'mnsjay'),
		'manage_options',
		mnsjay_settings_slug(),
		'mnsjay_settings_page',
		10
	);
}
add_action('admin_menu', 'mnsjay_settings_menu_item', 9);

add_action('admin_menu', function () {
	add_submenu_page(
		mnsjay_settings_slug(),
		__('MNS Jaayegah Postmans', 'mnsjay'),
		__('Postmans', 'mnsjay'),
		'manage_options',
		mnsjay_postmans_slug(),
		'mnsjay_postmans_page',
		60
	);
}, 30);


function mnsjay_settings_sections() {

	// array: tab name, custom page, subs
	$settings_sections = array(
		'general' => array(__('General', 'mnsjay'), false, array()),
		/*'shipping' => array(__('Shipping', 'mnsjay'), false, array(
			'general' => array(__('General', 'mnsjay'), false),
			'origin' => array(__('Origins', 'mnsjay'), false),
			'zone' => array(__('Zones', 'mnsjay'), false),
			'distance' => array(__('Distances', 'mnsjay'), false),
			'weight' => array(__('Weights', 'mnsjay'), false),
			'distance_weight' => array(__('Distance and Weight', 'mnsjay'), false),
			'condition' => array(__('Other Conditions', 'mnsjay'), false),
			//'test' => array(__('Cost Test', 'mnsjay'), true),
		)),*/
		'postman' => array(__('Postman Panel', 'mnsjay'), false, array(
			'general' => array(__('General', 'mnsjay'), false),
			'customize' => array(__('Customize', 'mnsjay'), false),
			'webservice' => array(__('SMS Webservice', 'mnsjay'), false),
			//'postmans' => array(__('Postmans', 'mnsjay'), false),
		)),
		'more' => array(__('More products', 'mnsjay'), true, array()),
	);

	$settings_sections = apply_filters('mnsjay_settings_tabs', $settings_sections);
	return $settings_sections;
}

function mnsjay_settings_page() {

	wp_enqueue_style('wp-color-picker');
	wp_enqueue_script('wp-color-picker');
	wp_enqueue_media();

	$active_tab = isset($_GET['tab']) ? sanitize_text_field($_GET['tab']) : 'general';
	$active_sub = isset($_GET['sub']) ? sanitize_text_field($_GET['sub']) : 'general';

	$settings_sections = mnsjay_settings_sections();

	echo '<div class="wrap mnsjay mnsjay-settings">';
	echo '<h1>' . __('MNS Jaayegah Settings', 'mnsjay') . '</h1>';

	settings_errors();

	echo '<nav class="nav-tab-wrapper">';
	foreach ($settings_sections as $tab_key => $tab_val) {
		echo '<a href="?page=' . mnsjay_settings_slug() . '&tab=' . $tab_key . '" class="nav-tab' . (($active_tab == $tab_key) ? ' nav-tab-active' : '') . '">' . $tab_val[0] . '</a>';
	}
	echo '</nav>';

	echo '<form method="post" action="options.php">';

	if (isset($settings_sections[$active_tab])) {

		$this_tab = $settings_sections[$active_tab];

		if (is_array($this_tab[2]) and count($this_tab[2]) > 0) {
			echo '<ul class="subsubsub">';
			$index = 1;
			foreach ($this_tab[2] as $sub_key => $sub_val) {
				echo '<li><a href="?' . http_build_query(array(
					'page' => mnsjay_settings_slug(),
					'tab' => $active_tab,
					'sub' => $sub_key
				)) . '"' . (($active_sub == $sub_key) ? ' class="current"' : '') . '>' . $sub_val[0] . '</a></li>';
				echo ((count($this_tab[2]) > $index) ? ' | ' : '');
				$index++;
			}
			echo '</ul>';
			echo '<br class="clear">';
		}

		$custom_page = isset($this_tab[2][$active_sub]) ? $this_tab[2][$active_sub][1] : $this_tab[1];

		if ($custom_page === true) {

			if (file_exists(MNSJAY_PATH . '/includes/settings/pages/' . $active_tab . '-' . $active_sub . '.php'))
				require_once(MNSJAY_PATH . '/includes/settings/pages/' . $active_tab . '-' . $active_sub . '.php');
		} elseif (is_string($custom_page)) {

			if (file_exists($custom_page))
				require_once($custom_page);
		} elseif ($custom_page === false) {

			settings_fields('mnsjay_settings_' . $active_tab . '_' . $active_sub . '_group');
			do_settings_sections('mnsjay_settings_' . $active_tab . '_' . $active_sub . '_page');
			submit_button();
		}
	}

	echo '</form>';
	echo '</div>';
}

function mnsjay_postmans_page() {

	echo '<div class="wrap mnsjay mnsjay-postmans">';
	echo '<h1>' . __('MNS Jaayegah Postmans', 'mnsjay') . '</h1>';

	settings_errors();

	echo '<form method="post" action="options.php">';

	settings_fields('mnsjay_postmans');
	do_settings_sections('mnsjay_postmans');
	submit_button();

	echo '</form>';
	echo '</div>';
}


require_once(MNSJAY_PATH . '/includes/settings/register.php');

function mnsjay_toolbar_item($wp_admin_bar) {

	if (mnsjay_get_option_supervisor_map_active() === 'yes' and mnsjay_is_current_user_in_roles(mnsjay_get_option_supervisor_map_roles())) {
		$wp_admin_bar->add_node([
			'id'    => 'mnsjay-supervisor-map',
			'title' => __('Supervisor Map', 'mnsjay'),
			'href'  => get_permalink(mnsjay_get_option_supervisor_map_page_id()),
		]);
	}

	if (mnsjay_get_option_heatmap_active() === 'yes' and mnsjay_is_current_user_in_roles(mnsjay_get_option_heatmap_roles())) {
		$wp_admin_bar->add_node([
			'id'    => 'mnsjay-heatmap',
			'title' => __('Heatmap', 'mnsjay'),
			'href'  => get_permalink(mnsjay_get_option_heatmap_page_id()),
		]);
	}
}
add_action('admin_bar_menu', 'mnsjay_toolbar_item', 9999);

function mnsjay_admin_footer_text($content) {

	if (!mnsjay_is_admin_pages())
		return $content;

	$five_star = '<a href="' . mnsjay_info('url') . '" target="_blank">★★★★★</a>';
	$message = sprintf(__('If you like %s, please give us %s rating. Thank you in advance :)', 'mnsjay'), mnsjay_info('name'), $five_star);
	return $message;
}
add_filter('admin_footer_text', 'mnsjay_admin_footer_text', 99999);

function mnsjay_admin_footer_version($content) {

	if (!mnsjay_is_admin_pages())
		return $content;

	return sprintf(__('%s version %s', 'mnsjay'), mnsjay_info('name'), MNSJAY_VERSION);
}
add_filter('update_footer', 'mnsjay_admin_footer_version', 99999);
