<?php

if (!defined('ABSPATH'))
	exit;


function mnsjay_shipping_options_field_output()
{
	wp_enqueue_media();

	$methods = mnsjay_get_option_shipping_methods();
	$categories = get_terms([
		'taxonomy' => 'product_cat',
		'orderby' => 'name',
		'hide_empty' => false,
	]);
	$payment_gateways = WC()->payment_gateways->payment_gateways();

	$logos = mnsjay_get_option_shipping_logos();
	$allowed_gateways = mnsjay_get_option_shipping_allowed_gateways();
	$allowed_roles = mnsjay_get_option_shipping_allowed_roles();
	$location_required = mnsjay_get_option_shipping_location_required();
	$display_distance = mnsjay_get_option_shipping_display_distance();
	$origins = mnsjay_get_option_shipping_origins();
	$areas = mnsjay_get_option_shipping_areas();
	$exclude_areas = mnsjay_get_option_shipping_exclude_areas();
	$regions = mnsjay_get_option_shipping_regions();
	$exclude_regions = mnsjay_get_option_shipping_exclude_regions();
	$disable_shippings = mnsjay_get_option_shipping_disable_shippings();
	$product_ids = mnsjay_get_option_shipping_product_ids();
	$exclude_product_ids = mnsjay_get_option_shipping_exclude_product_ids();
	$product_categories = mnsjay_get_option_shipping_product_categories();
	$exclude_product_categories = mnsjay_get_option_shipping_exclude_product_categories();
	$classes = mnsjay_get_option_shipping_classes();
	$exclude_classes = mnsjay_get_option_shipping_exclude_classes();
	$base_types = mnsjay_get_option_shipping_base_types();
	$base_costs = mnsjay_get_option_shipping_base_costs();
	$extra_costs = mnsjay_get_option_shipping_extra_costs();
	$week_days =  mnsjay_get_option_shipping_week_days();
	$week_times = mnsjay_get_option_shipping_week_times();
	$distances_classes = mnsjay_get_option_shipping_distances();
	$weights_classes = mnsjay_get_option_shipping_weights();
	$cart_classes = mnsjay_get_option_shipping_cart_classes();
	$classes_counter = mnsjay_get_option_shipping_classes_counter();

	// backward compatibility
	$old_origins = mnsjay_get_option_origin_locations();
	$old_check_type = mnsjay_get_option_shipping_zone_check_type();
	$old_zones = mnsjay_get_option_shipping_zones();
	$old_layers = mnsjay_get_option_zone_layers();

	if (empty($methods)) {
		echo '<p class="description">' . __('There is no active method! Please active at least one of them and then return back.', 'mnsjay') . '</p>';
		return;
	}

	$active_method = isset($_GET['method_key']) ? sanitize_text_field($_GET['method_key']) : false;

	if ($active_method and !isset($methods[$active_method])) {
		echo '<p class="description">' . __('This shipping method is not active! Please active it and then return back.', 'mnsjay') . '</p>';
		return;
	}

?>

	<div class="mnsjay-shipping-options-settings mnsjay-tabs-container mnsjay-addable-area">

		<div class="mnsjay-tab-items">
			<?php foreach ($methods as $method_key => $method_values) {
				$active_method = $active_method ? $active_method : $method_key;
				echo '<div class="mnsjay-tab-item' . ($active_method === $method_key ? ' current' : '') . '"><span>' . $method_values['default_title'] . '</span></div>';
			} ?>
		</div>

		<input type="hidden" class="mnsjay-counter" name="mnsjay_shipping_classes_counter" value="<?php echo $classes_counter; ?>">

		<?php foreach ($methods as $method_key => $method_values) {

			$origins[$method_key] = isset($origins[$method_key]) ? $origins[$method_key] : '';
			$areas[$method_key] = isset($areas[$method_key]) ? $areas[$method_key] : array();
			$exclude_areas[$method_key] = isset($exclude_areas[$method_key]) ? $exclude_areas[$method_key] : array();
			$disable_shippings[$method_key] = isset($disable_shippings[$method_key]) ? $disable_shippings[$method_key] : array();
			$product_ids[$method_key] = isset($product_ids[$method_key]) ? $product_ids[$method_key] : array();
			$exclude_product_ids[$method_key] = isset($exclude_product_ids[$method_key]) ? $exclude_product_ids[$method_key] : array();
			$product_categories[$method_key] = isset($product_categories[$method_key]) ? $product_categories[$method_key] : array();
			$exclude_product_categories[$method_key] = isset($exclude_product_categories[$method_key]) ? $exclude_product_categories[$method_key] : array();
			$base_costs[$method_key] = isset($base_costs[$method_key]) ? $base_costs[$method_key] : '0';
			$allowed_roles[$method_key] = isset($allowed_roles[$method_key]) ? $allowed_roles[$method_key] : [];
		?>

			<div class="mnsjay-tab-box mnsjay-shipping-options-container" style="display: <?php echo $active_method === $method_key ? 'flex' : 'none'; ?>;" data-method_key="<?php echo $method_key; ?>">

				<h3><?php _e('Basic settings', 'mnsjay'); ?></h3>

				<div class="mnsjay-option-item">
					<label for="mnsjay_shipping_logos_<?php echo $method_key; ?>">
						<strong><?php _e('Shipping Logo', 'mnsjay'); ?>:</strong>
					</label>
					<div>
						<?php mnsjay_upload_image('mnsjay_shipping_logos[' . $method_key . ']', $logos[$method_key], [
							'title' => __('Choose Shipping Logo', 'mnsjay')
						]); ?>
						<p class="description"><?php _e('Choose a logo for this shipping method.', 'mnsjay'); ?></p>
					</div>
				</div>

				<div class="mnsjay-option-item">
					<label for="mnsjay_shipping_disable_shippings_<?php echo $method_key; ?>">
						<strong><?php _e('Disable Shippings', 'mnsjay'); ?>:</strong>
					</label>
					<div>
						<div>
							<select class="wc-enhanced-select regular-text" id="mnsjay_shipping_disable_shippings_<?php echo $method_key; ?>" name="mnsjay_shipping_disable_shippings[<?php echo $method_key; ?>][]" multiple>
								<?php foreach ($methods as $disable_key => $disable_values) {

									if ($disable_key === $method_key)
										continue;

									echo '<option value="' . $disable_key . '" ' . selected(in_array($disable_key, $disable_shippings[$method_key]), true, false) . '>' . $disable_values['default_title'] . '</option>';
								} ?>
							</select>
						</div>
						<p class="description"><?php _e('If this shipping method is enabled, other selected methods will be disabled.', 'mnsjay'); ?></p>
					</div>
				</div>

				<div class="mnsjay-option-item">
					<label for="mnsjay_shipping_allowed_gateways_<?php echo $method_key; ?>">
						<strong><?php _e('Allowed Payment Gateways', 'mnsjay'); ?>:</strong>
					</label>
					<div>
						<div>
							<select class="wc-enhanced-select regular-text" id="mnsjay_shipping_allowed_gateways_<?php echo $method_key; ?>" name="mnsjay_shipping_allowed_gateways[<?php echo $method_key; ?>][]" multiple>
								<?php foreach ($payment_gateways as $gateway_key => $gateway) {
									echo '<option value="' . $gateway_key . '" ' . selected(in_array($gateway_key, $allowed_gateways[$method_key]), true, false) . '>' . $gateway->title . '</option>';
								} ?>
							</select>
						</div>
						<p class="description"><?php _e('If this shipping method is chosen by customer, which payment gateways can be used? If you want all payment gateways to remain active, leave this option blank.', 'mnsjay'); ?></p>
					</div>
				</div>

				<div class="mnsjay-option-item">
					<label for="mnsjay_shipping_allowed_roles_<?php echo $method_key; ?>">
						<strong><?php _e('Allowed User Roles', 'mnsjay'); ?>:</strong>
					</label>
					<div>
						<div>
							<select class="wc-enhanced-select regular-text" id="mnsjay_shipping_allowed_roles_<?php echo $method_key; ?>" name="mnsjay_shipping_allowed_roles[<?php echo $method_key; ?>][]" multiple>
								<?php foreach (array_reverse(get_editable_roles()) as $role => $details) {
									echo '<option value="' . esc_attr($role) . '" ' . selected(in_array($role, $allowed_roles[$method_key]), true, false) . '>' . translate_user_role($details['name']) . '</option>';
								} ?>
							</select>
						</div>
						<p class="description"><?php _e('Specify the user roles that can use this shipping method. Leave this option blank if you want all roles to be able to use this method.', 'mnsjay'); ?></p>
					</div>
				</div>

				<div class="mnsjay-option-item">
					<div>
						<div>
							<label><input type="checkbox" name="mnsjay_shipping_location_required[<?php echo $method_key; ?>]" value="yes" <?php checked($location_required[$method_key], 'yes'); ?>> <strong><?php _e('Location Required', 'mnsjay'); ?></strong></label>
						</div>
						<p class="description"><?php _e('This shipping method is activated only when the location is setted on the map by the customer.', 'mnsjay'); ?></p>
					</div>
				</div>

				<div class="mnsjay-option-item">
					<div>
						<div>
							<label><input type="checkbox" name="mnsjay_shipping_display_distance[<?php echo $method_key; ?>]" value="yes" <?php checked($display_distance[$method_key], 'yes'); ?>> <strong><?php _e('Display Distance', 'mnsjay'); ?></strong></label>
						</div>
						<p class="description"><?php _e('Display distance from origin to customer destination that setted by map next to name of this shipping method.', 'mnsjay'); ?></p>
					</div>
				</div>

				<h3><?php _e('Areas and regions settings', 'mnsjay'); ?></h3>

				<div class="mnsjay-option-item">
					<label for="mnsjay_shipping_origins_<?php echo $method_key; ?>">
						<strong><?php _e('Shipping Origin', 'mnsjay'); ?>:</strong>
					</label>
					<?php if (isset($old_origins[$method_key])) { ?>
						<div class="mnsjay-converter-alert" data-method="<?php echo $method_key; ?>">
							<div>برای این روش حمل و نقل، یک مبدا از تنظیمات قدیمی وجود دارد.</div>
							<div>
								<div class="mnsjay-btn" data-action="origin-trans">تبدیل به نسخه جدید</div>
								<div class="mnsjay-btn" data-action="origin-delete">صرف نظر کردن از تنظیمات قدیمی</div>
							</div>
						</div>
					<?php } ?>
					<div>
						<div>
							<select class="wc-enhanced-select regular-text" id="mnsjay_shipping_origins_<?php echo $method_key; ?>" name="mnsjay_shipping_origins[<?php echo $method_key; ?>]">
								<?php foreach (mnsjay_get_locations() as $location) {
									echo '<option value="' . $location->ID . '" ' . selected($location->ID, $origins[$method_key], false) . '>' . get_the_title($location->ID) . ' (' . mnsjay_get_location_address($location->ID) . ')</option>';
								} ?>
							</select>
						</div>
						<p class="description"><?php _e('Select the origin of this shipping method.', 'mnsjay'); ?></p>
					</div>
				</div>

				<div class="mnsjay-option-item">
					<label for="mnsjay_shipping_areas_<?php echo $method_key; ?>">
						<strong><?php _e('Only in these areas', 'mnsjay'); ?>:</strong>
					</label>
					<?php if (isset($old_layers[$method_key]) and $old_layers[$method_key] != '[]' and isset($old_check_type[$method_key]) and !in_array($old_check_type[$method_key], ['none', 'zone'])) { ?>
						<div class="mnsjay-converter-alert" data-method="<?php echo $method_key; ?>">
							<div>برای این روش حمل و نقل، یک منطقه از تنظیمات قدیمی وجود دارد.</div>
							<div>
								<div class="mnsjay-btn" data-action="layer-trans">تبدیل به نسخه جدید</div>
								<div class="mnsjay-btn" data-action="layer-delete">صرف نظر کردن از تنظیمات قدیمی</div>
							</div>
						</div>
					<?php } ?>
					<div>
						<div>
							<select class="wc-enhanced-select regular-text" id="mnsjay_shipping_areas_<?php echo $method_key; ?>" name="mnsjay_shipping_areas[<?php echo $method_key; ?>][]" multiple>
								<?php foreach (mnsjay_get_areas() as $area) {
									echo '<option value="' . $area->ID . '" ' . selected(in_array($area->ID, $areas[$method_key]), true, false) . '>' . get_the_title($area->ID) . '</option>';
								} ?>
							</select>
						</div>
						<p class="description"><?php _e('This shipping method will only be activated if the customer set their location in the designated areas. Leave this option blank for nationwide coverage.', 'mnsjay'); ?></p>
					</div>
				</div>

				<div class="mnsjay-option-item">
					<label for="mnsjay_shipping_exclude_areas_<?php echo $method_key; ?>">
						<strong><?php _e('Except these areas', 'mnsjay'); ?>:</strong>
					</label>
					<div>
						<div>
							<select class="wc-enhanced-select regular-text" id="mnsjay_shipping_exclude_areas_<?php echo $method_key; ?>" name="mnsjay_shipping_exclude_areas[<?php echo $method_key; ?>][]" multiple>
								<?php foreach (mnsjay_get_areas() as $area) {
									echo '<option value="' . $area->ID . '" ' . selected(in_array($area->ID, $exclude_areas[$method_key]), true, false) . '>' . get_the_title($area->ID) . '</option>';
								} ?>
							</select>
						</div>
						<p class="description"><?php _e('This shipping method will only be activated if the customer does not set their location in the designated areas.', 'mnsjay'); ?></p>
					</div>
				</div>

				<div class="mnsjay-option-item">
					<label for="mnsjay_shipping_regions_<?php echo $method_key; ?>">
						<strong><?php _e('Only in these regions', 'mnsjay'); ?>:</strong>
					</label>
					<div>
						<div>
							<?php mnsjay_regions_dropdown('mnsjay_shipping_regions_' . $method_key, 'mnsjay_shipping_regions[' . $method_key . ']', $regions[$method_key]); ?>
						</div>
						<p class="description"><?php _e('This shipping method will only be activated if the customer chooses designated regions in the state and city fields. Leave this option blank for nationwide coverage.', 'mnsjay'); ?></p>
					</div>
				</div>

				<div class="mnsjay-option-item">
					<label for="mnsjay_shipping_exclude_regions_<?php echo $method_key; ?>">
						<strong><?php _e('Except these regions', 'mnsjay'); ?>:</strong>
					</label>
					<div>
						<div>
							<?php mnsjay_regions_dropdown('mnsjay_shipping_exclude_regions_' . $method_key, 'mnsjay_shipping_exclude_regions[' . $method_key . ']', $exclude_regions[$method_key]); ?>
						</div>
						<p class="description"><?php _e('This shipping method will only be activated if the customer does not choose designated regions in the state and city fields.', 'mnsjay'); ?></p>
					</div>
				</div>

				<h3><?php _e('Products settings', 'mnsjay'); ?></h3>

				<div class="mnsjay-option-item">
					<label for="mnsjay_shipping_product_ids_<?php echo $method_key; ?>">
						<strong><?php _e('Only in these products', 'mnsjay'); ?>:</strong>
					</label>
					<div>
						<div>
							<select class="wc-product-search regular-text" id="mnsjay_shipping_product_ids_<?php echo $method_key; ?>" name="mnsjay_shipping_product_ids[<?php echo $method_key; ?>][]" data-action="woocommerce_json_search_products_and_variations" multiple="multiple">
								<?php foreach ($product_ids[$method_key] as $product_id) {
									$product = wc_get_product($product_id);
									if (is_object($product)) {
										echo '<option value="' . esc_attr($product_id) . '"' . selected(true, true, false) . '>' . esc_html(wp_strip_all_tags($product->get_formatted_name())) . '</option>';
									}
								} ?>
							</select>
						</div>
						<p class="description"><?php _e('This shipping method is only available when the shopping cart contains these products.', 'mnsjay'); ?></p>
					</div>
				</div>

				<div class="mnsjay-option-item">
					<label for="mnsjay_shipping_exclude_product_ids_<?php echo $method_key; ?>">
						<strong><?php _e('All except these products', 'mnsjay'); ?>:</strong>
					</label>
					<div>
						<div>
							<select class="wc-product-search regular-text" id="mnsjay_shipping_exclude_product_ids_<?php echo $method_key; ?>" name="mnsjay_shipping_exclude_product_ids[<?php echo $method_key; ?>][]" data-action="woocommerce_json_search_products_and_variations" multiple="multiple">
								<?php foreach ($exclude_product_ids[$method_key] as $product_id) {
									$product = wc_get_product($product_id);
									if (is_object($product)) {
										echo '<option value="' . esc_attr($product_id) . '"' . selected(true, true, false) . '>' . esc_html(wp_strip_all_tags($product->get_formatted_name())) . '</option>';
									}
								} ?>
							</select>
						</div>
						<p class="description"><?php _e('This shipping method is only available when the shopping cart does not include these products.', 'mnsjay'); ?></p>
					</div>
				</div>

				<div class="mnsjay-option-item">
					<label for="mnsjay_shipping_product_categories_<?php echo $method_key; ?>">
						<strong><?php _e('Only in these categories', 'mnsjay'); ?>:</strong>
					</label>
					<div>
						<div>
							<select class="wc-enhanced-select regular-text" id="mnsjay_shipping_product_categories_<?php echo $method_key; ?>" name="mnsjay_shipping_product_categories[<?php echo $method_key; ?>][]" data-action="woocommerce_json_search_products_and_variations" multiple="multiple">
								<?php if ($categories) {
									foreach ($categories as $cat) {
										echo '<option value="' . esc_attr($cat->term_id) . '"' . wc_selected($cat->term_id, $product_categories[$method_key]) . '>' . esc_html($cat->name) . '</option>';
									}
								} ?>
							</select>
						</div>
						<p class="description"><?php _e('This shipping method is only available when the shopping cart contains products from these categories.', 'mnsjay'); ?></p>
					</div>
				</div>

				<div class="mnsjay-option-item">
					<label for="mnsjay_shipping_exclude_product_categories_<?php echo $method_key; ?>">
						<strong><?php _e('All except these categories', 'mnsjay'); ?>:</strong>
					</label>
					<div>
						<div>
							<select class="wc-enhanced-select regular-text" id="mnsjay_shipping_exclude_product_categories_<?php echo $method_key; ?>" name="mnsjay_shipping_exclude_product_categories[<?php echo $method_key; ?>][]" data-action="woocommerce_json_search_products_and_variations" multiple="multiple">
								<?php if ($categories) {
									foreach ($categories as $cat) {
										echo '<option value="' . esc_attr($cat->term_id) . '"' . wc_selected($cat->term_id, $exclude_product_categories[$method_key]) . '>' . esc_html($cat->name) . '</option>';
									}
								} ?>
							</select>
						</div>
						<p class="description"><?php _e('This shipping method is only available when the shopping cart does not include products in these categories.', 'mnsjay'); ?></p>
					</div>
				</div>

				<div class="mnsjay-option-item">
					<label for="mnsjay_shipping_classes_<?php echo $method_key; ?>">
						<strong><?php _e('Only in these shipping classes', 'mnsjay'); ?>:</strong>
					</label>
					<div>
						<div>
							<select class="wc-enhanced-select regular-text" id="mnsjay_shipping_classes_<?php echo $method_key; ?>" name="mnsjay_shipping_classes[<?php echo $method_key; ?>][]" multiple="multiple">
								<?php foreach (mnsjay_get_shipping_classes() as $shipping_class) {
									echo '<option value="' . esc_attr($shipping_class->term_id) . '"' . wc_selected($shipping_class->term_id, $classes[$method_key]) . '>' . esc_html($shipping_class->name) . '</option>';
								} ?>
							</select>
						</div>
						<p class="description"><?php _e('This shipping method is only available when the shopping cart contains products from these classes.', 'mnsjay'); ?></p>
					</div>
				</div>

				<div class="mnsjay-option-item">
					<label for="mnsjay_shipping_exclude_classes_<?php echo $method_key; ?>">
						<strong><?php _e('All except these shipping classes', 'mnsjay'); ?>:</strong>
					</label>
					<div>
						<div>
							<select class="wc-enhanced-select regular-text" id="mnsjay_shipping_exclude_classes_<?php echo $method_key; ?>" name="mnsjay_shipping_exclude_classes[<?php echo $method_key; ?>][]" multiple="multiple">
								<?php foreach (mnsjay_get_shipping_classes() as $shipping_class) {
									echo '<option value="' . esc_attr($shipping_class->term_id) . '"' . wc_selected($shipping_class->term_id, $exclude_classes[$method_key]) . '>' . esc_html($shipping_class->name) . '</option>';
								} ?>
							</select>
						</div>
						<p class="description"><?php _e('This shipping method is only available when the shopping cart does not contain products from these classes.', 'mnsjay'); ?></p>
					</div>
				</div>

				<h3><?php _e('Costs settings', 'mnsjay'); ?></h3>

				<div class="mnsjay-option-item">
					<label for="mnsjay_shipping_base_costs_<?php echo $method_key; ?>">
						<strong><?php _e('Base Cost', 'mnsjay'); ?>:</strong>
					</label>
					<div>
						<div class="mnsjay-base-cost-switch">
							<ul>
								<li><label><input type="radio" name="mnsjay_shipping_base_types[<?php echo $method_key; ?>]" value="simple" <?php checked($base_types[$method_key], 'simple'); ?>> <?php _e('Simple', 'mnsjay'); ?></label></li>
								<li><label><input type="radio" name="mnsjay_shipping_base_types[<?php echo $method_key; ?>]" value="pishtaz" <?php checked($base_types[$method_key], 'pishtaz'); ?>> <?php _e('Iran National Post: Pishtaz', 'mnsjay'); ?></label></li>
								<?php foreach (mnsjay_logistic_providers() as $provider_key => $provider) {
									if (mnsjay_logistic_get_setting($provider_key, 'active') !== 'none' and mnsjay_logistic_get_setting($provider_key, 'active') !== null and mnsjay_logistic_get_setting($provider_key, 'active') !== '') {
										foreach ($provider['cost_options'] as $cost_key => $cost_title) {
											echo '<li><label><input type="radio" name="mnsjay_shipping_base_types[' . $method_key . ']" value="' . $cost_key . '" ' . checked($base_types[$method_key], $cost_key, false) . '> ' . $cost_title . '</label></li>';
										}
									}
								} ?>
							</ul>
							<div class="mnsjay-base-cost-simple-field">
								<input type="text" class="mnsjay-base-cost regular-text" id="mnsjay_shipping_base_costs_<?php echo $method_key; ?>" name="mnsjay_shipping_base_costs[<?php echo $method_key; ?>]" value="<?php echo $base_costs[$method_key]; ?>" placeholder="0">
								<?php echo get_woocommerce_currency_symbol(); ?>
							</div>
						</div>
						<p class="description"><?php _e('Define base code for this shipping method. All other costs will be added to this amount.', 'mnsjay'); ?></p>
					</div>
				</div>

				<div class="mnsjay-option-item">
					<label>
						<strong><?php _e('Week Days', 'mnsjay'); ?>:</strong>
						<small style="opacity: 0.5;">
							<?php echo sprintf(__('Now: %s at %s', 'mnsjay'), wp_date('l'), wp_date('H:i')); ?>
						</small>
					</label>
					<div>
						<p class="description">
							<?php _e('Customize this method\'s basics in each day of week separately.', 'mnsjay'); ?>
						</p>
						<div>
							<div class="mnsjay-week-grid">
								<?php foreach (mnsjay_local_week_days() as $week_key => $week_name) { ?>
									<div class="mnsjay-week-name">
										<label>
											<input type="checkbox" name="mnsjay_shipping_week_days[<?php echo $method_key; ?>][<?php echo $week_key; ?>][active]" <?php checked('yes', $week_days[$method_key][$week_key]['active']); ?> value="yes"><?php echo $week_name; ?>
										</label>
									</div>
									<div class="mnsjay-addable-container mnsjay-moveable-container mnsjay-week-container mnsjay-week-options" data-path="<?php echo $method_key . '-' . $week_key; ?>">
										<div>
											<label for="mnsjay_shipping_week_days_<?php echo $method_key; ?>_<?php echo $week_key; ?>_ratio"><?php _e('This day\'s ratio', 'mnsjay'); ?>:</label><br>
											<input type="text" id="mnsjay_shipping_week_days_<?php echo $method_key; ?>_<?php echo $week_key; ?>_ratio" name="mnsjay_shipping_week_days[<?php echo $method_key; ?>][<?php echo $week_key; ?>][ratio]" placeholder="1" value="<?php echo $week_days[$method_key][$week_key]['ratio']; ?>">
										</div>
										<div>
											<label for="mnsjay_shipping_week_days_<?php echo $method_key; ?>_<?php echo $week_key; ?>_title"><?php _e('This day\'s method title', 'mnsjay'); ?>:</label><br>
											<input type="text" id="mnsjay_shipping_week_days_<?php echo $method_key; ?>_<?php echo $week_key; ?>_title" name="mnsjay_shipping_week_days[<?php echo $method_key; ?>][<?php echo $week_key; ?>][title]" placeholder="<?php echo $method_values['default_title']; ?>" value="<?php echo $week_days[$method_key][$week_key]['title']; ?>">
										</div>
										<div class="mnsjay-buttons">
											<a href="#add" class="button mnsjay-add-button" data-path="<?php echo $method_key . '-' . $week_key; ?>"><?php _e('+ Add time condition', 'mnsjay'); ?></a>
										</div>
										<div class="mnsjay-addables mnsjay-moveables mnsjay-week-addables" data-path="<?php echo $method_key . '-' . $week_key; ?>"></div>
										<div class="mnsjay-new" style="display: none;"><?php mnsjay_template_week_day_hour_row(); ?></div>
										<input type="hidden" class="mnsjay-data" value='<?php echo wp_json_encode($week_times); ?>'>
									</div>
								<?php } ?>
							</div>
						</div>
					</div>
				</div>

				<div class="mnsjay-option-item">
					<label>
						<strong><?php _e('Extra Costs', 'mnsjay'); ?>:</strong>
					</label>
					<div class="mnsjay-addable-container mnsjay-moveable-container mnsjay-extra-costs-container" data-path="<?php echo $method_key; ?>">
						<p class="description"><?php _e('Specify extra costs associated with this shipping method. These costs will be added as an item on customer\'s invoice.', 'mnsjay'); ?></p>
						<div class="mnsjay-buttons">
							<a href="#add" class="button mnsjay-add-button" data-path="<?php echo $method_key; ?>"><?php _e('+ Add new extra cost', 'mnsjay'); ?></a>
						</div>
						<div class="mnsjay-addables mnsjay-moveables mnsjay-extra-costs-addables" data-path="<?php echo $method_key; ?>"></div>
						<div class="mnsjay-new" style="display: none;"><?php mnsjay_template_extra_cost_class_row(); ?></div>
						<input type="hidden" class="mnsjay-data" value='<?php echo wp_json_encode($extra_costs); ?>'>
					</div>
				</div>

				<div class="mnsjay-option-item">
					<label>
						<strong><?php _e('Distance Conditions', 'mnsjay'); ?>:</strong>
					</label>
					<div class="mnsjay-addable-container mnsjay-moveable-container mnsjay-distance-container" data-path="<?php echo $method_key; ?>">
						<p class="description"><?php _e('Specify extra cost and other conditions of this shipping method for each distance range.', 'mnsjay'); ?></p>
						<div class="mnsjay-buttons">
							<a href="#add" class="button mnsjay-add-button" data-path="<?php echo $method_key; ?>"><?php _e('+ Add new condition', 'mnsjay'); ?></a>
						</div>
						<div class="mnsjay-addables mnsjay-moveables mnsjay-distance-addables" data-path="<?php echo $method_key; ?>"></div>
						<div class="mnsjay-new" style="display: none;"><?php mnsjay_template_distance_class_row(); ?></div>
						<input type="hidden" class="mnsjay-data" value='<?php echo wp_json_encode($distances_classes); ?>'>
					</div>
				</div>

				<div class="mnsjay-option-item">
					<label>
						<strong><?php _e('Weight Conditions', 'mnsjay'); ?>:</strong>
					</label>
					<div class="mnsjay-addable-container mnsjay-moveable-container mnsjay-weight-container" data-path="<?php echo $method_key; ?>">
						<p class="description"><?php _e('Specify extra cost and other conditions of this shipping method for each weight range.', 'mnsjay'); ?></p>
						<div class="mnsjay-buttons">
							<a href="#add" class="button mnsjay-add-button" data-path="<?php echo $method_key; ?>"><?php _e('+ Add new condition', 'mnsjay'); ?></a>
						</div>
						<div class="mnsjay-addables mnsjay-moveables mnsjay-weight-addables" data-path="<?php echo $method_key; ?>"></div>
						<div class="mnsjay-new" style="display: none;"><?php mnsjay_template_weight_class_row(); ?></div>
						<input type="hidden" class="mnsjay-data" value='<?php echo wp_json_encode($weights_classes); ?>'>
					</div>
				</div>

				<div class="mnsjay-option-item">
					<label>
						<strong><?php _e('Cart Total Conditions', 'mnsjay'); ?>:</strong>
					</label>
					<div class="mnsjay-addable-container mnsjay-moveable-container mnsjay-cart-container" data-path="<?php echo $method_key; ?>">
						<p class="description"><?php _e('Specify ratio and other conditions of this shipping method for each cart total range.', 'mnsjay'); ?></p>
						<div class="mnsjay-buttons">
							<a href="#add" class="button mnsjay-add-button" data-path="<?php echo $method_key; ?>"><?php _e('+ Add new condition', 'mnsjay'); ?></a>
						</div>
						<div class="mnsjay-addables mnsjay-moveables mnsjay-cart-addables" data-path="<?php echo $method_key; ?>"></div>
						<div class="mnsjay-new" style="display: none;"><?php mnsjay_template_cart_class_row(); ?></div>
						<input type="hidden" class="mnsjay-data" value='<?php echo wp_json_encode($cart_classes); ?>'>
					</div>
				</div>

			</div>

		<?php } ?>
	</div>

<?php
}
