<?php

function mnsjay_shippings_slug() {

	return 'mnsjay-shippings';
}

function mnsjay_shippings_menu_item() {

	add_submenu_page(
		mnsjay_settings_slug(),
		__('MNS Jaayegah Shipping Methods', 'mnsjay'),
		__('Shippings', 'mnsjay'),
		'manage_options',
		mnsjay_shippings_slug(),
		'mnsjay_shippings_page',
		10
	);
}
add_action('admin_menu', 'mnsjay_shippings_menu_item', 10);

function mnsjay_shippings_tabs() {

	return apply_filters('mnsjay_shippings_tabs', [
		'methods' => [
			'title' => __('Methods', 'mnsjay'),
			'subs' => [
				'methods' => [
					'title' => __('Methods', 'mnsjay'),
					'page' => false
				]
			]
		],
		'options' => [
			'title' => __('Options', 'mnsjay'),
			'subs' => [
				'options' => [
					'title' => __('Options', 'mnsjay'),
					'page' => false
				]
			]
		]
	]);
}

function mnsjay_shippings_page() {

	wp_enqueue_style('wp-color-picker');
	wp_enqueue_script('wp-color-picker');
	wp_enqueue_media();

	$tabs = mnsjay_shippings_tabs();

	$tab_key = isset($_GET['tab']) ? sanitize_text_field($_GET['tab']) : array_key_first($tabs);
	$tab_values = isset($tabs[$tab_key]) ? $tabs[$tab_key] : $tabs[array_key_first($tabs)];

	$sub_key = isset($_GET['sub']) ? sanitize_text_field($_GET['sub']) : array_key_first($tab_values['subs']);
	$sub_values = isset($tab_values['subs'][$sub_key]) ? $tab_values['subs'][$sub_key] : $tab_values['subs'][array_key_first($tab_values['subs'])];

	echo '<div class="wrap mnsjay mnsjay-shippings">';
	echo '<h1>' . __('MNS Jaayegah Shipping Methods', 'mnsjay') . '</h1>';

	settings_errors();

	echo '<form method="post" action="options.php">';

	if (count($tabs) > 1) {
		echo '<nav class="nav-tab-wrapper">';
		foreach ($tabs as $_tab_key => $_tab_values) {
			echo '<a href="?' . http_build_query([
				'page' => mnsjay_shippings_slug(),
				'tab' => $_tab_key
			]) . '" class="nav-tab' . ($tab_key === $_tab_key ? ' nav-tab-active' : '') . '">' . $_tab_values['title'] . '</a>';
		}
		echo '</nav>';
	}

	if (count($tab_values['subs']) > 1) {
		echo '<ul class="subsubsub">';
		foreach ($tab_values['subs'] as $_sub_key => $_sub_values) {
			echo '<li><a href="?' . http_build_query([
				'page' => mnsjay_shippings_slug(),
				'tab' => $tab_key,
				'sub' => $_sub_key
			]) . '"' . ($sub_key === $_sub_key ? ' class="current"' : '') . '>' . $_sub_values['title'] . '</a></li>';
			echo (array_key_last($tab_values['subs']) === $_sub_key ? ' | ' : '');
		}
		echo '</ul>';
		echo '<br class="clear">';
	}

	if ($sub_values['page'] === false) {
		settings_fields('mnsjay_shippings_' . $tab_key . '_' . $sub_key);
		do_settings_sections('mnsjay_shippings_' . $tab_key . '_' . $sub_key);
		submit_button();
	} else if (is_string($sub_values['page']) and file_exists($sub_values['page'])) {
		require_once($sub_values['page']);
	}

	echo '</form>';
	echo '</div>';
}

function mnsjay_shippings_register() {

	require_once(MNSJAY_PATH . '/includes/shipping/settings-methods.php');

	add_settings_section('mnsjay_shippings_methods_methods', __('Shipping Method Items', 'mnsjay'), function () {
		echo '<p>' . __('Activation settings of shipping methods', 'mnsjay') . '</p>';
	}, 'mnsjay_shippings_methods_methods');

	add_settings_field('mnsjay_shipping_methods', __('Shipping Methods', 'mnsjay'), 'mnsjay_shipping_methods_field_output', 'mnsjay_shippings_methods_methods', 'mnsjay_shippings_methods_methods', ['label_for' => '']);

	register_setting('mnsjay_shippings_methods_methods', 'mnsjay_shipping_methods');
	register_setting('mnsjay_shippings_methods_methods', 'mnsjay_shipping_methods_counter');

	require_once(MNSJAY_PATH . '/includes/shipping/settings-options.php');

	add_settings_section('mnsjay_shippings_options_options', __('Shipping Methods Options', 'mnsjay'), function () {
		echo '<p>' . __('Customization settings of shipping methods', 'mnsjay') . '</p>';
	}, 'mnsjay_shippings_options_options');

	add_settings_field('mnsjay_shipping_options', __('Shipping Options', 'mnsjay'), 'mnsjay_shipping_options_field_output', 'mnsjay_shippings_options_options', 'mnsjay_shippings_options_options', ['label_for' => '']);

	register_setting('mnsjay_shippings_options_options', 'mnsjay_shipping_logos');
	register_setting('mnsjay_shippings_options_options', 'mnsjay_shipping_allowed_gateways');
	register_setting('mnsjay_shippings_options_options', 'mnsjay_shipping_location_required');
	register_setting('mnsjay_shippings_options_options', 'mnsjay_shipping_display_distance');
	register_setting('mnsjay_shippings_options_options', 'mnsjay_shipping_origins');
	register_setting('mnsjay_shippings_options_options', 'mnsjay_shipping_areas');
	register_setting('mnsjay_shippings_options_options', 'mnsjay_shipping_exclude_areas');
	register_setting('mnsjay_shippings_options_options', 'mnsjay_shipping_regions');
	register_setting('mnsjay_shippings_options_options', 'mnsjay_shipping_exclude_regions');
	register_setting('mnsjay_shippings_options_options', 'mnsjay_shipping_disable_shippings');
	register_setting('mnsjay_shippings_options_options', 'mnsjay_shipping_product_ids');
	register_setting('mnsjay_shippings_options_options', 'mnsjay_shipping_exclude_product_ids');
	register_setting('mnsjay_shippings_options_options', 'mnsjay_shipping_product_categories');
	register_setting('mnsjay_shippings_options_options', 'mnsjay_shipping_exclude_product_categories');
	register_setting('mnsjay_shippings_options_options', 'mnsjay_shipping_classes');
	register_setting('mnsjay_shippings_options_options', 'mnsjay_shipping_exclude_classes');
	register_setting('mnsjay_shippings_options_options', 'mnsjay_shipping_base_types');
	register_setting('mnsjay_shippings_options_options', 'mnsjay_shipping_base_costs');
	register_setting('mnsjay_shippings_options_options', 'mnsjay_shipping_extra_costs');
	register_setting('mnsjay_shippings_options_options', 'mnsjay_shipping_week_days');
	register_setting('mnsjay_shippings_options_options', 'mnsjay_shipping_week_times');
	register_setting('mnsjay_shippings_options_options', 'mnsjay_shipping_distances');
	register_setting('mnsjay_shippings_options_options', 'mnsjay_shipping_weights');
	register_setting('mnsjay_shippings_options_options', 'mnsjay_shipping_cart_classes');
	register_setting('mnsjay_shippings_options_options', 'mnsjay_shipping_classes_counter');
}
add_action('admin_init', 'mnsjay_shippings_register');
