<?php

if (!defined('ABSPATH'))
	exit;


function mnsjay_get_sms_webservices() {

	$webservices = array(
		'wpsms' => array(
			'name' => 'WP SMS',
			'type' => 'plugin',
			'url' => 'https://wordpress.org/plugins/wp-sms/',
			'support' => array('plugin', 'patterns', 'pattern_text'),
			'send_callback' => 'mnsjay_send_plugin_wpsms'
		),
		'persianwoocommercesms' => array(
			'name' => 'Persian WooCommerce SMS',
			'type' => 'plugin',
			'url' => 'https://wordpress.org/plugins/persian-woocommerce-sms/',
			'support' => array('plugin', 'patterns', 'pattern_text'),
			'send_callback' => 'mnsjay_send_plugin_persianwoocommercesms'
		),
		'kavenegarcom' => array(
			'name' => 'Kavenegar',
			'type' => 'pattern',
			'url' => 'https://kavenegar.com/',
			'support' => array('apikey', 'patterns', 'pattern_id'),
			'send_callback' => 'mnsjay_send_pattern_kavenegarcom'
		),
		'ippanel' => array(
			'name' => 'IPPanel',
			'type' => 'pattern',
			'url' => 'https://ippanel.com/',
			'support' => array('userpass', 'from', 'patterns', 'pattern_id', 'pattern_vars'),
			'send_callback' => 'mnsjay_send_pattern_ippanel'
		),
		'farazsmscom' => array(
			'name' => 'Faraz SMS',
			'type' => 'pattern',
			'url' => 'https://farazsms.com/',
			'support' => array('userpass', 'from', 'patterns', 'pattern_id', 'pattern_vars'),
			'send_callback' => 'mnsjay_send_pattern_farazsmscom'
		),
		'melipayamak' => array(
			'name' => 'Melipayamak',
			'type' => 'pattern',
			'url' => 'https://melipayamak.com/',
			'support' => array('userpass', 'patterns', 'pattern_id'),
			'send_callback' => 'mnsjay_send_pattern_melipayamak'
		),
		'smsir' => array(
			'name' => 'SMS.IR',
			'type' => 'pattern',
			'url' => 'https://sms.ir/',
			'support' => array('apikey', 'secretkey', 'patterns', 'pattern_id', 'pattern_vars'),
			'send_callback' => 'mnsjay_send_pattern_smsir'
		),
	);

	return apply_filters('mnsjay_sms_webservices', $webservices);
}

function mnsjay_get_sms_patterns() {

	$patterns = array(
		'to_postman' => array(
			'title' => __('Send SMS to Postman', 'mnsjay'),
			'vars' => array(
				'NAME' => __('Postman Name', 'mnsjay')
			),
			'text' => __("Dear %NAME%,\nA shipment was added to your panel to send.", 'mnsjay')
		),
		'to_customer' => array(
			'title' => __('Send SMS to Customer', 'mnsjay'),
			'vars' => array(
				'NAME' => __('Customer Name', 'mnsjay')
			),
			'text' => __("Dear %NAME%,\nYour shipment was delivered to the postman to be sent to you!", 'mnsjay')
		),
		'to_customer_with_code' => array(
			'title' => __('Send Delivery Code SMS to Customer', 'mnsjay'),
			'vars' => array(
				'NAME' => __('Customer Name', 'mnsjay'),
				'CODE' => __('Delivery Code', 'mnsjay'),
			),
			'text' => __("Dear %NAME%,\nYour shipment was delivered to the postman to be sent to you!\nYour delivery code is %CODE%. Give it to the postman before deliver.", 'mnsjay')
		),
	);

	return apply_filters('mnsjay_sms_patterns', $patterns);
}

function mnsjay_get_sms_webservice($webservice_key, $value = 'whole') {

	$webservices = mnsjay_get_sms_webservices();

	if (!isset($webservices[$webservice_key]))
		return false;

	if ($value == 'whole')
		return $webservices[$webservice_key];

	return isset($webservices[$webservice_key][$value]) ? $webservices[$webservice_key][$value] : false;
}

function mnsjay_get_sms_pattern($pattern_key, $value = 'whole') {

	$patterns = mnsjay_get_sms_patterns();

	if (!isset($patterns[$pattern_key]))
		return false;

	if ($value == 'whole')
		return $patterns[$pattern_key];

	return isset($patterns[$pattern_key][$value]) ? $patterns[$pattern_key][$value] : false;
}

function mnsjay_log_sms_response($response) {

	if (mnsjay_get_option_debug_mode() != 'yes')
		return;

	update_option('mnsjay_sms_response', $response);
}

function mnsjay_send_sms($mobile, $pattern_key, $pattern_values) {

	$webservice_key = mnsjay_get_option_sms_webservice();

	if ($webservice_key == 'none')
		return;

	$webservice = mnsjay_get_sms_webservice($webservice_key);

	if (!$webservice)
		return;

	$send_callback = $webservice['send_callback'];

	if (!function_exists($send_callback))
		return;

	$pattern = mnsjay_get_sms_pattern($pattern_key);

	if (!$pattern)
		return;

	foreach ($pattern['vars'] as $var_key => $var_name) {
		$pattern_values[$var_key] = isset($pattern_values[$var_key]) ? $pattern_values[$var_key] : '';
	}

	$patterns = mnsjay_get_option_sms_patterns();

	if (!isset($patterns[$pattern_key]))
		return;

	$pattern_options = $patterns[$pattern_key];

	if ($webservice['type'] == 'plugin' or $webservice['type'] == 'normal') {

		$message = (isset($pattern_options['text']) and $pattern_options['text'] != '') ? $pattern_options['text'] : $pattern['text'];

		foreach ($pattern['vars'] as $var_key => $var_name) {
			$message = str_replace('%' . $var_key . '%', $pattern_values[$var_key], $message);
		}

		$response = $send_callback($mobile, $message);
	} else if ($webservice['type'] == 'pattern') {

		if (!isset($pattern_options['vars']) or !is_array($pattern_options['vars']))
			return;

		$pattern_options['vars'] = array_map(function ($value) {

			$value = trim(str_replace('%', '', $value));
			return $value;
		}, $pattern_options['vars']);

		$response = $send_callback($mobile, $pattern_options, $pattern_values);
	}

	mnsjay_log_sms_response($response);
}

function mnsjay_send_plugin_wpsms($mobile, $message) {

	if (!function_exists('wp_sms_send'))
		return 'function wp_sms_send not exists.';

	return wp_sms_send($mobile, $message, false);
}

function mnsjay_send_plugin_persianwoocommercesms($mobile, $message) {

	if (!function_exists('PWooSMS'))
		return 'function PWooSMS not exists.';

	return PWooSMS()->SendSMS(array(
		'mobile'  => $mobile,
		'message' => $message
	));
}

function mnsjay_send_pattern_kavenegarcom($mobile, $pattern_options, $pattern_values) {

	$key = mnsjay_get_option_sms_apikey();
	$url = 'https://api.kavenegar.com/v1/' . $key . '/verify/lookup.json';
	$response = false;

	$query_strings = array(
		'receptor' => $mobile,
		'template' => $pattern_options['id']
	);

	$var_count = 0;

	foreach ($pattern_options['vars'] as $var_key => $var) {

		$var_count++;
		$var_index = $var_count === 1 ? 'token' : 'token' . $var_count;

		$query_strings[$var_index] = str_replace(' ', '‌', $pattern_values[$var_key]);
	}

	$url = $url . '?' . http_build_query($query_strings);

	if (extension_loaded('curl')) {
		$ch = curl_init($url);
		curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
		curl_setopt($ch, CURLOPT_SSL_VERIFYHOST, false);
		curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false);
		$sms_response = curl_exec($ch);
		curl_close($ch);
	} else {
		$sms_response = @file_get_contents($url);
	}

	if (false !== $sms_response) {
		$json_response = json_decode($sms_response);
		if (!empty($json_response->return->status) && $json_response->return->status == 200) {
			return $response = true; //success
		}
	}

	if ($response !== true) {
		$response = $sms_response;
	}

	return $response;
}

function mnsjay_send_pattern_ippanel($mobile, $pattern_options, $pattern_values) {

	$username = mnsjay_get_option_sms_username();
	$password = mnsjay_get_option_sms_password();
	$from = mnsjay_get_option_sms_from();
	$to = array($mobile);
	$pattern_code = $pattern_options['id'];
	$input_data = array();

	foreach ($pattern_options['vars'] as $var_key => $var) {
		$input_data[$var] = $pattern_values[$var_key];
	}

	$query_strings = http_build_query(array(
		'username' => $username,
		'password' => $password,
		'from' => $from,
		'to' => json_encode($to),
		'input_data' => json_encode($input_data),
		'pattern_code' => $pattern_code,
	));

	$url = 'https://ippanel.com/patterns/pattern?' . $query_strings;
	$handler = curl_init($url);
	curl_setopt($handler, CURLOPT_CUSTOMREQUEST, "POST");
	curl_setopt($handler, CURLOPT_POSTFIELDS, $input_data);
	curl_setopt($handler, CURLOPT_RETURNTRANSFER, true);
	$response = curl_exec($handler);

	return $response;
}

function mnsjay_send_pattern_farazsmscom($mobile, $pattern_options, $pattern_values) {

	return mnsjay_send_pattern_ippanel($mobile, $pattern_options, $pattern_values);
}

function mnsjay_send_pattern_melipayamak($mobile, $pattern_options, $pattern_values) {

	$input_data = array();

	foreach ($pattern_options['vars'] as $var_key => $var) {
		$input_data[] = $pattern_values[$var_key];
	}

	$data = array(
		'username' => mnsjay_get_option_sms_username(),
		'password' => mnsjay_get_option_sms_password(),
		'text' => implode(';', $input_data),
		'to' => $mobile,
		"bodyId" => $pattern_options['id']
	);

	$post_data = http_build_query($data);

	$handle = curl_init('https://rest.payamak-panel.com/api/SendSMS/BaseServiceNumber');
	curl_setopt($handle, CURLOPT_HTTPHEADER, array(
		'content-type' => 'application/x-www-form-urlencoded'
	));
	curl_setopt($handle, CURLOPT_RETURNTRANSFER, true);
	curl_setopt($handle, CURLOPT_SSL_VERIFYHOST, false);
	curl_setopt($handle, CURLOPT_SSL_VERIFYPEER, false);
	curl_setopt($handle, CURLOPT_POST, true);
	curl_setopt($handle, CURLOPT_POSTFIELDS, $post_data);
	$response = curl_exec($handle);

	return $response;
}

function mnsjay_send_pattern_smsir($mobile, $pattern_options, $pattern_values) {

	$postData = array(
		'UserApiKey' => mnsjay_get_option_sms_apikey(),
		'SecretKey' => mnsjay_get_option_sms_secretkey(),
		'System' => 'php_rest_v_1_2'
	);
	$postString = json_encode($postData);

	$ch = curl_init('https://RestfulSms.com/api/Token');
	curl_setopt($ch, CURLOPT_HTTPHEADER, array(
		'Content-Type: application/json'
	));
	curl_setopt($ch, CURLOPT_HEADER, false);
	curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
	curl_setopt($ch, CURLOPT_SSL_VERIFYHOST, false);
	curl_setopt($ch, CURLOPT_POSTFIELDS, $postString);

	$result = curl_exec($ch);
	curl_close($ch);

	$response = json_decode($result);
	$token = false;

	if (is_object($response)) {
		$resultVars = get_object_vars($response);
		if (is_array($resultVars)) {
			@$IsSuccessful = $resultVars['IsSuccessful'];
			if ($IsSuccessful == true) {
				@$TokenKey = $resultVars['TokenKey'];
				$token = $TokenKey;
			}
		}
	}

	if (!$token)
		return false;

	$data = array(
		"ParameterArray" => array(),
		"Mobile" => $mobile,
		"TemplateId" => $pattern_options['id']
	);

	foreach ($pattern_options['vars'] as $var_key => $var) {
		$data["ParameterArray"][] = array("Parameter" => $var, "ParameterValue" => $pattern_values[$var_key]);
	}

	$postString = json_encode($data);

	$ch = curl_init('https://RestfulSms.com/api/UltraFastSend');
	curl_setopt($ch, CURLOPT_HTTPHEADER, array(
		'Content-Type: application/json',
		'x-sms-ir-secure-token: ' . $token
	));
	curl_setopt($ch, CURLOPT_HEADER, false);
	curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
	curl_setopt($ch, CURLOPT_SSL_VERIFYHOST, false);
	curl_setopt($ch, CURLOPT_POSTFIELDS, $postString);

	$result = curl_exec($ch);
	curl_close($ch);

	return $result;
}
