<?php

$algo = sanitize_text_field(get_query_var('oi')); // mnsjay_order_algo original query

if ($algo == false or $algo == '') {
	wp_redirect(home_url());
	exit();
}

if (!mnsjay_validate_order_algo($algo)) {
	wp_redirect(home_url());
	exit();
}

$algo_parse = mnsjay_parse_order_algo($algo);

$order = wc_get_order($algo_parse['order_id']);

if (!$order) {
	wp_redirect(home_url());
	exit();
}

if (!headers_sent()) {
	header("X-Robots-Tag: noindex", true);
}

add_filter('show_admin_bar', '__return_false');

$checkout = $algo_parse['checkout'] === 'b' ? 'billing' : 'shipping';
$location = mnsjay_get_order_location($algo_parse['order_id'], $checkout);

?>
<!DOCTYPE html>
<html <?php language_attributes(); ?> class="mnsjay-order-location-html" style="width: 100%; height: 100%;">

<head>
	<meta charset="UTF-8">
	<meta name="viewport" content="width=device-width, initial-scale=1, minimum-scale=1, maximum-scale=1">
	<meta http-equiv="X-UA-Compatible" content="IE=edge">
	<meta name="robots" content="noindex" />
	<meta name="distribution" content="Global" />
	<?php wp_head(); ?>
</head>

<body class="mnsjay-order-location-page" style="width: 100%; height: 100%;">
	<?php mnsjay_template_map([
		'id' => 'order_' . $checkout . '_map',
		'classes' => ['mnsjay-order-' . $checkout . '-map'],
		'holder_type' => 'fullscreen',
		'central_marker' => false,
		'display_search' => mnsjay_get_option_map_display_search(),
		'device_location' => true,
		'fullscreen' => true,
		'traffic' => mnsjay_get_option_map_display_traffic(),
		'location' => $location,
		'markers' => [
			'destination' => [
				'coord' => $location,
				'class' => 'mnsjay-destination-marker',
				'text' => mnsjay_get_order_formatted_details($order)
			]
		]
	]); ?>
	<div class="mnsjay-routing">
		<span><?php _e('Routing in map application', 'mnsjay'); ?></span>
		<div class="mnsjay-routing-items">
			<?php foreach (mnsjay_order_location_app_items() as $app_key => $app_values) {
				echo '<a href="' . $app_values['url_callback']($location) . '" target="_blank" class="mnsjay-open-in-app mnsjay-' . $app_key . '">' . $app_values['icon'] . '</a>';
			} ?>
		</div>
	</div>
</body>
<?php wp_footer(); ?>

</html>