<?php

$my_account = wc_get_page_permalink('myaccount');

if (mnsjay_get_option_postman_panel_active() != 'yes') {
	wp_redirect($my_account);
	exit();
}

if (!is_user_logged_in()) {
	wp_redirect($my_account);
	exit();
}

$postman = mnsjay_get_postman(get_current_user_id());

if (!$postman->is_postman()) {
	wp_redirect($my_account);
	exit();
}

add_filter('show_admin_bar', '__return_false');

$section = sanitize_text_field(get_query_var('mnsjay_postman_section'));
$section = in_array($section, array_keys(mnsjay_postman_panel_sections())) ? $section : 'dashboard';

?>

<!DOCTYPE html>
<html <?php language_attributes(); ?> class="mnsjay-postman-panel-html">

<head>
	<meta charset="UTF-8">
	<meta name="viewport" content="width=device-width, initial-scale=1, minimum-scale=1, maximum-scale=1">
	<meta http-equiv="X-UA-Compatible" content="IE=edge">
	<meta name="robots" content="index, follow">
	<meta name="distribution" content="Global" />
	<?php wp_head(); ?>
</head>

<body class="mnsjay-postman-body">

	<aside class="mnsjay-sidebar">

		<div class="mnsjay-logo">
			<?php if (mnsjay_get_option_postman_panel_logo_id()) {
				echo '<div class="mnsjay-logo-img"><img src="' . wp_get_attachment_image_url(mnsjay_get_option_postman_panel_logo_id(), 'full') . '"></div>';
			} else {
				echo '<div class="mnsjay-logo-text">' . mnsjay_get_option_postman_panel_title() . '</div>';
			} ?>
		</div>

		<nav class="mnsjay-navbar">
			<ul>
				<?php foreach (mnsjay_postman_panel_sections() as $section_key => $section_values) { ?>
					<li>
						<a href="<?php echo mnsjay_postman_panel_url($section_key); ?>" <?php if ($section_key === $section) echo ' class="mnsjay-active"'; ?>>
							<div class="mnsjay-has-icon"><?php echo mnsjay_svg($section_values['icon']); ?></div>
							<span><?php echo $section_values['title']; ?></span>
						</a>
					</li>
				<?php } ?>
			</ul>
		</nav>

		<div class="mnsjay-side-footer">
			<a href="<?php echo esc_url($my_account); ?>" class="mnsjay-user">
				<div class="mnsjay-user-name">
					<div class="mnsjay-user-icon"><?php echo mnsjay_svg('user_circle'); ?></div>
					<div class="mnsjay-user-text">
						<div class="mnsjay-user-display"><?php echo $postman->get_fullname(); ?></div>
					</div>
				</div>
			</a>
		</div>

	</aside>

	<div class="mnsjay-content">

		<div class="mnsjay-breadcrumb">
			<span class="mnsjay-has-icon"><?php echo mnsjay_svg('house'); ?></span>
			<span><?php echo mnsjay_postman_panel_sections()[$section]['title']; ?></span>
		</div>

		<?php do_action('mnsjay_postman_panel_' . $section . '_section'); ?>

	</div>

	<div class="mnsjay-popup-container mnsjay-delivery-container" style="display: none;">
		<div class="mnsjay-popup-content">
			<div class="mnsjay-popup-details"></div>
			<?php if (mnsjay_get_option_delivery_code_active() === 'yes') { ?>
				<input type="text" class="mnsjay-delivery-code-input" placeholder="<?php _e('Delivery Code', 'mnsjay'); ?>" value="">
			<?php } else { ?>
				<input type="hidden" class="mnsjay-delivery-code-input" placeholder="<?php _e('Delivery Code', 'mnsjay'); ?>" value="">
			<?php } ?>
			<div class="mnsjay-popup-buttons">
				<a href="#confirm" class="mnsjay-button-alt mnsjay-confirm mnsjay-has-icon"><?php echo mnsjay_svg('check'); ?><span><?php _e('Confirm', 'mnsjay'); ?></span></a>
				<a href="#cancel" class="mnsjay-button-alt mnsjay-cancel mnsjay-has-icon"><?php echo mnsjay_svg('xmark'); ?><span><?php _e('Cancel', 'mnsjay'); ?></span></a>
			</div>
		</div>
	</div>

	<div class="mnsjay-popup-container mnsjay-return-container" style="display: none;">
		<div class="mnsjay-popup-content">
			<div class="mnsjay-popup-details"></div>
			<textarea class="mnsjay-return-note" placeholder="<?php _e('Reasons for the return', 'mnsjay'); ?>"></textarea>
			<div class="mnsjay-popup-buttons">
				<a href="#confirm" class="mnsjay-button-alt mnsjay-confirm mnsjay-has-icon"><?php echo mnsjay_svg('check'); ?><span><?php _e('Confirm', 'mnsjay'); ?></span></a>
				<a href="#cancel" class="mnsjay-button-alt mnsjay-cancel mnsjay-has-icon"><?php echo mnsjay_svg('xmark'); ?><span><?php _e('Cancel', 'mnsjay'); ?></span></a>
			</div>
		</div>
	</div>

</body>

<?php wp_footer(); ?>

</html>