<?php

$my_account = wc_get_page_permalink('myaccount');

if (mnsjay_get_option_postman_panel_active() != 'yes') {
	wp_redirect($my_account);
	exit();
}

if (!is_user_logged_in()) {
	wp_redirect($my_account);
	exit();
}

$user_id = get_current_user_id();
$postman = mnsjay_get_postman($user_id);

if (!$postman->is_postman()) {
	wp_redirect($my_account);
	exit();
}

add_filter('show_admin_bar', '__return_false');

$methods = mnsjay_get_option_shipping_methods();

$ready_orders = $postman->get_orders([
	'status' => [mnsjay_get_option_order_ready_status()],
]);
$all_orders = $postman->get_orders([
	'status' => [mnsjay_get_option_order_delivery_status()],
]);

$postman_values = mnsjay_get_option_postmans()[$user_id];
$postman_methods = isset($postman_values['methods']) ? $postman_values['methods'] : array();

$tsp_provider = mnsjay_map_provider(mnsjay_get_option_map_providers()['navigation']);

if ($tsp_provider and isset($tsp_provider['services']['tsp'])) {
	$max_coords = $tsp_provider['services']['tsp']['max_coords'];
	$profiles = $tsp_provider['services']['tsp']['profiles'];
}

$order_ids = array();

foreach ($ready_orders as $order) {
	$order_ids[] = $order->get_id();
}

$map_options = apply_filters('mnsjay_postman_panel_map_options', mnsjay_map_display_default_options(array(
	'central_marker' => false,
	'display_search' => mnsjay_get_option_map_display_search(),
	'gesture_handling' => true,
	'device_location' => true,
	'fullscreen' => true,
	'traffic' => mnsjay_get_option_map_display_traffic(),
	'location' => mnsjay_get_default_location(),
	'watch' => mnsjay_get_option_supervisor_map_active(),
)));

?>

<!DOCTYPE html>
<html <?php language_attributes(); ?> class="mnsjay-postman-panel-html">

<head>
	<meta charset="UTF-8">
	<meta name="viewport" content="width=device-width, initial-scale=1, minimum-scale=1, maximum-scale=1">
	<meta http-equiv="X-UA-Compatible" content="IE=edge">
	<meta name="robots" content="index, follow">
	<meta name="distribution" content="Global" />
	<?php wp_head(); ?>
</head>

<body class="mnsjay-postman-body">

	<div class="mnsjay-header">
		<div class="mnsjay-logo">
			<?php if (mnsjay_get_option_postman_panel_logo_id()) {
				echo '<div class="mnsjay-logo-img"><img src="' . wp_get_attachment_image_url(mnsjay_get_option_postman_panel_logo_id(), 'full') . '"></div>';
			} ?>
			<div class="mnsjay-logo-text">
				<div class="mnsjay-name"><?php echo mnsjay_get_option_postman_panel_title(); ?></div>
				<div class="mnsjay-description"><?php echo mnsjay_get_option_postman_panel_description(); ?></div>
			</div>
		</div>
		<a href="<?php echo esc_url($my_account); ?>" class="mnsjay-user">
			<div class="mnsjay-user-name">
				<div class="mnsjay-user-icon mnsjay-has-icon"><?php echo mnsjay_svg_user(); ?></div>
				<div class="mnsjay-user-text">
					<div class="mnsjay-user-display"><?php echo $postman->get_fullname(); ?></div>
					<div class="mnsjay-user-number"><?php echo sprintf(__('Postman No. %s', 'mnsjay'), mnsjay_maybe_persian($postman_values['counter'])); ?></div>
				</div>
				<div class="mnsjay-user-arrow mnsjay-has-icon"><?php echo mnsjay_svg_arrow_down(); ?></div>
			</div>
		</a>
	</div>

	<?php do_action('mnsjay_postman_panel_before_content', $user_id); ?>

	<div class="mnsjay-block-container mnsjay-grid-items mnsjay-dashboard">
		<div class="mnsjay-grid-item mnsjay-ready" data-count="<?php echo count($order_ids); ?>">
			<div class="mnsjay-grid-title"><?php _e('Shipments ready to send', 'mnsjay'); ?></div>
			<div class="mnsjay-grid-badge"><?php echo mnsjay_maybe_persian(count($order_ids)); ?></div>
		</div>
		<div class="mnsjay-grid-item mnsjay-delivered" data-count="<?php echo count($all_orders); ?>">
			<div class="mnsjay-grid-title"><?php _e('Shipments sent all time', 'mnsjay'); ?></div>
			<div class="mnsjay-grid-badge"><?php echo mnsjay_maybe_persian(count($all_orders)); ?></div>
		</div>
	</div>

	<?php if (mnsjay_get_option_tsp_active() == 'yes' and $tsp_provider and isset($tsp_provider['services']['tsp'])) { ?>
		<div class="mnsjay-block-container mnsjay-tsp-container">

			<div class="mnsjay-block-header">
				<div class="mnsjay-block-title">
					<div class="mnsjay-block-title-icon mnsjay-has-icon"><?php echo mnsjay_svg_bolt(); ?></div>
					<div class="mnsjay-block-title-text">
						<?php _e('Fast Delivery Shipments', 'mnsjay'); ?>
						<span><?php _e('Suggest an optimal route for delivery of shipments', 'mnsjay'); ?></span>
					</div>
				</div>
			</div>

			<div class="mnsjay-block-body mnsjay-tsp-body">
				<form class="mnsjay-tsp-form" method="post">
					<ul class="mnsjay-tsp-form-checklist">
						<?php foreach ($postman_methods as $method_key) {

							if (!mnsjay_shipping_is_active(isset($methods[$method_key]) ? $methods[$method_key] : false))
								continue;

							$first_method = isset($first_method) ? false : true;

							$method = $methods[$method_key];

							echo '<li><label class="checklist"><input type="radio" class="mnsjay-tsp-shipping-input" name="mnsjay_tsp_shipping" value="' . $method_key . '" ' . checked($first_method, true, false) . '>' . $method['title'] . '</label></li>';
						} ?>
					</ul>
					<ul class="mnsjay-tsp-form-checklist mnsjay-tsp-form-orders" data-max="<?php echo $max_coords; ?>">
						<?php foreach ($ready_orders as $order) {

							if ($order->has_shipping_address()) {
								$full_name = $order->get_formatted_shipping_full_name();
								$address_1 = $order->get_shipping_address_1();
								$location = mnsjay_get_order_location($order->get_id(), 'shipping');
							} else {
								$full_name = $order->get_formatted_billing_full_name();
								$address_1 = $order->get_billing_address_1();
								$location = mnsjay_get_order_location($order->get_id(), 'billing');
							}

							$location = $location ? $location : mnsjay_get_order_location($order->get_id(), 'billing');

							if (!$location)
								continue;

							$order_shipping = $order->get_items('shipping');

							if (!$order_shipping)
								continue;

							$method_key = array_shift($order_shipping)->get_method_id();

							if (!in_array($method_key, $postman_methods))
								continue;

							echo '<li data-shipping="' . $method_key . '" id="mnsjay-tsp-order-' . $order->get_id() . '"><label class="checklist"><input type="checkbox" class="mnsjay-tsp-order-input" name="mnsjay_tsp_item[]" value="' . $order->get_id() . '" checked="checked">' . $full_name . '</label></li>';
						} ?>
					</ul>
					<div class="mnsjay-tsp-profiles mnsjay-has-icon">
						<?php foreach ($profiles as $profile) {
							echo '<label class="mnsjay-tsp-profile mnsjay-' . $profile . '"><input class="mnsjay-tsp-profile-input" type="radio" name="mnsjay_tsp_profile" value="' . $profile . '"' . checked($profile, 'driving', false) . '>' . mnsjay_get_tsp_profile_icon($profile) . '</label>';
						} ?>
					</div>
					<div class="mnsjay-tsp-form-buttons">
						<button class="mnsjay-button mnsjay-tsp-button mnsjay-has-icon"><?php echo mnsjay_svg_route(); ?><span><?php _e('Suggest a route', 'mnsjay'); ?></span></button>
					</div>
				</form>
				<div class="mnsjay-tsp-result" style="display: none;">
					<div class="mnsjay-tsp-count"></div>
					<div class="mnsjay-tsp-stats"></div>
					<div class="mnsjay-tsp-step mnsjay-tsp-step-placeholder" style="display: none;">
						<div class="mnsjay-step-text">
							<div class="mnsjay-step-turn"></div>
							<div class="mnsjay-step-description">
								<div class="mnsjay-customer"></div>
								<div class="mnsjay-address"></div>
								<div class="mnsjay-details">
									<div class="mnsjay-distance mnsjay-has-icon"><?php echo mnsjay_svg_road(); ?><span></span></div>
									<div class="mnsjay-duration mnsjay-has-icon"><?php echo mnsjay_svg_stopwatch(); ?><span></span></div>
								</div>
							</div>
						</div>
						<div class="mnsjay-step-buttons">
							<div class="mnsjay-button mnsjay-tsp-step-button mnsjay-info mnsjay-has-icon"><?php echo mnsjay_svg_info(); ?></div>
							<div class="mnsjay-button mnsjay-tsp-step-button mnsjay-location mnsjay-has-icon" data-location=""><?php echo mnsjay_svg_location_dot(); ?></div>
							<div class="mnsjay-button mnsjay-tsp-step-button mnsjay-delivered mnsjay-has-icon"><?php echo mnsjay_svg_check(); ?></div>
						</div>
					</div>
					<div class="mnsjay-tsp-steps"></div>
				</div>
			</div>

		</div>
	<?php } ?>

	<div class="mnsjay-block-container mnsjay-postman-map-container">
		<div class="mnsjay-map-picker mnsjay-autoload mnsjay-postman-map">
			<div class="mnsjay-map-container" id="mnsjay_postman_map" style="width: 100%; height: 500px;">
				<div class="mnsjay-search">
					<div class="mnsjay-search-form">
						<input type="text" class="mnsjay-search-input" placeholder="<?php echo mnsjay_get_option_map_search_text(); ?>" value="">
						<a class="mnsjay-search-button mnsjay-has-icon" href="#search-location"><?php echo mnsjay_magnifying_glass(); ?></a>
					</div>
					<div class="mnsjay-search-results" style="display: none;"></div>
				</div>
				<div class="mnsjay-marker"></div>
			</div>
			<div class="mnsjay-map-row" style="display: none;">
				<div class="mnsjay-map-location">
					<div class="mnsjay-latitude"><?php _e('Latitude', 'mnsjay'); ?>: <span class="mnsjay-ltr"></span></div>
					<div class="mnsjay-longitude"><?php _e('Longitude', 'mnsjay'); ?>: <span class="mnsjay-ltr"></span></div>
				</div>
				<div class="mnsjay-map-buttons"></div>
			</div>
			<input class="mnsjay-location" type="hidden" value="<?php echo $map_options['location']; ?>">
			<input class="mnsjay-coords" type="hidden" value='<?php echo wp_json_encode(mnsjay_get_orders_location($order_ids)); ?>'>
			<input class="mnsjay-map-options" type="hidden" value='<?php echo wp_json_encode($map_options); ?>'>
		</div>
	</div>

	<div class="mnsjay-block-container mnsjay-list-items mnsjay-list-orders">

		<div class="mnsjay-block-header">
			<div class="mnsjay-block-title">
				<div class="mnsjay-block-title-icon mnsjay-has-icon"><?php echo mnsjay_svg_boxes_pack(); ?></div>
				<div class="mnsjay-block-title-text">
					<?php _e('Shipments', 'mnsjay'); ?>
					<span><?php _e('Shipments ready to send', 'mnsjay'); ?></span>
				</div>
			</div>
		</div>

		<?php if (!count($ready_orders)) {

			echo '<div class="mnsjay-postman-empty-text">';
			echo __('There are no orders to send!', 'mnsjay');
			echo '</div>';
		} else {

			foreach ($ready_orders as $order) {

				if ($order->has_shipping_address()) {
					$full_name = $order->get_formatted_shipping_full_name();
					$address_1 = $order->get_shipping_address_1();
					$checkout = 'shipping';
				} else {
					$full_name = $order->get_formatted_billing_full_name();
					$address_1 = $order->get_billing_address_1();
					$checkout = 'billing';
				}

				$location = mnsjay_get_order_location($order->get_id(), $checkout);
				$location_page = mnsjay_create_order_location_url($order->get_id(), $checkout);

				if (!$location) {
					$location = mnsjay_get_order_location($order->get_id(), 'billing');
					$location_page = mnsjay_create_order_location_url($order->get_id(), 'billing');
				}

		?>
				<div class="mnsjay-order-item" id="mnsjay-order-item-<?php echo $order->get_id(); ?>" data-id="<?php echo $order->get_id(); ?>">
					<div class="mnsjay-order-header">
						<div class="mnsjay-order-title">
							<div>
								<span class="mnsjay-order-customer"><?php echo $full_name; ?></span>
								<span class="mnsjay-order-address"><?php echo $address_1; ?></span>
							</div>
						</div>
						<div class="mnsjay-order-arrow mnsjay-has-icon"><?php echo mnsjay_svg_arrow_down(); ?></div>
					</div>
					<div class="mnsjay-order-body" style="display: none;">
						<div class="mnsjay-order-details">
							<?php echo mnsjay_get_order_formatted_details($order); ?>
						</div>
						<div class="mnsjay-order-buttons">
							<?php if ($location) { ?>
								<a href="<?php echo $location_page; ?>" target="_blank" class="mnsjay-button mnsjay-order-button mnsjay-location-page mnsjay-has-icon"><?php echo mnsjay_svg_map_location_dot(); ?><span><?php _e('Location page', 'mnsjay'); ?></span></a>
								<div class="mnsjay-button mnsjay-order-button mnsjay-location mnsjay-has-icon" data-location="<?php echo $location; ?>"><?php echo mnsjay_svg_location_dot(); ?><span><?php _e('Location', 'mnsjay'); ?></span></div>
							<?php } ?>
							<div class="mnsjay-button mnsjay-order-button mnsjay-delivered mnsjay-has-icon"><?php echo mnsjay_svg_check(); ?><span><?php _e('Deliver', 'mnsjay'); ?></span></div>
						</div>
					</div>
				</div>
		<?php }
		} ?>
	</div>

	<?php do_action('mnsjay_postman_panel_after_content', $user_id); ?>

	<div class="mnsjay-delivery-code-container" style="display: none;">
		<div class="mnsjay-delivery-code-content">
			<div class="mnsjay-delivery-details"></div>
			<?php if (mnsjay_get_option_delivery_code_active() == 'yes') { ?>
				<input type="text" class="mnsjay-delivery-code-input" placeholder="<?php _e('Delivery Code', 'mnsjay'); ?>" value="">
			<?php } else { ?>
				<input type="hidden" class="mnsjay-delivery-code-input" placeholder="<?php _e('Delivery Code', 'mnsjay'); ?>" value="">
			<?php } ?>
			<div class="mnsjay-delivery-code-buttons">
				<a href="#confirm" class="mnsjay-button mnsjay-delivery-confirm mnsjay-has-icon"><?php echo mnsjay_svg_check(); ?><span><?php _e('Confirm', 'mnsjay'); ?></span></a>
				<a href="#cancel" class="mnsjay-button mnsjay-delivery-cancel mnsjay-has-icon"><?php echo mnsjay_svg_times(); ?><span><?php _e('Cancel', 'mnsjay'); ?></span></a>
			</div>
		</div>
	</div>

</body>
<?php wp_footer(); ?>

</html>