<?php

if (mnsjay_get_option_supervisor_map_active() !== 'yes') {
	wp_redirect(home_url());
	exit();
}

if (!mnsjay_is_current_user_in_roles(mnsjay_get_option_supervisor_map_roles())) {
	wp_redirect(home_url());
	exit();
}

add_filter('show_admin_bar', '__return_false');

$methods = [];
$postmans = [];
$markers = [];
$items = [];

foreach (mnsjay_get_ready_orders() as $order) {

	$method_key = mnsjay_get_order_shipping_key($order);

	if (!$method_key)
		continue;

	$methods[$method_key] = $method_key;

	$postman = mnsjay_get_postman(mnsjay_get_order_postman_id($order->get_id()));

	if ($postman->is_postman()) {
		$postmans[$postman->postman_id] = $postman;
	}

	$markers['order_' . $order->get_id()] = [
		'coord' => mnsjay_get_order_active_location($order),
		'class' => 'mnsjay-destination-marker',
		'text' => mnsjay_get_order_formatted_details($order)
	];

	$items[] = [
		'type' => 'order',
		'key' => 'order_' . $order->get_id(),
		'origin_key' => 'origin_' . $method_key,
		'postman_key' => 'postman_' . $postman->postman_id
	];
}

foreach ($methods as $method_key) {

	$markers['origin_' . $method_key] = [
		'coord' => mnsjay_get_shipping_origin_coords($method_key),
		'class' => 'mnsjay-origin-marker',
		'text' => mnsjay_get_shipping_default_title($method_key)
	];

	$items[] = [
		'key' => 'origin_' . $method_key,
		'type' => 'origin'
	];
}

foreach ($postmans as $postman) {

	if (empty($postman->get_last_coords()['coord']))
		continue;

	$markers['postman_' . $postman->postman_id] = [
		'coord' => $postman->get_last_coords()['coord'] ?? mnsjay_get_default_location(),
		'class' => 'mnsjay-postman-marker',
		'text' => $postman->get_fullname()
	];

	$items[] = [
		'key' => 'postman_' . $postman->postman_id,
		'type' => 'postman',
		'time' => $postman->get_last_coords()['time'] ?? mnsjay_get_default_location(),
	];
}

?>
<!DOCTYPE html>
<html <?php language_attributes(); ?> class="mnsjay-supervisor-map-html" style="width: 100%; height: 100%;">

<head>
	<meta charset="UTF-8">
	<meta name="viewport" content="width=device-width, initial-scale=1, minimum-scale=1, maximum-scale=1">
	<meta http-equiv="X-UA-Compatible" content="IE=edge">
	<meta name="robots" content="noindex" />
	<meta name="distribution" content="Global" />
	<?php wp_head(); ?>
</head>

<body class="mnsjay-supervisor-map-page" style="width: 100%; height: 100%;">
	<?php mnsjay_template_map([
		'id' => 'mnsjay_supervisor_map',
		'classes' => ['mnsjay-supervisor-map'],
		'holder_type' => 'fullscreen',
		'central_marker' => false,
		'display_search' => mnsjay_get_option_map_display_search(),
		'device_location' => false,
		'fullscreen' => true,
		'traffic' => mnsjay_get_option_map_display_traffic(),
		'markers' => $markers,
		'sv_items' => $items
	]); ?>
	<div class="mnsjay-supervisor-panel">
		<div class="mnsjay-panel-header"></div>
		<div class="mnsjay-panel-section mnsjay-panel-orders">
			<div class="mnsjay-section-header">
				<div class="mnsjay-header-text mnsjay-has-icon"><?php _e('Ready Orders', 'mnsjay'); ?></div>
				<div class="mnsjay-header-arrow mnsjay-has-icon"><?php echo mnsjay_svg('arrow_up'); ?></div>
			</div>
			<div class="mnsjay-section-body" style="display: none;"></div>
		</div>
		<div class="mnsjay-panel-section mnsjay-panel-postmans">
			<div class="mnsjay-section-header">
				<div class="mnsjay-header-text mnsjay-has-icon"><?php _e('Postmans', 'mnsjay'); ?></div>
				<div class="mnsjay-header-arrow mnsjay-has-icon"><?php echo mnsjay_svg('arrow_up'); ?></div>
			</div>
			<div class="mnsjay-section-body" style="display: none;"></div>
		</div>
		<div class="mnsjay-panel-section mnsjay-panel-origins">
			<div class="mnsjay-section-header">
				<div class="mnsjay-header-text mnsjay-has-icon"><?php _e('Shipping Origins', 'mnsjay'); ?></div>
				<div class="mnsjay-header-arrow mnsjay-has-icon"><?php echo mnsjay_svg('arrow_up'); ?></div>
			</div>
			<div class="mnsjay-section-body" style="display: none;"></div>
		</div>
	</div>
</body>
<?php wp_footer(); ?>

</html>