<?php

/**
 * Plugin Name: MNS Jaayegah
 * Plugin URI: https://www.zhaket.com/web/jaayegah-woocommerce-plugin/
 * Description: With this plugin you can calculate shipping costs based on distance and weight.
 * Version: 4.8.0
 * Requires at least: 5.5.0
 * Requires PHP: 7.4.0
 * Author: Hooman Mansuri
 * Author URI: https://hoomanmns.com/
 * Developer: Hooman Mansuri
 * Developer URI: https://www.zhaket.com/store/web/mnsdev
 * Text Domain: mnsjay
 * Domain Path: /languages
 *
 * WC requires at least: 6.0.0
 * WC tested up to: 8.0.0
 *
 * Copyright: © 2023 MNS.
 */

if (!defined('ABSPATH')) {
	exit; // Exit if accessed directly
}

// Define important directories
define('MNSJAY_VERSION', '4.8.0');
define('MNSJAY_ROOT', __FILE__);
define('MNSJAY_PATH', plugin_dir_path(MNSJAY_ROOT));
define('MNSJAY_URL', plugin_dir_url(MNSJAY_ROOT));
define('MNSJAY_FILE', basename(MNSJAY_ROOT));
define('MNSJAY_DIR', basename(MNSJAY_PATH));

// Minimum requirements
define('MNSJAY_WP_MIN', '5.5.0');
define('MNSJAY_WC_MIN', '6.0.0');
define('MNSJAY_IC_MIN', '12.0.0');
define('MNSJAY_PHP_MIN', '7.4.0');

// Add plugin support for Translation
function mnsjay_load_textdomain()
{
	load_plugin_textdomain('mnsjay', false, MNSJAY_DIR . '/languages');
}
add_action('init', 'mnsjay_load_textdomain');

// Add plugin row meta
function mnsjay_row_meta($plugin_meta, $plugin_file, $plugin_data, $status)
{
	if (strpos($plugin_file, MNSJAY_FILE)) {
		$plugin_meta[] = '<a href="https://t.me/codimns">' . __('Telegram Channel', 'mnsjay') . '</a>';
		$plugin_meta[] = '<a href="https://www.zhaket.com/web/jaayegah-woocommerce-plugin/support">' . __('Support', 'mnsjay') . '</a>';
	}

	return $plugin_meta;
}
add_filter('plugin_row_meta', 'mnsjay_row_meta', 10, 4);

// Plugin info
function mnsjay_info($info = null)
{
	$data = get_plugin_data(MNSJAY_ROOT);

	switch ($info) {
		case 'name':
			return $data['Name'];
			break;
		case 'version':
			return $data['Version'];
			break;
		case 'url':
			return esc_url($data['PluginURI']);
			break;
	}

	if ($info === null)
		return $data;

	return isset($data[$info]) ? $data[$info] : null;
}

// Enqueueing Admin Assets
function mnsjay_admin_assets()
{
	mnsjay_register_dependencies();
	mnsjay_enqueue_map_assets();

	wp_enqueue_style('mnsjay-admin', mnsjay_asset_url('admin.css'), ['mnsjay-common'], mnsjay_asset_version('admin.css'));
	wp_enqueue_script('mnsjay-admin', mnsjay_asset_url('admin.js'), ['mnsjay-common'], mnsjay_asset_version('admin.js'), false);

	wp_set_script_translations('mnsjay-admin', 'mnsjay-js', plugin_dir_path(__FILE__) . 'languages');
}

// Enqueueing Public Assets
function mnsjay_public_assets()
{
	mnsjay_register_dependencies();

	if ((function_exists('is_checkout') and is_checkout()) or (function_exists('is_account_page') and is_account_page())) {
		wp_enqueue_style('mnsjay-public', mnsjay_asset_url('public.css'), ['mnsjay-common'], mnsjay_asset_version('public.css'));
		wp_enqueue_script('mnsjay-public', mnsjay_asset_url('public.js'), ['mnsjay-common'], mnsjay_asset_version('public.js'), false);
		mnsjay_enqueue_map_assets();
	}

	if (mnsjay_is_order_location()) {
		wp_enqueue_style('mnsjay-location', mnsjay_asset_url('location.css'), ['mnsjay-common'], mnsjay_asset_version('location.css'));
		wp_enqueue_script('mnsjay-location', mnsjay_asset_url('location.js'), ['mnsjay-common'], mnsjay_asset_version('location.js'), false);
		mnsjay_enqueue_map_assets();
	}

	if (mnsjay_is_postman_panel()) {
		wp_enqueue_style('mnsjay-postman', mnsjay_asset_url('postman.css'), ['mnsjay-common'], mnsjay_asset_version('postman.css'));
		wp_enqueue_script('mnsjay-postman', mnsjay_asset_url('postman.js'), ['mnsjay-common'], mnsjay_asset_version('postman.js'), false);
		wp_enqueue_script('selectWoo');
		wp_enqueue_script('wc-enhanced-select');
		wp_enqueue_style('select2');
		mnsjay_enqueue_map_assets();
	}

	if (mnsjay_is_supervisor_map()) {
		wp_enqueue_style('mnsjay-supervisor', mnsjay_asset_url('supervisor.css'), ['mnsjay-common'], mnsjay_asset_version('supervisor.css'));
		wp_enqueue_script('mnsjay-supervisor', mnsjay_asset_url('supervisor.js'), ['mnsjay-common'], mnsjay_asset_version('supervisor.js'), false);
		mnsjay_enqueue_map_assets();
	}

	if (mnsjay_is_heatmap()) {
		wp_enqueue_style('mnsjay-heatmap', mnsjay_asset_url('heatmap.css'), ['mnsjay-common'], mnsjay_asset_version('heatmap.css'));
		wp_enqueue_script('mnsjay-heatmap-page', mnsjay_asset_url('heatmap.js'), ['mnsjay-common'], mnsjay_asset_version('heatmap.js'), false);
		mnsjay_enqueue_map_assets();
	}

	wp_add_inline_style('mnsjay-postman', mnsjay_array_to_css(array(
		':root' => array(
			'--mnsjay-accent-color' => mnsjay_get_option_postman_panel_accent_color(),
			'--mnsjay-background-color' => mnsjay_get_option_postman_panel_background_color(),
			'--mnsjay-font-size' => mnsjay_get_option_postman_panel_font_size(),
		)
	)));

	wp_localize_script('mnsjay-public', 'mnsjayCheckoutGlobal', array(
		'locationFieldKey' => mnsjay_location_field_key(),
		'onlyInRegions' => mnsjay_get_option_map_only_in_regions()
	));

	wp_localize_script('mnsjay-postman', 'mnsjayPostmanGlobal', array(
		'postmanId' => get_current_user_id(),
	));

	wp_set_script_translations('mnsjay-public', 'mnsjay-js', plugin_dir_path(__FILE__) . 'languages');
	wp_set_script_translations('mnsjay-location', 'mnsjay-js', plugin_dir_path(__FILE__) . 'languages');
	wp_set_script_translations('mnsjay-postman', 'mnsjay-js', plugin_dir_path(__FILE__) . 'languages');
	wp_set_script_translations('mnsjay-supervisor', 'mnsjay-js', plugin_dir_path(__FILE__) . 'languages');
}

// Upgrade version
function mnsjay_version_upgrade()
{
	$current_version = get_option('mnsjay_current_version', null);

	if (version_compare($current_version, MNSJAY_VERSION) === 0)
		return;

	$previous_version = is_null($current_version) ? MNSJAY_VERSION : $current_version;

	update_option('mnsjay_previous_version', $previous_version);
	update_option('mnsjay_current_version', MNSJAY_VERSION);
}

// Set install timestamp
function mnsjay_set_install_time()
{
	$install_time = get_option('mnsjay_install_time');

	if (!$install_time)
		update_option('mnsjay_install_time', time());
}

// Do somethings when activate or deactivate
function mnsjay_activate_plugin()
{
	flush_rewrite_rules(true);

	if (function_exists('mnsjay_version_upgrade'))
		mnsjay_version_upgrade();

	if (function_exists('mnsjay_set_install_time'))
		mnsjay_set_install_time();

	if (!wp_next_scheduled('mnsjay_check_tapin_statuses'))
		wp_schedule_event(time(), 'hourly', 'mnsjay_check_tapin_statuses');
}
register_activation_hook(MNSJAY_ROOT, 'mnsjay_activate_plugin');

function mnsjay_deactivate_plugin()
{
	flush_rewrite_rules(true);

	delete_option('mnsjay_install_time');
	delete_option('mnsjay_permalinks_flushed');

	wp_clear_scheduled_hook('mnsjay_check_tapin_statuses');
}
register_deactivation_hook(MNSJAY_ROOT, 'mnsjay_deactivate_plugin');

// Load notices
require_once(MNSJAY_PATH . '/includes/notices.php');

// Check requirements and run plugin!
function mnsjay_run()
{
	if (version_compare(PHP_VERSION, MNSJAY_PHP_MIN, '<')) {
		add_action('admin_notices', 'mnsjay_admin_php_update_notice__error');
		return;
	}

	if (version_compare(get_bloginfo('version'), MNSJAY_WP_MIN, '<')) {
		add_action('admin_notices', 'mnsjay_admin_wordpress_update_notice__error');
		return;
	}

	if (!in_array('woocommerce/woocommerce.php', apply_filters('active_plugins', get_option('active_plugins')))) {
		add_action('admin_notices', 'mnsjay_admin_woocommerce_notice__error');
		return;
	}

	if (version_compare(get_option('woocommerce_version'), MNSJAY_WC_MIN, '<')) {
		add_action('admin_notices', 'mnsjay_admin_woocommerce_update_notice__error');
		return;
	}

	if (!extension_loaded('ionCube Loader') or !function_exists('ioncube_loader_iversion')) {
		add_action('admin_notices', 'mnsjay_admin_ioncube_loader_notice__error');
		return;
	}

	if (version_compare(implode('.', array_map('intval', str_split(ioncube_loader_iversion(), 2))), MNSJAY_IC_MIN, '<')) {
		add_action('admin_notices', 'mnsjay_admin_ioncube_loader_update_notice__error');
		return;
	}

	require_once(MNSJAY_PATH . '/vendor/autoload.php');
	require_once(MNSJAY_PATH . '/includes/functions.php');

	if (in_array('dokan-lite/dokan.php', apply_filters('active_plugins', get_option('active_plugins')))) {
		require_once(MNSJAY_PATH . '/includes/dokan.php');
	}

	add_action('wp_loaded', 'mnsjay_version_upgrade');
	add_action('wp_loaded', 'mnsjay_set_install_time');
	add_action('admin_notices', 'mnsjay_admin_rating_notice__info');

	add_action('admin_enqueue_scripts', 'mnsjay_admin_assets', PHP_INT_MAX);
	add_action('wp_enqueue_scripts', 'mnsjay_public_assets', PHP_INT_MAX);
}

mnsjay_run();
